@@ -1,9 +1,20 @@
 ////////////////////////////////////////////////////////////////////////
 // Breeze Website Builder
-// Copyright EB Dynamics, Inc., Edward Lemmers, P.E.
+// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
 // For licensing, see license.txt.
 // Created: 9/22/2014	ELL
+// Revised: 6/16/2017	ELL
+// Overhauled for new form system.
 
+function ElExists(el)
+{
+	if ((document.getElementById(el) != null) && (typeof document.getElementById(el) != "undefined"))
+		return true;
+	else
+		return false;
+}
+
+////////////////////////////////////////////////////////////////////////////////////////////////////////
 document.getElementById("userid").focus();
 document.getElementById("javascript_warning").innerHTML = "";
 
@@ -72,7 +83,7 @@ if (document.getElementById("email_link_page").value == "")
 		for (j = 0; j < el_cnt; j++)
 		{
 			el = document.forms[i].elements[j];
-			if ((el.type == "text") && (el.name != "password") && (el.name != "password_confirm"))	{
+			if (el.type == "text")	{
 				tmp = ReadGetVar(el.name);
 				el.value = replaceAll(tmp, "%20", " ");
 				// Special patch for email_confirm.
@@ -83,6 +94,15 @@ if (document.getElementById("email_link_page").value == "")
 						el.value = replaceAll(tmp, "%20", "");
 					}
 				}
+				// Special patch for password_confirm
+				if (el.name == "password_confirm")	{
+					var tmperr = ReadGetVar("err");
+					if(tmperr != "no_match")	{
+						tmp = ReadGetVar("password");
+						if (tmp != "")
+							el.value = tmp;
+					}
+				}
 			}
 			else if (el.type == "textarea")	{
 				tmp = ReadGetVar(el.name);
@@ -109,17 +129,21 @@ if (document.getElementById("email_link_page").value == "")
 	if ((err != undefined) && (err != ""))
 	{
 		if (err == "bad_email")	{
-			document.getElementById("ErrBadEmail").style.display = "table-row";
+			document.getElementById("ErrBadEmail").style.display = "block";
 			document.getElementById("email").focus();
-			document.getElementById("email").className = "field_highlight";
+			class_name = document.getElementById("email").className;
+			class_name = class_name.replace(" required_field", "");
+			document.getElementById("email").className = class_name + " field_highlight";
 		}
 		else if (err == "blank_email")	{
-			document.getElementById("ErrEmail").style.display = "table-row";
+			document.getElementById("ErrEmail").style.display = "block";
 			document.getElementById("email").focus();
-			document.getElementById("email").className = "field_highlight";
+			class_name = document.getElementById("email").className;
+			class_name = class_name.replace(" required_field", "");
+			document.getElementById("email").className = class_name + " field_highlight";
 		}
 		else if (err == "captcha")	{
-			document.getElementById("ErrCaptcha").style.display = "table-row";
+			document.getElementById("ErrCaptcha").style.display = "block";
 			if (captcha_type == "recaptcha")
 				document.getElementById("recaptcha_td").className = "field_highlight";
 			else  if (captcha_type == "recaptcha2")
@@ -130,46 +154,76 @@ if (document.getElementById("email_link_page").value == "")
 				document.getElementById("captcha_response_field").className = "field_highlight";
 		}
 		else if (err == "bad_password")	{
-			document.getElementById("ErrBadPassword").style.display = "table-row";
+			document.getElementById("ErrBadPassword").style.display = "block";
 			document.getElementById("password").focus();
-			document.getElementById("password").className = "field_highlight";
+			class_name = document.getElementById("password").className;
+			class_name = class_name.replace(" required_field", "");
+			document.getElementById("password").className = class_name + " field_highlight";
 		}
 		else if(err == "bad_user")	{          
-			document.getElementById("ErrBadUser").style.display="table-row";
+			document.getElementById("ErrBadUser").style.display="block";
 			document.getElementById("userid").focus();
-			document.getElementById("userid").className = "field_highlight";
+			class_name = document.getElementById("userid").className;
+			class_name = class_name.replace(" required_field", "");
+			document.getElementById("userid").className = class_name + " field_highlight";
 		}
 		else if(err == "bad_access_level")	{          
-			document.getElementById("ErrAccessLevel").style.display="table-row";
+			document.getElementById("ErrAccessLevel").style.display="block";
 		}
 		else if(err == "not_active")	{          
-			document.getElementById("ErrNotActive").style.display="table-row";
+			document.getElementById("ErrNotActive").style.display="block";
 		}
 		else if(err == "password_reset")	{          
-			document.getElementById("PasswordReset").style.display="table-row";
+			document.getElementById("PasswordReset").style.display="block";
 			document.getElementById("userid").focus();
-			document.getElementById("userid").className = "field_highlight";
+			class_name = document.getElementById("userid").className;
+			class_name = class_name.replace(" required_field", "");
+			document.getElementById("userid").className = class_name + " field_highlight";
 		}
 	}
 
 /////////////////////////////////////////////////////////////////////////////////////////////
 function ShowPasswordReset()
 {
-	document.getElementById("reset_password_form").style.display="inline";
+	if (is_mobile)
+		document.getElementById("reset_password_form").style.display="block";
+	else
+		document.getElementById("reset_password_form").style.display="inline";
 	document.getElementById("recaptcha_row").style.display = "none";
 	document.getElementById("recaptcha2_row").style.display = "none";
 	document.getElementById("wscaptcha_row").style.display = "none";
 	document.getElementById("mollomcaptcha_row").style.display = "none";
 	if (document.getElementById("use_captcha").value == 1)
 	{
-		if (document.getElementById("captcha_type").value == "recaptcha")
-			document.getElementById("recaptcha_row").style.display = "table-row";
-		else if (document.getElementById("captcha_type").value == "recaptcha2")
-	        document.getElementById("recaptcha2_row").style.display = "table-row";
-		else if (document.getElementById("captcha_type").value == "wscaptcha")
-			document.getElementById("wscaptcha_row").style.display = "table-row";
-		else if (document.getElementById("captcha_type").value == "mollom")
-			document.getElementById("mollomcaptcha_row").style.display = "table-row";
+		var element_type;
+		if ((document.getElementById("captcha_type").value == "recaptcha") && ElExists('recaptcha_row'))	{
+			element_type = document.getElementById("recaptcha_row").tagName.toLowerCase();
+			if (element_type == "tr")
+				document.getElementById("recaptcha_row").style.display = "table-row";
+			else
+				document.getElementById("recaptcha_row").style.display = "inline-block";
+		}
+		else if ((document.getElementById("captcha_type").value == "recaptcha2") && ElExists('recaptcha2_row'))	{
+			element_type = document.getElementById("recaptcha2_row").tagName.toLowerCase();
+			if (element_type == "tr")
+				document.getElementById("recaptcha2_row").style.display = "table-row";
+			else
+				document.getElementById("recaptcha2_row").style.display = "inline-block";
+		}
+		else if ((document.getElementById("captcha_type").value == "wscaptcha") && ElExists('wscaptcha_row'))	{
+			element_type = document.getElementById("wscaptcha_row").tagName.toLowerCase();
+			if (element_type == "tr")
+				document.getElementById("wscaptcha_row").style.display = "table-row";
+			else
+				document.getElementById("wscaptcha_row").style.display = "inline-block";
+		}
+		else if ((document.getElementById("captcha_type").value == "mollom") && ElExists('mollomcaptcha_row'))	{
+			element_type = document.getElementById("mollomcaptcha_row").tagName.toLowerCase();
+			if (element_type == "tr")
+				document.getElementById("mollomcaptcha_row").style.display = "table-row";
+			else
+				document.getElementById("mollomcaptcha_row").style.display = "inline-block";
+		}
 	}
 	
 	if ((document.getElementById("captcha_type").value == "recaptcha") && (document.getElementById("use_captcha").value == 1))
