@@ -6,6 +6,12 @@
 // Created: 4/3/2014	ELL
 // Modified: 10/15/2014	ELL
 // Added grouping of plugins by category and sub categories.
+// Modified: 6/20/2017	ELL
+// Added filtering to not list "Console Only' plugins.
+// Modified: 10/6/2017	ELL
+// Fixed bug with sub categories that have no plugins display div of next sub category.
+// Added message on where to get plugins when category or sub category contions no plugin.
+// 
 // 
 	
 	include ("check_session.php");
@@ -60,6 +66,10 @@
 <?php
 	echo "var ADD_PLUGIN_TO_PAGE_PAGE_SELECTED = \"" . ADD_PLUGIN_TO_PAGE_PAGE_SELECTED . "\";\n";
 	echo "var ADD_PLUGIN_TO_PAGE_PLUGIN_SELECTED = \"" . ADD_PLUGIN_TO_PAGE_PLUGIN_SELECTED . "\";\n";
+	echo "var GET_MORE_PLUGINS_BTN = '" . GET_MORE_PLUGINS_BTN . "';\n";
+	echo "var CREATE_PAGE_SELECT_NO_PLUGIN_EXISTS_FOR_CAT_1 = '" . CREATE_PAGE_SELECT_NO_PLUGIN_EXISTS_FOR_CAT_1 . "';\n";
+	echo "var CREATE_PAGE_SELECT_NO_PLUGIN_EXISTS_FOR_CAT_2 = '" . CREATE_PAGE_SELECT_NO_PLUGIN_EXISTS_FOR_CAT_2 . "';\n";
+	echo "var CREATE_PAGE_SELECT_NO_PLUGIN_EXISTS_FOR_CAT_3 = '" . CREATE_PAGE_SELECT_NO_PLUGIN_EXISTS_FOR_CAT_3 . "';\n";
 	
 	if (isset($saved_page_name) && ($saved_page_name != "") && isset($saved_plugin_name) && ($saved_plugin_name != ""))
 	{
@@ -84,7 +94,7 @@
 
 <table width="90%" border="0" align="center">
     <tr><td>
-<div class="button_heading_sub_level_1" id="add_plugin_to_page_heading"><div class="button_heading_text_sub_level_1"><?php echo ADD_PLUGIN_TO_PAGE_HEADING; ?></div><div class="help_button" id="help_button" onclick="OpenHelpWindow();">&nbsp;</div></div>
+<div class="button_heading_sub_level_1" id="add_plugin_to_page_heading"><div class="button_heading_text_sub_level_1"><?php echo ADD_PLUGIN_TO_PAGE_HEADING; ?></div><div class="help_button" id="help_button" onClick="OpenHelpWindow();">&nbsp;</div></div>
 	</td></tr>
 </table>
 
@@ -137,13 +147,13 @@
 			$j = 0;
 			$top_border_style = "border-top-width:1px;border-top-color:#585858;border-top-style:solid;";
 			
-		  	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "plugin_categories WHERE (parent_category IS NULL) OR (parent_category = '') ORDER BY sort_order";
+		  	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "plugin_categories WHERE (((parent_category IS NULL) OR (parent_category = '')) AND (category <> 'Console Only')) ORDER BY sort_order";
 			$result = $bwb_dbh->query($query);
 			while($row = $result->fetch(PDO::FETCH_ASSOC))
 			{
 				$category = $row['category'];
 				$parent_cat_id = $cat_id;
-				echo "<div id='cat_select$j' class='button_sub_level_1' style='width:258px;$top_border_style' onClick=\"SelectPluginCategory($cat_id, $parent_cat_id);\"><span class='button_text_sub_level_1'>$category</span></div>\n";
+				echo "<div id='cat_select$j' class='button_sub_level_1' style='width:258px;$top_border_style' onClick=\"SelectPluginCategory('$category', $cat_id, $parent_cat_id);\"><span class='button_text_sub_level_1'>$category</span></div>\n";
 				$j++;
 				$top_border_style = "";
 				
@@ -164,7 +174,7 @@
 					if ($description != "")
 						$description = " - " . $description;
 						
-					echo "<div id='plugin_select$i' class='button_sub_level_1' style='width:99%;$top_border_style' onClick=\"SelectPlugin('$id', $i);\"><span class='button_text_sub_level_1'>$plugin_name$description</span></div>\n";
+					echo "<div id='plugin_select$i' class='button_sub_level_1' style='width:99%;$top_border_style' onClick=\"SelectPlugin('$id', $i);\"><span class='button_text_sub_level_1' style='width:98%'>$plugin_name$description</span></div>\n";
 					$i++;
 					$top_border_style = "";
 				}
@@ -181,16 +191,22 @@
 				while($row2 = $result2->fetch(PDO::FETCH_ASSOC))
 				{
 					$sub_category = $row2['category'];
-					echo "<div id='cat_select$j' class='button_sub_level_1' style='width:258px;' onClick=\"SelectPluginCategory($cat_id, $parent_cat_id);\"><span class='button_text_sub_level_1'>$sub_category</span></div>\n";
+//					echo "<div id='cat_select$j' class='button_sub_level_1' style='width:258px;' onClick=\"SelectPluginCategory($cat_id, $parent_cat_id);\"><span class='button_text_sub_level_1'>$sub_category</span></div>\n";
+					$sub_cat_div_str = "<div id='cat_select$j' class='button_sub_level_1' style='width:258px;' onClick=\"SelectPluginCategory('$sub_category', $cat_id, $parent_cat_id);\"><span class='button_text_sub_level_1'>$sub_category</span></div>\n";
+					$alt_sub_cat_div_str = "<div id='cat_select$j' class='button_sub_level_1' style='width:258px;' onClick=\"DisplayNoPluginsInSubCatMsg('$sub_category', $cat_id, $parent_cat_id);\"><span class='button_text_sub_level_1'>$sub_category</span></div>\n";
 					$j++;
 					
 					$query = "SELECT `id`, `name`, `description` FROM `" . BWB_TABLE_PREFIX . "plugins` WHERE (`available` = 1) AND (`category` = '$sub_category') ORDER BY `sort_order`";
 					$result3 = $bwb_dbh->query($query);
 					$num_results = $result3->rowCount();
 					if ($num_results > 0)	{
+						echo $sub_cat_div_str;
 						echo "<div style='margin-left:20px; display:none;' id='div_$cat_id'>\n";
-						$cat_id++;
+//						$cat_id++;
 					}
+					else
+						echo $alt_sub_cat_div_str;
+					$cat_id++;
 					
 					$top_border_style = "border-top-width:1px;border-top-color:#585858;border-top-style:solid;";
 					while($row3 = $result3->fetch(PDO::FETCH_ASSOC))
@@ -201,7 +217,7 @@
 						if ($description != "")
 							$description = " - " . $description;
 						
-						echo "<div id='plugin_select$i' class='button_sub_level_1' style='width:99%;$top_border_style' onClick=\"SelectPlugin('$id', $i);\"><span class='button_text_sub_level_1'>$plugin_name$description</span></div>\n";
+						echo "<div id='plugin_select$i' class='button_sub_level_1' style='width:99%;$top_border_style' onClick=\"SelectPlugin('$id', $i);\"><span class='button_text_sub_level_1' style='width:98%'>$plugin_name$description</span></div>\n";
 						$i++;
 						$top_border_style = "";
 					}
@@ -211,7 +227,9 @@
 				if ($result2->rowCount() > 0)
 					echo "</div>\n";
 			}
+			$cat_id++;
             ?>
+            <div class='button_sub_level_1' style='width:258px;' ><a href="http://breezewebsitebuilder.com/plugins.php" target="_blank" class="button_console_link"><span class='button_text_sub_level_1'><?php echo GET_MORE_PLUGINS_BTN; ?></span></a></div>
             
             <input type="hidden" name="plugin" id="plugin" />
             <input type="hidden" name="plugin_cnt" id="plugin_cnt" value="<?php echo $plugin_cnt; ?>" />
@@ -223,14 +241,14 @@
           </tr>
          </table>
         
-          <div class='button_console_add_disabled' onClick="document.getElementById('frmAddPluginToPage').submit();" id="install_plugin_btn"><span class='button_console_text_w_icon'>Install</span></div>
+          <div class='button_console_add_disabled' onClick="AddPluginToPage();" id="install_plugin_btn"><span class='button_console_text_w_icon'>Install</span></div>
 		
 	  </form>
 
 <?php include("lib/popup_msg.html"); ?>
 
 <script language="javascript" type="text/javascript">
-	HidePopupMsg();
+	popup_msg.HidePopupMsg();
 	
 <?php	if (isset($saved_page_name) && ($saved_page_name != ""))	{	?>
 	popup_msg.top_offset = 100;
