@@ -38,7 +38,7 @@
 	$result = $bwb_dbh->query($query);
 	$row = $result->fetch(PDO::FETCH_ASSOC);
 	$tmp_user_name = $row["UserID"];
-	if ($tmp_user_name)
+	if (isset($tmp_user_name))
 	{
 		if (!isset($table) || ($table == "users") || ($table == ""))
 			echo $user_name . " " . CLASSES_ADD_CLASS_ADD_ERR . " " . CLICK_WORD . " <a href=\"users.php\" title=\"" . HERE_WORD . "\">" . HERE_WORD . "</a> " . MANAGE_USERS_USER_ALREADY_EXISTS_ERR;
