@@ -16,8 +16,5 @@
 	else
 		$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "page_data WHERE page_name='$page_name'";
 	$result = $bwb_dbh->query($query);
-	if ($row = $result->fetch(PDO::FETCH_ASSOC))
-		print "1";
-	else
-		print "0";
+	echo $result->rowCount();
 ?>
\ No newline at end of file
