@@ -36,11 +36,22 @@
 // Replaced JavaScript AJAX with JQuery AJAX.
 // Converted from form post to (JQuery) AJAX.
 // Added style-sheet switching.
+// Revised: 4/28/2016	ELL
+// Added trapping of adding blank class or ID namse.
+// Revised: 5/27/2016	ELL
+// Added class-name copy button for copy/rename class.
+// Modified: 12/2/2016	ELL
+// Consolidated all class tables into site_classes table indexed by style_sheet field.
+// Consolidated all CSS tables into site_css table indexed by style_sheet field.
+// Revised: 2/3/2017	ELL
+// Added ability to copy from all classes by checking checkbox.
+// Revised: 2/5/2018	ELL
+// Filtered out fonts style sheet as this is created soley under custom fonts management and thus should not be edited in the CSS editor, 
+// has no attributes that should be altered, and has no reason to be modified for mobile.
 // 
 	include ("check_session.php");
 		
 	$style_sheet = $_REQUEST['style_sheet'];
-	$class_table = $style_sheet . "_classes";
 	$last_class_edited = $_SESSION['last_class_edited'];
 	if (isset($_GET['class_sort_method']))	{
 		$class_sort_method = $_GET['class_sort_method'];
@@ -50,6 +61,11 @@
 		$class_sort_method = $_SESSION['class_sort_method'];
 	else
 		$class_sort_method = 0;
+		
+	if (isset($_SESSION['style_sheet_sort_method']) && ($_SESSION['style_sheet_sort_method'] == 1))
+		$style_sheet_sort_method = 1;
+	else
+		$style_sheet_sort_method = 0;
 ?>
 <!DOCTYPE html>
 <html>
@@ -133,6 +149,7 @@
 	echo "var CLASSES_DEFINE_SUBCLASS_DEFINE_ERR = \"" . CLASSES_DEFINE_SUBCLASS_DEFINE_ERR . "\";\n";
 	echo "var CLASSES_DELETE_CLASS_COMPLETE_MSG = \"" . CLASSES_DELETE_CLASS_COMPLETE_MSG . "\";\n";
 	echo "var CLASSES_NO_CUSTOM_CLASSES_DEFINED = \"" . CLASSES_NO_CUSTOM_CLASSES_DEFINED . "\";\n";
+	echo "var CLASSES_ADD_CLASS_CANNOT_BE_BLANK_MSG = \"" . CLASSES_ADD_CLASS_CANNOT_BE_BLANK_MSG . "\";\n";
 ?>
 
 var style_sheet = '<?php echo $style_sheet; ?>';
@@ -150,12 +167,41 @@ var style_sheet = '<?php echo $style_sheet; ?>';
 <form name="frmChangeStyleSheet" id="frmChangeStyleSheet" action="classes.php" method="post" enctype="multipart/form-data">
   	<select name="style_sheet" id="style_sheet" onChange="document.getElementById('frmChangeStyleSheet').submit();">
 <?php
-	$query = "SELECT * FROM `" . BWB_TABLE_PREFIX . "style_sheets`";
+	if (isset($style_sheet_sort_method) && ($style_sheet_sort_method == 1))
+		$sort = "`description`, `name`";
+	else
+		$sort = "sort_order";
+				
+	$query = "SELECT * FROM `" . BWB_TABLE_PREFIX . "style_sheets` WHERE `name` <> 'fonts' ORDER BY " . $sort;
 	$result = $bwb_dbh->query($query);
+	$style_sheets = array();
 	while($row = $result->fetch(PDO::FETCH_ASSOC))
 	{
 		$tmp_style_sheet = $row['name'];
 		$tmp_description = $row['description'];
+		if ((strpos($tmp_style_sheet, "menu", 0) !== false) && (strpos($tmp_style_sheet, "item", 4) === false))
+		{
+			$query2 = "SELECT * FROM " . BWB_TABLE_PREFIX . "menus WHERE menu_name = '$tmp_style_sheet'";
+			$result2 = $bwb_dbh->query($query2);
+			$row2 = $result2->fetch(PDO::FETCH_ASSOC);
+			$tmp_description = $row2['description'] . " Styles";
+		}
+		elseif ((strpos($tmp_style_sheet, "menu", 0) !== false) && (strpos($tmp_style_sheet, "item", 4) !== false))
+		{
+			$tmp_name = str_replace("_item", "", $tmp_style_sheet);
+			$query2 = "SELECT * FROM " . BWB_TABLE_PREFIX . "menus WHERE menu_name = '$tmp_name'";
+			$result2 = $bwb_dbh->query($query2);
+			$row2 = $result2->fetch(PDO::FETCH_ASSOC);
+			$tmp_description = $row2['description'] . " Item Styles";
+		}
+		$style_sheets[$tmp_style_sheet] = $tmp_description;
+	}
+	
+	if (isset($style_sheet_sort_method) && ($style_sheet_sort_method == 1))
+		asort($style_sheets, SORT_FLAG_CASE);
+	
+	foreach ($style_sheets as $tmp_style_sheet => $tmp_description)
+	{	
 		if ($tmp_style_sheet == $style_sheet)
 			echo "		<option value='$tmp_style_sheet' selected>$tmp_description</option>\n";
 		else
@@ -183,7 +229,7 @@ var style_sheet = '<?php echo $style_sheet; ?>';
             <option value=""><?php echo _NONE_WORD; ?></option>
         </select>
     </td>
-    <td><input type="text" name="class" id="class" /></td>
+    <td><input type="text" name="class" id="class" onKeyPress="CheckClassName(this);" /></td>
     <td align="right"><?php echo DESCRIPTION_WORD; ?>:&nbsp;</td>
     <td><input type="text" name="description" id="description"></td>
     <td align="right"><?php echo SORT_ORDER; ?>:&nbsp;</td>
@@ -319,7 +365,7 @@ var style_sheet = '<?php echo $style_sheet; ?>';
 
   <table width="100%" border="0" cellspacing="0" cellpadding="0">
   <tr>
-    <td colspan="8" class="sub_title" style="padding-left:5px;"><?php echo CLASSES_COPY_CLASS; ?></td>
+    <td colspan="9" class="sub_title" style="padding-left:5px;"><?php echo CLASSES_COPY_CLASS; ?></td>
   </tr>
   <tr>
   	<td align="center">
@@ -334,8 +380,9 @@ var style_sheet = '<?php echo $style_sheet; ?>';
         </div>
     </td>
   	<td align="right"><?php echo CLASSES_FROM_CLASS; ?>:&nbsp;</td>
-    <td id="copy_from_class_td">&nbsp;
-		
+    <td id="copy_from_class_td">&nbsp;</td>
+    <td style="width:30px;">
+        <span style="display:inline; font-size:24px; cursor:pointer;" onClick="CopyClassName();">&raquo;</span>
     </td>
     <td style="text-align:right; width:90px;"><?php echo CLASSES_TO_CLASS; ?>:&nbsp;</td>
     <td style="text-align:right; width:90px;">
@@ -350,14 +397,10 @@ var style_sheet = '<?php echo $style_sheet; ?>';
   	<span id="to_style_sheet_label"><?php echo CLASSES_TO_STYLE_SHEET; ?>: </span>
     </td>
     <td align="left">
-      <select name="to_style_sheet" id="to_style_sheet">
-<?php
-	$query = "SELECT * FROM `" . BWB_TABLE_PREFIX . "style_sheets`";
-	$result = $bwb_dbh->query($query);
-	while($row = $result->fetch(PDO::FETCH_ASSOC))
+      <select name="to_style_sheet" id="to_style_sheet" onChange="CheckClassNames();">
+<?php	
+	foreach ($style_sheets as $tmp_style_sheet => $tmp_description)
 	{
-		$tmp_style_sheet = $row['name'];
-		$tmp_description = $row['description'];
 		if ($tmp_style_sheet == $style_sheet)
 			echo "		<option value='$tmp_style_sheet' selected>$tmp_description</option>\n";
 		else
@@ -370,11 +413,15 @@ var style_sheet = '<?php echo $style_sheet; ?>';
   	<td colspan="2">&nbsp;</td>
   	<td>
     	<span class="small_message"><?php echo EDIT_CSS_SORT_ALPHABETICALLY; ?></span> <input type="checkbox" id="sort_alpha_copy" name="sort_alpha" <?php if ($class_sort_method == 1) echo "checked='checked'"; ?> onClick="ChangeSort(this.checked);" />
+        
+        <div style="margin-bottom:-25px; margin-top:5px;">
+        <span class="small_message" ><?php echo EDIT_CSS_SHOW_ALL_CLASSES; ?></span> <input type="checkbox" id="show_all_classes" name="show_all_classes" onClick="GetClassLists();" />
+        </div>
     </td>
-    <td colspan="5">&nbsp;</td>
+    <td colspan="6">&nbsp;</td>
   </tr>
   <tr>
-    <td colspan="8" align="center" style="padding-bottom:10px;">
+    <td colspan="9" align="center" style="padding-bottom:10px;">
       <div class="button_console_edit_disabled" id="copy_rename_btn" onClick="CopyClass();">
         <span class='button_console_text_w_icon'><?php echo COPY_RENAME_PAGE_COPY_RENAME_BTN; ?></span>
       </div>
@@ -405,7 +452,7 @@ var style_sheet = '<?php echo $style_sheet; ?>';
 <?php include("lib/popup_msg.html"); ?>
 
 <script language="javascript" type="text/javascript">
-	HidePopupMsg();
+	popup_msg.HidePopupMsg();
 </script>
 </body>
 </html>
