@@ -48,6 +48,10 @@
 // Revised plugin code insertion to handle multiple areas that now exist in all-in-one template.
 // Revised: 1/4/2015	ELL
 // Fixed bug with copy page introduced with new page template layout files on 10/3/2015. Implementation was incorrect.
+// Modified: 12/2/2016	ELL
+// Consolidated all menu items tables into menu_items.
+// Revised: 1/12/2016	ELL
+// Modified error handling for attempting to rename page to existing page to have nice AJAX-like experience.
 //
 
 include ("check_session.php");
@@ -110,6 +114,7 @@ $new_name = preg_replace("/[^A-Za-z0-9_.-]/", "", $new_name, -1);
 			echo COPY_RENAME_PAGE_ERROR_OPENING_NEW_PAGE_ERR . " " . CLICK_WORD . " <a href=\"copy_rename_page_select.php\" title=\"" . HERE_WORD . "\">" . HERE_WORD . "</a> " . COPY_RENAME_PAGE_TO_RETURN_TO_COPY_RENAME_CONSOLE . " \n" . $php_errormsg;
 			exit;
 		}
+
 		if (!fwrite($fh, $contents)) {
 			echo COPY_RENAME_PAGE_ERROR_UPDATING_PAGE_NAME_REFERENCES_ERR . " " . CLICK_WORD . " <a href=\"copy_rename_page_select.php\" title=\"" . HERE_WORD . "\">" . HERE_WORD . "</a> " . COPY_RENAME_PAGE_TO_RETURN_TO_COPY_RENAME_CONSOLE . " \n" . $php_errormsg;
 			exit;
@@ -131,7 +136,8 @@ $new_name = preg_replace("/[^A-Za-z0-9_.-]/", "", $new_name, -1);
 		$query = "SELECT * FROM `" . BWB_TABLE_PREFIX . "page_data` WHERE `page_name`='$new_name'";
 		$result = $bwb_dbh->query($query);
 		if ($result->rowCount() > 0) {
-			echo COPY_RENAME_PAGE_RENAME_NEW_PAGE_ALREADY_EXISTS_1_ERR . " $new_name " . COPY_RENAME_PAGE_RENAME_NEW_PAGE_ALREADY_EXISTS_2_ERR . " $page_name " . TO_WORD . " $new_name.  " . CLICK_WORD . " <a href=\"copy_rename_page_select.php\" title=\"" . HERE_WORD . "\">" . HERE_WORD . "</a> " . COPY_RENAME_PAGE_RENAME_NEW_PAGE_ALREADY_EXISTS_3_ERR;
+			$err_msg = COPY_RENAME_PAGE_RENAME_NEW_PAGE_ALREADY_EXISTS_1_ERR . " $new_name " . COPY_RENAME_PAGE_RENAME_NEW_PAGE_ALREADY_EXISTS_2_ERR . " <b>$page_name</b> " . TO_WORD . " <b>$new_name</b>.";
+			header("Location: copy_rename_page_select.php?page_name=$page_name&new_name=$new_name&copy_mode=$copy_mode&err_msg=$err_msg");
 			exit;
 		}
 		
@@ -257,9 +263,9 @@ $new_name = preg_replace("/[^A-Za-z0-9_.-]/", "", $new_name, -1);
 			$query = "SELECT * FROM `" . BWB_TABLE_PREFIX . "page_data` WHERE `page_name`='$new_name'";
 			$result = $bwb_dbh->query($query);
 			if ($result->rowCount() > 0)
-				$query = "UPDATE `" . BWB_TABLE_PREFIX . "page_data` SET `page_content`='$page_content', `template`='$template', `revised`='$revised', `plugins`='$plugin_ids', `use_table_structure`=$use_table_structure, `use_table_structure_mobile`=$use_table_structure_mobile, `body_onload`='$body_onload', `body_onload_function`='$on_load_function', `head_name`='$head_name', `header_name`='$header_name', `top_name`='$top_name', `left_name`='$left_name', `right_name`='$right_name', `bottom_name`='$bottom_name', `footer_name`='$footer_name', `insert_default_head`='$insert_default_head', `insert_default_header`='$insert_default_header', `insert_default_top`='$insert_default_top', `insert_default_left`='$insert_default_left', `insert_default_right`='$insert_default_right', `insert_default_bottom`='$insert_default_bottom', `insert_default_footer`='$insert_default_footer' WHERE `page_name`='$new_name'";
+				$query = "UPDATE `" . BWB_TABLE_PREFIX . "page_data` SET `page_content`='$page_content', `template`='$template', `revised`='$revised', `plugins`='$plugin_ids', `use_table_structure`=$use_table_structure, `use_table_structure_mobile`=$use_table_structure_mobile, `body_onload`='$body_onload', `body_onload_function`='$body_onload_function', `head_name`='$head_name', `header_name`='$header_name', `top_name`='$top_name', `left_name`='$left_name', `right_name`='$right_name', `bottom_name`='$bottom_name', `footer_name`='$footer_name', `insert_default_head`='$insert_default_head', `insert_default_header`='$insert_default_header', `insert_default_top`='$insert_default_top', `insert_default_left`='$insert_default_left', `insert_default_right`='$insert_default_right', `insert_default_bottom`='$insert_default_bottom', `insert_default_footer`='$insert_default_footer' WHERE `page_name`='$new_name'";
 			else
-				$query = "INSERT INTO `" . BWB_TABLE_PREFIX . "page_data` SET `page_name`='$new_name', `page_content`='$page_content', `template`='$template', `revised`='$revised', `plugins`='$plugin_ids', `use_table_structure`=$use_table_structure, `use_table_structure_mobile`=$use_table_structure_mobile, `body_onload`='$body_onload', `body_onload_function`='$on_load_function', `head_name`='$head_name', `header_name`='$header_name', `top_name`='$top_name', `left_name`='$left_name', `right_name`='$right_name', `bottom_name`='$bottom_name', `footer_name`='$footer_name', `insert_default_head`='$insert_default_head', `insert_default_header`='$insert_default_header', `insert_default_top`='$insert_default_top', `insert_default_left`='$insert_default_left', `insert_default_right`='$insert_default_right', `insert_default_bottom`='$insert_default_bottom', `insert_default_footer`='$insert_default_footer'";
+				$query = "INSERT INTO `" . BWB_TABLE_PREFIX . "page_data` SET `page_name`='$new_name', `page_content`='$page_content', `template`='$template', `revised`='$revised', `plugins`='$plugin_ids', `use_table_structure`=$use_table_structure, `use_table_structure_mobile`=$use_table_structure_mobile, `body_onload`='$body_onload', `body_onload_function`='$body_onload_function', `head_name`='$head_name', `header_name`='$header_name', `top_name`='$top_name', `left_name`='$left_name', `right_name`='$right_name', `bottom_name`='$bottom_name', `footer_name`='$footer_name', `insert_default_head`='$insert_default_head', `insert_default_header`='$insert_default_header', `insert_default_top`='$insert_default_top', `insert_default_left`='$insert_default_left', `insert_default_right`='$insert_default_right', `insert_default_bottom`='$insert_default_bottom', `insert_default_footer`='$insert_default_footer'";
 			$cnt = $bwb_dbh->exec($query);
 
 			// Clear any old junk in draft table.
@@ -335,7 +341,7 @@ $new_name = preg_replace("/[^A-Za-z0-9_.-]/", "", $new_name, -1);
 		elseif ($create_new_template == 1)
 			// Get new content based on selected site option for template.
 			$contents = GetNewTemplateContentFromSiteOptions($new_name, $new_file_name, $page_name, $bwb_dbh);
-		
+
 		// Create new file.
 		if (!($fh = fopen($new_file_name, 'x'))) {
 			echo COPY_RENAME_PAGE_ERROR_OPENING_NEW_PAGE_ERR . " " . CLICK_WORD . " <a href=\"copy_rename_page_select.php\" title=\"" . HERE_WORD . "\">" . HERE_WORD . "</a> " . COPY_RENAME_PAGE_TO_RETURN_TO_COPY_RENAME_CONSOLE . " \n" . $php_errormsg;
@@ -365,16 +371,8 @@ $new_name = preg_replace("/[^A-Za-z0-9_.-]/", "", $new_name, -1);
 		while ($row2 = $result2->fetch(PDO::FETCH_ASSOC))
 		{
 			$menu = $row2['menu_name'];
-			$menu_type = $row2['menu_type'];
-			$tmp = str_replace("_mobile", "", $menu);
-			$suffix = substr($tmp, 4);
-			$query = "UPDATE `" . BWB_TABLE_PREFIX . "menu" . $suffix . "_items` SET `URL`='" . $new_name . "' WHERE `URL`='" . $old_name . "'";
+			$query = "UPDATE `" . BWB_TABLE_PREFIX . "menu_items` SET `URL`='" . $new_name . "' WHERE `menu`='" . $menu . "' AND `URL`='" . $old_name . "'";
 			$cnt = $bwb_dbh->exec($query);
-			
-			////////////////////////////////////////////////////////////
-			// Re-write menu_items.js with new references.
-			if ($menu_type == 1)
-				include("save_menu_items_file.php");
 		}
 	}
 	
@@ -386,12 +384,6 @@ $new_name = preg_replace("/[^A-Za-z0-9_.-]/", "", $new_name, -1);
 	///////////////////////////////////////////////////////////////////////////////////////////
 	function GetNewTemplateContentFromSiteOptions($pagename, $file_name, $old_page_name, $bwb_dbh)
 	{
-		/////////////////////////////////////////
-		// Read file.
-		$fh = fopen($file_name, 'r') or die(COPY_RENAME_PAGE_CANT_READ_ERR . $file_name . ": " . $php_errormsg);
-		$contents = fread($fh, filesize($file_name));
-		fclose($fh) or die($php_errormsg);
-	
 		//Get template from database.
 		$query = "SELECT `page_template` FROM `" . BWB_TABLE_PREFIX . "template` WHERE `template_name` = 'all'";
 		$result = $bwb_dbh->query($query);
