@@ -57,6 +57,19 @@
 // Modified to set template field in page data record instead of pulling specific template.
 // Modified to set border area and head fields in page data record instead of parsing template layout file to insert custom border area references.
 // Added setting of body_onload function name as attribute it the page data table.
+// Revised: 5/26/2016	ELL
+// Added function string checking to standardize entry of function call.
+// Revised: 6/11/2016	ELL
+// Modified template minimum requirements checking to include header and footer.
+// Added simultaneous deployment of mobile styles for plugin if provided.
+// Revised: 8/15/2016	ELL
+// Added ability to adapt script and css folders in head HTML to config file settings.
+// Revised: 11/11/2016	ELL
+// Implemented new plugin field custom_css_sql.
+// Revised: 1/9/2017	ELL
+// Added hook to allow to be called without going to editor.  This facilitates creating child plugin pages when creating a group of pages out of a plugin group.
+// Revised: 6/19/2017	ELL
+// Moved 'deployed' field to new table plugins_deployed.
 //
 
 include ("check_session.php");
@@ -65,12 +78,13 @@ $page_name = $_POST['createPage'];
 $plugin = $_POST['plugin'];
 $template_name = $_POST['template_name'];
 $mode = $_REQUEST['mode'];
+$no_edit = $_REQUEST['no_edit'];
 
 include("lib/run_sql.php");
 include ("lib/build_css_string.php");
 
 ////////////////////////////////////////////////////////////////////////////////////////////////
-function copy_table_structure($table, $table_prefix, $dbh, $database)
+function copy_table_structure($table, $table_prefix, $dbh, $database, $source_table = "", $copy_data = false)
 {
 	$query = "SELECT COUNT(*) FROM information_schema.tables WHERE table_schema = '" . $database . "' AND table_name = '" . $table_prefix . $table . "'";
 	$result = $dbh->query($query);
@@ -79,13 +93,21 @@ function copy_table_structure($table, $table_prefix, $dbh, $database)
 	if ($table_count < 1)
 	{
 		// Must be a missing menu table, find suffix.
-		if (strpos($table, "_classes") > 0)
-			$source_table = $table_prefix . "site_classes";
+		if ($source_table == "")	{
+			if (strpos($table, "_classes") > 0)
+				$source_table = $table_prefix . "site_classes";
+			else
+				$source_table = $table_prefix . "site_css";
+		}
 		else
-			$source_table = $table_prefix . "site_css";
+			$source_table = $table_prefix . $source_table;
 
 		$query = "CREATE TABLE " . $table_prefix . $table . " LIKE " . $source_table;
 		$cnt = $dbh->exec($query);
+		if ($copy_data === true)	{
+			$query = "INSERT " . $table_prefix . $table . " SELECT * FROM " . $source_table;
+			$cnt = $dbh->exec($query);
+		}
 	}
 		
 	return 1;
@@ -148,6 +170,7 @@ function copy_table_structure($table, $table_prefix, $dbh, $database)
 		}
 	}
 	
+	$page_content_divider = "<!-- Page Content Divider -->";
 	// If plugin code selected, then get plugin code snippet.
 	if ((!isset($plugin)) || ($plugin == ""))
 		$plugin = "-not selected-";
@@ -167,7 +190,7 @@ function copy_table_structure($table, $table_prefix, $dbh, $database)
 		$left_code = $row["left_code"];
 		$left_html = $row["left_html"];
 		$content_code = $row["content_code"];
-		$content_html = $row["content_html"];
+		$content_html = $page_content_divider . "\n" . $row["content_html"];
 		$right_code = $row["right_code"];
 		$right_html = $row["right_html"];
 		$bottom_code = $row["bottom_code"];
@@ -178,94 +201,129 @@ function copy_table_structure($table, $table_prefix, $dbh, $database)
 		$style_sheet_description = $row["style_sheet_description"];
 		$class_sql = $row["class_sql"];
 		$css_sql = $row["css_sql"];
+		$custom_css_sql = $row["custom_css_sql"];
 		$plugin_sql = $row["plugin_sql"];
-		$deployed = $row["deployed"];
 		$disable_site_styles = $row["disable_site_styles"];
 		$body_onload = $row["body_onload"];
-		$body_onload_function = $row["body_onload_function"];
-		$body_onload_function = (isset($row["body_onload_function"]) ? $row["body_onload_function"] : $page_name . "_load");
+		if (isset($row["body_onload_function"]) && ($row["body_onload_function"] != ""))	{
+			$body_onload_function = $row["body_onload_function"];
+			$funct_str_len = strlen($body_onload_function);
+			$funct_str_end = substr($body_onload_function, $funct_str_len - 3);
+			if (strpos($funct_str_end, "();") === false)	{
+				if (strpos($funct_str_end, ")") == 2)
+					$body_onload_function .= ";";
+				elseif (strpos($funct_str_end, ");") != 1)
+					$body_onload_function .= "();";
+			}
+		}
+		else
+			$body_onload_function = $page_name . "_load();";
+			
+		$query = "SELECT * FROM `" . BWB_TABLE_PREFIX . "plugins_deployed` WHERE `plugin_id` = $plugin";
+		$result = $bwb_dbh->query($query);
+		$row = $result->fetch(PDO::FETCH_ASSOC);
+		if ($result->rowCount() > 0)	{
+			$row = $result->fetch(PDO::FETCH_ASSOC);
+			$deployed = $row["deployed"];
+		}
+		else
+			$deployed = 0;
+			
 		// Check template compatibility with plugin.
-		if (strpos($template_name, "top_bottom_left_right") < 0)
+		if (strpos($template_name, "header_footer_top_bottom_left_right") === false)
 		{
-			if ((isset($top_code) && ($top_code != "")) || (isset($top_html) && ($top_html != "")))
+			$need_header = false;
+			$need_footer = false;
+			$need_top = false;
+			$need_left = false;
+			$need_right = false;
+			$need_bottom = false;
+			$need_alt = false;
+			$need_alt2 = false;
+			$dont_want_header = false;
+			$dont_want_footer = false;
+			$dont_want_top = false;
+			$dont_want_left = false;
+			$dont_want_right = false;
+			$dont_want_bottom = false;
+			
+			if ((isset($header_code) && ($header_code != "")) || (isset($header_html) && ($header_html != "")) && (strpos($template_name, "header") === false))
+				$need_header = true;
+			if ((isset($footer_code) && ($footer_code != "")) || (isset($footer_html) && ($footer_html != "")) && (strpos($template_name, "footer") === false))
+				$need_footer = true;
+			if ((isset($top_code) && ($top_code != "")) || (isset($top_html) && ($top_html != "")) && (strpos($template_name, "top") === false))
 				$need_top = true;
-			if ((isset($left_code) && ($left_code != "")) || (isset($left_html) && ($left_html != "")))
+			if ((isset($left_code) && ($left_code != "")) || (isset($left_html) && ($left_html != "")) && (strpos($template_name, "left") === false))
 				$need_left = true;
-			if ((isset($right_code) && ($right_code != "")) || (isset($right_html) && ($right_html != "")))
+			if ((isset($right_code) && ($right_code != "")) || (isset($right_html) && ($right_html != "")) && (strpos($template_name, "right") === false))
 				$need_right = true;
-			if ((isset($bottom_code) && ($bottom_code != "")) || (isset($bottom_html) && ($bottom_html != "")))
+			if ((isset($bottom_code) && ($bottom_code != "")) || (isset($bottom_html) && ($bottom_html != "")) && (strpos($template_name, "bottom") === false))
 				$need_bottom = true;
 				
-			if ($need_top && $need_left && $need_right && $need_bottom && ($template_name != "top_bottom_left_right") && ($template_name != "top_bottom_left_right_alt") && ($template_name != "top_bottom_left_right_alt2"))
-				$template_name = "top_bottom_left_right";
-			elseif ($need_top && $need_left && $need_right && !$need_bottom && ((strpos($template_name, "top") < 0) || (strpos($template_name, "left") < 0) || (strpos($template_name, "right") < 0)))
-				$template_name = "top_left_right";
-			elseif ($need_top && $need_left && !$need_right && $need_bottom && ((strpos($template_name, "top") < 0) || (strpos($template_name, "left") < 0) || (strpos($template_name, "bottom") < 0)))
-				$template_name = "top_bottom_left";
-			elseif ($need_top && !$need_left && $need_right && $need_bottom && ((strpos($template_name, "top") < 0) || (strpos($template_name, "right") < 0) || (strpos($template_name, "right") < 0)))
-				$template_name = "top_bottom_left_right";
-			elseif (!$need_top && $need_left && $need_right && $need_bottom && ((strpos($template_name, "bottom") < 0) || (strpos($template_name, "left") < 0) || (strpos($template_name, "right") < 0)))
-				$template_name = "top_bottom_left_right";
-			elseif ($need_top && $need_left && !$need_right && !$need_bottom && ((strpos($template_name, "top") < 0) || (strpos($template_name, "left") < 0)))
+			if (strpos($template_name, "header") === false)
+				$dont_want_header = true;
+			if (strpos($template_name, "footer") === false)
+				$dont_want_footer = true;
+			if (strpos($template_name, "top") === false)
+				$dont_want_top = true;
+			if (strpos($template_name, "left") === false)
+				$dont_want_left = true;
+			if (strpos($template_name, "right") === false)
+				$dont_want_right = true;
+			if (strpos($template_name, "bottom") === false)
+				$dont_want_bottom = true;
+				
+			if (strpos($template_name, "alt2") !== false)
+				$need_alt2 = true;
+			elseif (strpos($template_name, "alt") !== false)
+				$need_alt = true;
+				
+			if (($need_header === true) || ($need_footer === true) || ($need_top === true) || ($need_left === true) || ($need_right === true) || ($need_bottom === true))
 			{
-				if ($template_name == "top_bottom")
-					$template_name = "top_bottom_left";
-				else
-					$template_name = "top_left";
-			}
-			elseif ($need_top && !$need_left && !$need_right && $need_bottom && ((strpos($template_name, "top") < 0) || (strpos($template_name, "bottom") < 0)))
-			{
-				if ($template_name == "top_left")
-					$template_name = "top_bottom_left";
-				else
-					$template_name = "top_bottom";
-			}
-			elseif (!$need_top && !$need_left && $need_right && $need_bottom && ((strpos($template_name, "right") < 0) || (strpos($template_name, "bottom") < 0)))
-				$template_name = "top_bottom_left_right";
-			elseif (!$need_top && $need_left && $need_right && !$need_bottom && ((strpos($template_name, "right") < 0) || (strpos($template_name, "left") < 0)))
-				$template_name = "top_bottom_left_right";
-			elseif (!$need_top && $need_left && !$need_right && $need_bottom && ((strpos($template_name, "left") < 0) || (strpos($template_name, "bottom") < 0)))
-				$template_name = "top_bottom_left";
-			elseif ($need_top && !$need_left && $need_right && !$need_bottom && ((strpos($template_name, "top") < 0) || (strpos($template_name, "right") < 0)))
-				$template_name = "top_bottom_left";
-			elseif ($need_top && !$need_left && !$need_right && !$need_bottom && (strpos($template_name, "top") < 0))
-			{
-				if ($template_name == "basic")
-					$template_name = "top";
-				else
-					$template_name = "top_left";
-			}
-			elseif (!$need_top && $need_left && !$need_right && !$need_bottom && (strpos($template_name, "left") < 0))
-			{
-				if ($template_name == "basic")
-					$template_name = "left";
-				elseif ($template_name == "top_bottom")
-					$template_name = "top_bottom_left";
-				elseif ($template_name == "top")
-					$template_name = "top_left";
-			}
-			elseif (!$need_top && !$need_left && $need_right && !$need_bottom && (strpos($template_name, "right") < 0))
-			{
-				if ($template_name != "top_bottom")
-					$template_name = "top_left_right";
-				else
-					$template_name = "top_bottom_left_right";
-			}
-			elseif (!$need_top && !$need_left && !$need_right && $need_bottom && (strpos($template_name, "bottom") < 0))
-			{
-				if (($template_name == "top") || ($template_name == "basic"))
-					$template_name = "top_bottom";
-				else
-					$template_name = "top_bottom_left";
+				$where = "";
+				if ($need_header === true)
+					$where .= " AND option_value LIKE '%header%'";
+				elseif (($dont_want_header === true) && ($need_footer !== true))
+					$where .= " AND option_value NOT LIKE '%header%'";
+				if ($need_footer === true)
+					$where .= " AND option_value LIKE '%footer%'";
+				elseif ($dont_want_footer === true)
+					$where .= " AND option_value NOT LIKE '%footer%'";
+				if ($need_top === true)
+					$where .= " AND option_value LIKE '%top%'";
+				elseif (($dont_want_top === true) && ($need_bottom !== true))
+					$where .= " AND option_value NOT LIKE '%top%'";
+				if ($need_left === true)
+					$where .= " AND option_value LIKE '%left%'";
+				elseif (($dont_want_left === true) && ($need_right !== true))
+					$where .= " AND option_value NOT LIKE '%left%'";
+				if ($need_right === true)
+					$where .= " AND option_value LIKE '%right%'";
+				elseif ($dont_want_right === true)
+					$where .= " AND option_value NOT LIKE '%right%'";
+				if ($need_bottom === true)
+					$where .= " AND option_value LIKE '%bottom%'";
+				elseif ($dont_want_bottom === true)
+					$where .= " AND option_value NOT LIKE '%bottom%'";
+					
+				if ($need_alt2 === true)
+					$where .= " AND option_value LIKE '%alt2%'";
+				elseif ($need_alt === true)
+					$where .= " AND option_value LIKE '%alt%' AND NOT LIKE '%alt2%'";
+					
+				$query = "SELECT option_value FROM " . BWB_TABLE_PREFIX . "options WHERE option_name = 'Template'" . $where . " ORDER BY dropdown_sort_order";
+				$result = $bwb_dbh->query($query);
+				$row = $result->fetch(PDO::FETCH_ASSOC);
+				$template_name = $row['option_value'];
 			}
 		}
 	}
 	else
 	{
-		$content_html = "\n<p>" . CREATE_PAGE_DEFAULT_CONTENT . "</p>\n";
+		$content_html = "\n<p>" . CREATE_PAGE_DEFAULT_CONTENT . "</p>\n" . $page_content_divider . "\n";
 		$plugin_id = "";
 		$body_onload = 0;
-		$body_onload_function = $page_name . "_load";
+		$body_onload_function = $page_name . "_load();";
 		$disable_site_styles = 0;
 	}
 	
@@ -407,6 +465,44 @@ function copy_table_structure($table, $table_prefix, $dbh, $database)
 		$row = $result->fetch(PDO::FETCH_ASSOC);
 		$head_content = $row["head_content"];
 		
+		// Adjust path to any JavaScript includes, CSS, images, Flash or media to settings in config file.
+		if ((BWB_BASE_DIR == '') && (BWB_WEBPAGE_DIR == ''))	{
+			$scripts_dir_rel = BWB_SCRIPTS_DIR . "/";
+			$flash_dir_rel = BWB_FLASH_DIR . "/";
+			$media_dir_rel = BWB_MEDIA_DIR . "/";
+			$image_dir_rel = BWB_IMAGE_DIR . "/";
+			$css_dir_rel = BWB_CSS_DIR . "/";
+		}
+		elseif ((BWB_BASE_DIR == '') || (BWB_WEBPAGE_DIR == ''))
+		{
+			if (BWB_BASE_DIR == '')	{
+				$scripts_dir_rel = "../" . BWB_SCRIPTS_DIR . "/";
+				$flash_dir_rel = "../" . BWB_FLASH_DIR . "/";
+				$media_dir_rel = "../" . BWB_MEDIA_DIR . "/";
+				$image_dir_rel = "../" .BWB_IMAGE_DIR . "/";
+				$css_dir_rel = "../" . BWB_CSS_DIR . "/";
+			}
+			elseif (BWB_WEBPAGE_DIR == '')	{
+				$scripts_dir_rel = BWB_SCRIPTS_DIR . "/";
+				$flash_dir_rel = BWB_FLASH_DIR . "/";
+				$media_dir_rel = BWB_MEDIA_DIR . "/";
+				$image_dir_rel = BWB_IMAGE_DIR . "/";
+				$css_dir_rel = BWB_CSS_DIR . "/";
+			}
+		}
+		else	{
+			$scripts_dir_rel = "../" . BWB_SCRIPTS_DIR . "/";
+			$flash_dir_rel = "../" . BWB_FLASH_DIR . "/";
+			$media_dir_rel = "../" . BWB_MEDIA_DIR . "/";
+			$image_dir_rel = "../" .BWB_IMAGE_DIR . "/";
+			$css_dir_rel = "../" . BWB_CSS_DIR . "/";
+		}
+		$head_html = str_replace("scripts/", $scripts_dir_rel, $head_html);
+		$head_html = str_replace("css/", $scripts_dir_rel, $head_html);
+		$head_html = str_replace("images/", $scripts_dir_rel, $head_html);
+		$head_html = str_replace("media/", $scripts_dir_rel, $head_html);
+		$head_html = str_replace("flash/", $scripts_dir_rel, $head_html);
+			
 		// Combine HTML (Javascript) code with default head content.
 		$head_content = $head_content . "\n\n\n" . $head_html;
 		$head_content = addslashes(stripslashes($head_content));
@@ -628,28 +724,46 @@ function copy_table_structure($table, $table_prefix, $dbh, $database)
 				$row = $result->fetch(PDO::FETCH_ASSOC);
 				$sort_order = $row['sort_order'] + 10;
 				
-				$query = "INSERT INTO " . BWB_TABLE_PREFIX . "style_sheets SET `name`='" . $style_sheet . "', `description`='" . $style_sheet_description . "', `sort_order`=" . $sort_order;
+				if (isset($custom_css_sql) && ($custom_css_sql != ""))
+				 	$show_custom_styles = 1;
+				else
+					$show_custom_styles = 0;
+				
+				$query = "INSERT INTO " . BWB_TABLE_PREFIX . "style_sheets SET `name`='" . $style_sheet . "', `description`='" . $style_sheet_description . "', `sort_order`=" . $sort_order . ", `show_custom_styles`='" . $show_custom_styles . "'";
+				$cnt = $bwb_dbh->exec($query);
+				
+				$sort_order = $sort_order + 10;
+				$style_sheet_desc_arr = explode("Styles", $style_sheet_description);
+				if (count($style_sheet_desc_arr) > 1)
+					$mobile_style_sheet_desc = $style_sheet_desc_arr[0] . "Mobile Styles" . $style_sheet_desc_arr[1];
+				else
+					$mobile_style_sheet_desc = $style_sheet_description . " Mobile Styles";
+				$query = "INSERT INTO " . BWB_TABLE_PREFIX . "style_sheets SET `name`='" . $style_sheet . "_mobile', `description`='" . $mobile_style_sheet_desc . "', `sort_order`=" . $sort_order . ", `show_custom_styles`='" . $show_custom_styles . "'";
 				$cnt = $bwb_dbh->exec($query);
 			}
 			
-			$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "plugins WHERE `style_sheet`='" . $style_sheet . "' AND `deployed` = 1";
+			$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "plugins AS T1 INNER JOIN " . BWB_TABLE_PREFIX . "plugins_deployed AS T2 ON T1.id = T2.plugin_id WHERE T1.style_sheet = '" . $style_sheet . "' AND T2.deployed = 1";
 			$result = $bwb_dbh->query($query);
 			if ($result->rowCount() < 1)
 			{
 				if (isset($class_sql) && ($class_sql != ""))
 				{
-					$class_table = $style_sheet . "_classes";
-					$result = copy_table_structure($class_table, BWB_TABLE_PREFIX, $bwb_dbh, $bwb_database);
 					$result = RunSQL($class_sql, $bwb_dbh, BWB_TABLE_PREFIX, false, false, UPLOAD_TEMPLATE_ROWS_AFFECTED_MSG);
 				}
 				
 				if (isset($css_sql) && ($css_sql != ""))
 				{
-					$site_css_table = $style_sheet . "_css";
-					$result = copy_table_structure($site_css_table, BWB_TABLE_PREFIX, $bwb_dbh, $bwb_database);
 					$result = RunSQL($css_sql, $bwb_dbh, BWB_TABLE_PREFIX, false, false, UPLOAD_TEMPLATE_ROWS_AFFECTED_MSG);
-					
-					$css_string = BuildCSSString(BWB_TABLE_PREFIX . $site_css_table, BWB_TABLE_PREFIX . $class_table, $bwb_dbh, BWB_BASE_DIR, BWB_IMAGE_DIR, BWB_TABLE_PREFIX . "fonts");
+				}
+				
+				if (isset($custom_css_sql) && ($custom_css_sql != ""))
+				{
+					$result = RunSQL($custom_css_sql, $bwb_dbh, BWB_TABLE_PREFIX, false, false, UPLOAD_TEMPLATE_ROWS_AFFECTED_MSG);
+				}
+				
+				if ((isset($css_sql) && ($css_sql != "")) || (isset($custom_css_sql) && ($custom_css_sql != "")))
+				{	
+					$css_string = BuildCSSString($style_sheet, $bwb_dbh, BWB_BASE_DIR, BWB_IMAGE_DIR, BWB_TABLE_PREFIX);
 					////////////////////////////////////////////////////////
 					/// Write menu items to menu.css file /////////////
 					//Test to see if file already exists.
@@ -674,6 +788,27 @@ function copy_table_structure($table, $table_prefix, $dbh, $database)
 					$result = (fputs($fh, $css_string));
 					fclose($fh) or die($php_errormsg);
 					@chmod($file_name, 0644);
+					
+					/////////////////////////////////////////////////////
+					// Build mobile style sheet
+					$css_string = BuildCSSString($style_sheet . "_mobile", $bwb_dbh, BWB_BASE_DIR, BWB_IMAGE_DIR, BWB_TABLE_PREFIX);
+					
+					$css_file = $style_sheet . "_mobile.css";
+					$file_name = $document_root . $userfiles . "/" . BWB_CSS_DIR . "/" . $css_file;
+						
+					if (file_exists($file_name))
+					{
+						$bkup_file_name = $file_name . time();
+						if (!rename($file_name, $bkup_file_name))
+							echo EDIT_CSS_COULD_NOT_RENAME_1_ERR . " $file_name " . EDIT_CSS_COULD_NOT_RENAME_2_ERR . " $bkup_file_name.<br>";
+						@chmod($bkup_file_name, 0644);
+					}
+					
+					// Create file.
+					$fh = fopen($file_name, 'x') or die(EDIT_CSS_CANT_CREATE_ERR . " $file_name: $php_errormsg");
+					$result = (fputs($fh, $css_string));
+					fclose($fh) or die($php_errormsg);
+					@chmod($file_name, 0644);
 				}
 			}
 		}
@@ -682,18 +817,22 @@ function copy_table_structure($table, $table_prefix, $dbh, $database)
 			$result = RunSQL($plugin_sql, $bwb_dbh, BWB_TABLE_PREFIX, false, false, UPLOAD_TEMPLATE_ROWS_AFFECTED_MSG);
 		}
 	
-		$query = "UPDATE " . BWB_TABLE_PREFIX . "plugins SET `deployed`=1 WHERE `id`=$plugin";
+		$query = "REPLACE INTO " . BWB_TABLE_PREFIX . "plugins_deployed SET `plugin_id`=$plugin, `deployed`=1";
 		$cnt = $bwb_dbh->exec($query);
 	}	
 	
 	//Go to edit page.
-	$edit_page = "edit_page.php?page_name=$page_name&mode=$mode";
-	if (($plugin != "-not selected-") && ($deployed != 1))
-		$edit_page .= "&refresh_buttons=1";
-	try	{
-		header("Location: $edit_page");
-	} catch (Exception $e) {
-		echo $e->getMessage();
+	if (!isset($no_edit) || ($no_edit != 1))	{
+		$edit_page = "edit_page.php?page_name=$page_name&mode=$mode";
+		if (($plugin != "-not selected-") && ($deployed != 1))
+			$edit_page .= "&refresh_buttons=1";
+		try	{
+			header("Location: $edit_page");
+		} catch (Exception $e) {
+			echo $e->getMessage();
+		}
 	}
+	else
+		echo "Child Plugin Page Created";
 	
 ?>
\ No newline at end of file
