@@ -15,6 +15,9 @@
 // Added 'hover' subclass and fixed subclass descriptions for link set.
 // Revised: 2/13/2015	ELL
 // Added class selector operator handling.
+// Modified: 12/2/2016	ELL
+// Consolidated all class tables into site_classes table indexed by style_sheet field.
+// Consolidated all CSS tables into site_css table indexed by style_sheet field.
 // 
 // 
 // 
@@ -26,14 +29,13 @@
 	$selector_param = $_POST['selector_param'];
 	$create_link_set = $_POST['create_link_set'];
 	$style_sheet = $_REQUEST['style_sheet'];
-	$class_table = $style_sheet . "_classes";
 	
 	$no_op_selectors = array(":link",":hover",":visited",":active","::before","::after",":checked",":disabled",":enabled",":focus",":target","::selection",":read-only",":read-write",":not",":empty","::first-letter","::first-line",":first-child",":last-child",":nth-child",":nth-last-child",":only-child",":first-of-type",":last-of-type",":nth-of-type",":nth-last-of-type",":only-of-type",":in-range",":out-of-range",":valid",":invalid",":lang",":required",":optional",":root");
 	
 	$selectors_w_params = array(":not",":nth-child",":nth-last-child",":nth-of-type",":nth-last-of-type",":lang");
 	
 	//Get descriptions.
-	$query = "SELECT * FROM `" . BWB_TABLE_PREFIX . $class_table . "` WHERE `class` = '$class'";
+	$query = "SELECT * FROM `" . BWB_TABLE_PREFIX . "site_classes` WHERE `style_sheet` = '$style_sheet' AND `class` = '$class'";
 	$result = $bwb_dbh->query($query);
 	$row = $result->fetch(PDO::FETCH_ASSOC);
 	$class_description = $row["description"];
@@ -44,7 +46,7 @@
 		$subclass_description = 'A:Link';
 	}
 	elseif (!in_array($subclass, $no_op_selectors))	{
-		$query = "SELECT * FROM `" . BWB_TABLE_PREFIX . $class_table . "` WHERE `class` = '$subclass'";
+		$query = "SELECT * FROM `" . BWB_TABLE_PREFIX . "site_classes` WHERE `style_sheet` = '$style_sheet' AND `class` = '$subclass'";
 		$result = $bwb_dbh->query($query);
 		$row = $result->fetch(PDO::FETCH_ASSOC);
 		$subclass_description = $row["description"];
@@ -96,7 +98,7 @@
 	$_SESSION['last_class_edited'] = $class_str;
 	
 	// Add relationship to database.
-	$query = "INSERT INTO `" . BWB_TABLE_PREFIX . $class_table . "` SET `class` = '$class_subclass', `description` = '$description', `sort_order` = $sort_order, `subclass_sort_order` = 500, `custom` = 1";
+	$query = "INSERT INTO `" . BWB_TABLE_PREFIX . "site_classes` SET `style_sheet` = '$style_sheet', `class` = '$class_subclass', `description` = '$description', `sort_order` = $sort_order, `subclass_sort_order` = 500, `custom` = 1";
 	$cnt = $bwb_dbh->exec($query);
 	
 	if (isset($create_link_set))
@@ -113,7 +115,7 @@
 		$class_str = str_replace($search, $replace, $class_subclass);
 		
 		// Add relationship to database.
-		$query = "INSERT INTO `" . BWB_TABLE_PREFIX . $class_table . "` SET `class` = '$class_subclass', `description` = '$description', `sort_order` = $sort_order, `subclass_sort_order` = 500, `custom` = 1";
+		$query = "INSERT INTO `" . BWB_TABLE_PREFIX . "site_classes` SET `style_sheet` = '$style_sheet', `class` = '$class_subclass', `description` = '$description', `sort_order` = $sort_order, `subclass_sort_order` = 500, `custom` = 1";
 		$cnt = $bwb_dbh->exec($query);
 		
 		//......................................
@@ -129,7 +131,7 @@
 		$class_str = str_replace($search, $replace, $class_subclass);
 		
 		// Add relationship to database.
-		$query = "INSERT INTO `" . BWB_TABLE_PREFIX . $class_table . "` SET `class` = '$class_subclass', `description` = '$description', `sort_order` = $sort_order, `subclass_sort_order` = 500, `custom` = 1";
+		$query = "INSERT INTO `" . BWB_TABLE_PREFIX . "site_classes` SET `style_sheet` = '$style_sheet', `class` = '$class_subclass', `description` = '$description', `sort_order` = $sort_order, `subclass_sort_order` = 500, `custom` = 1";
 		$cnt = $bwb_dbh->exec($query);
 		
 		//......................................
@@ -145,7 +147,7 @@
 		$class_str = str_replace($search, $replace, $class_subclass);
 		
 		// Add relationship to database.
-		$query = "INSERT INTO `" . BWB_TABLE_PREFIX . $class_table . "` SET `class` = '$class_subclass', `description` = '$description', `sort_order` = $sort_order, `subclass_sort_order` = 500, `custom` = 1";
+		$query = "INSERT INTO `" . BWB_TABLE_PREFIX . "site_classes` SET `style_sheet` = '$style_sheet', `class` = '$class_subclass', `description` = '$description', `sort_order` = $sort_order, `subclass_sort_order` = 500, `custom` = 1";
 		$cnt = $bwb_dbh->exec($query);
 	}
 	
