@@ -13,6 +13,9 @@
 // though you cannot edit it.
 // Revised: 2/8/2012	ELL
 // Added table prefix handling.
+// Modified: 12/2/2016	ELL
+// Consolidated all class tables into site_classes table indexed by style_sheet field.
+// Consolidated all CSS tables into site_css table indexed by style_sheet field.
 //
 	include ("check_session.php");
 	include("lib/build_css_string.php");
@@ -22,20 +25,18 @@
 	$replace = array(".", "#", " ", ",", ">", "&gt;", "+", "~");
 	$class = str_replace($search, $replace, $class);
 	$style_sheet = $_REQUEST['style_sheet'];
-	$class_table = $style_sheet . "_classes";
-	$css_table = $style_sheet . "_css";
 	$css_file =  $style_sheet . ".css";
 	
 	// Go ahead and delete tag from class table.
-	$query = "DELETE FROM `" . BWB_TABLE_PREFIX . $class_table . "` WHERE `class` = '$class'";
+	$query = "DELETE FROM `" . BWB_TABLE_PREFIX . "site_classes` WHERE `style_sheet` = '$style_sheet' AND `class` = '$class'";
 	$cnt = $bwb_dbh->exec($query);
 	
 	// Also remove tag from tag from css table.
-	$query = "DELETE FROM `" . BWB_TABLE_PREFIX . $css_table . "` WHERE `class` = '$class'";
+	$query = "DELETE FROM `" . BWB_TABLE_PREFIX . "site_css` WHERE `style_sheet` = '$style_sheet' AND `class` = '$class'";
 	$cnt = $bwb_dbh->exec($query);
 	
 	// Build new CSS string without deleted class.
-	$css_string = BuildCSSString(BWB_TABLE_PREFIX . $css_table, BWB_TABLE_PREFIX . $class_table, $bwb_dbh, BWB_BASE_DIR, BWB_IMAGE_DIR, BWB_TABLE_PREFIX . "fonts");
+	$css_string = BuildCSSString($style_sheet, $bwb_dbh, BWB_BASE_DIR, BWB_IMAGE_DIR, BWB_TABLE_PREFIX);
 	
 	////////////////////////////////////////////////////////
 	/// Write new css file /////////////
@@ -85,4 +86,4 @@
 	
 	echo 1;
 	
-?>
+?>
\ No newline at end of file
