@@ -3,17 +3,22 @@
 // Breeze Website Builder
 // Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
 // For licensing, see license.txt.
-// Revised: 5/11/2015	ELL
+// Created: 5/11/2015	ELL
+// Revised: 3/29/2017	ELL
+// Added include of write_custom_font_css.php to move creation of font CSS from editing style sheets to adding/deleting custom fonts.
 // 
 // 
 // 
 	include ("check_session.php");
 
 	$font = $_POST['font'];
-	$src = $_POST['src'];
+	$src = stripslashes($_POST['src']);
+	$src2 = "'" . $src . "'";
+	$src2 = addslashes($src2);
+	$src = addslashes($src);
 	
 	// Delete font from database.
-	$query = "DELETE FROM `" . BWB_TABLE_PREFIX . "fonts` WHERE (`font` = '$font') AND (`src` = '$src')";
+	$query = "DELETE FROM `" . BWB_TABLE_PREFIX . "fonts` WHERE (`font` = '$font') AND ((`src` = '$src') OR (`src` = '$src2'))";
 	$cnt = $bwb_dbh->exec($query);
 	
 	$document_root = $_SERVER['DOCUMENT_ROOT'];
@@ -29,5 +34,8 @@
 	if ((isset($src_file)) && ($src_file != "") && (substr($src, 0, 4) != "http"))
 		unlink($src_file);
 	
+	// Create cust font CSS file.
+	include("write_custom_font_css.php");
+	
 	echo 1;
 ?>
