@@ -45,12 +45,15 @@
 	echo "	var DELETE_PAGE_OR_BLOG_DELETE_PAGE_CONFIRM_2_MSG = \"" . DELETE_PAGE_OR_BLOG_DELETE_PAGE_CONFIRM_2_MSG . "\";\n";
 	echo "	var DELETE_PAGE_OR_BLOG_RECALL_PLUGIN_CONFIRM_1_MSG = \"" . DELETE_PAGE_OR_BLOG_RECALL_PLUGIN_CONFIRM_1_MSG . "\";\n";
 	echo "	var DELETE_PAGE_OR_BLOG_RECALL_PLUGIN_CONFIRM_2_MSG = \"" . DELETE_PAGE_OR_BLOG_RECALL_PLUGIN_CONFIRM_2_MSG . "\";\n";
+	
+	echo "	var BWB_BASE_DIR = \"" . BWB_BASE_DIR . "\";\n";
+	echo "	var BWB_WEBPAGE_DIR = \"" . BWB_WEBPAGE_DIR . "\";\n";
 ?>
 </script>
 </head>
 
 <body>
-<div class="button_heading_sub_level_1" id="delete_page_blog_heading"><div class="button_heading_text_sub_level_1"><?php echo DELETE_PAGE_OR_BLOG_HEADING; ?></div><div class="help_button" id="help_button" onclick="OpenHelpWindow();">&nbsp;</div></div>
+<div class="button_heading_sub_level_1" id="delete_page_blog_heading"><div class="button_heading_text_sub_level_1"><?php echo DELETE_PAGE_OR_BLOG_HEADING; ?></div><div class="help_button" id="help_button" onClick="OpenHelpWindow();">&nbsp;</div></div>
 
 <div id="delete_page">
 	  <table align="center" border="0" width="80%"><tr><td>
@@ -118,7 +121,7 @@
   <?php include("lib/popup_msg.html"); ?>
       
 <script language="JavaScript"  type="text/javascript">
-HidePopupMsg();
+	popup_msg.HidePopupMsg();
 </script>
 </body>
 </html>
\ No newline at end of file
