@@ -7,7 +7,15 @@
 // Modified: 3/18/2013	ELL
 // Modified: 3/22/2014	ELL
 // Added graceful handling of allow_url_fopen not set.
+// Modified: 12/13/2016	ELL
+// Added auto-login and auto-cleanup.
 
+session_start();
+$userid = "admin";
+$_SESSION['userid'] = $userid;
+$session = md5(session_id());
+$_SESSION['enable_file_manager'] = "100";
+	
 ini_set("track_errors", 1);
 
 $db_server = $_POST["db_server"];
@@ -27,6 +35,10 @@ if ((isset($db_prefix)) && ($db_prefix != ""))	{
 }
 
 $table_prefix = $_POST["table_prefix"];
+if ((isset($table_prefix)) && ($table_prefix != ""))	{
+	if (strpos($table_prefix, "_", 2) < 1)
+		$table_prefix .= "_";
+}
 $base_website_folder = $_POST["base_website_folder"];
 $files = $_POST["files"];
 $images = $_POST["images"];
@@ -161,8 +173,8 @@ function ChangePassword($user_name, $salted_password, $password, $email, $first_
 }
 
 ?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
-<html xmlns="http://www.w3.org/1999/xhtml">
+<!DOCTYPE html>
+<html>
 <head>
 <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
 <title>Breeze Website Builder Install</title>
@@ -263,9 +275,9 @@ $contents = str_replace("define('BWB_TABLE_PREFIX', 'bwb_');", "define('BWB_TABL
 $contents = str_replace("define('BWB_REQUIRE_SSL', 0);", "define('BWB_REQUIRE_SSL', '" . $require_ssl . "');", $contents);
 $contents = str_replace("define('BWB_SALT', '!oegTGFhFD87@');", "define('BWB_SALT', '" . $user_salt . "');", $contents);
 $contents = str_replace("define('BWB_PUB_SALT', '#uePYd%3f78C');", "define('BWB_PUB_SALT', '" . $public_salt . "');", $contents);
-$contents = str_replace("define('BWB_SN', '255.255.255.255-1';", "define('BWB_SN', '" . $sn . "');", $contents);
-$contents = str_replace("define('SESSION_SAVE_PATH', '/tmp';", "define('SESSION_SAVE_PATH', '" . $session_save_path . "');", $contents);
-$contents = str_replace("define('BWB_LANG', 'en';", "define('BWB_LANG', '" . $language . "');", $contents);
+$contents = str_replace("define('BWB_SN', '255.255.255.255-1');", "define('BWB_SN', '" . $sn . "');", $contents);
+$contents = str_replace("define('SESSION_SAVE_PATH', '/tmp');", "define('SESSION_SAVE_PATH', '" . $session_save_path . "');", $contents);
+$contents = str_replace("define('BWB_LANG', 'en');", "define('BWB_LANG', '" . $language . "');", $contents);
 
 if (!($fh4 = fopen($config_file, 'w'))) {
 	echo "Error opening config file.  Please contact your system administrator.  Click <a href=\"install.php\" title=\"here\">here</a> to return to the installation start.\n$php_errormsg";
@@ -319,9 +331,33 @@ include ("run_sql_install.php");
 	ChangePassword("user", $salted_pass, $password, $email, $first_name, $last_name, BWB_TABLE_PREFIX, $bwb_dbh);
 	ChangePassword("restricted", $salted_pass, $password, $email, $first_name, $last_name, BWB_TABLE_PREFIX, $bwb_dbh);
 	ChangePassword("blogger", $salted_pass, $password, $email, $first_name, $last_name, BWB_TABLE_PREFIX, $bwb_dbh);
+	
+	$ip = $_SERVER['REMOTE_ADDR'];
+	$query = "UPDATE `" . BWB_TABLE_PREFIX . "users` SET `Session`='$session', `IP`='$ip' WHERE `UserID` = :userid";
+	$stmt = $bwb_dbh->prepare($query);
+	$stmt->execute(array(':userid' => $userid));	
 ?>
-<p><b>Installation complete.</b>  Click here <a href="../manage/"><span id="login_btn">Log into Breeze Website Builder</span></a> to login and start using the Breeze Website Builder&#8482;. Use <em>admin</em> for the username and the password you entered to log in. You may create other user accounts after logging in. For security purposes, delete the <b>install</b> folder and <b>SQL</b> folder immediately.</p>
+<p><b>Installation complete.</b>  Click here <a href="finish_install.php"><span id="login_btn">Log into Breeze Website Builder</span></a> to login and start using the Breeze Website Builder&#8482;. You will be logged is as <em>admin</em> automatically the first time.  Bookmark that page and use <em>admin</em> for the username and the password you entered to log in at a later time. You may create other user accounts after logging in.</p>
 <p>Thanks for using the Breeze Website Builder&#8482;!</p>
 </div>
+<script>
+	var bottom = document.body.scrollHeight;
+	var from_height = 0;
+	var step = parseInt(bottom/100);
+	var to_height = 0;
+	var code = "AnimateScroll();";
+	
+	function AnimateScroll()
+	{
+		if (to_height < bottom)
+		{
+			to_height = to_height + step;
+			window.scrollTo(from_height, to_height);
+			setTimeout(code, 10);
+			from_height = to_height;
+		}
+	}
+	AnimateScroll();
+</script>
 </body>
 </html>
\ No newline at end of file
