@@ -24,6 +24,8 @@
 // Updated CKEditor from version 4.4.5 to version 4.4.6.
 // Revised:	2/2/2012	ELL
 // Fixed bug with "See Site" button not updating to new file after "Save As".
+// Rezised: 4/28/2016	ELL
+// Added ability to use either desktop styles or mobile styles.
 
 
 	include ("check_session.php");
@@ -34,6 +36,7 @@
 	$page_name = $_REQUEST['page_name'];
 	$blog_id = $_REQUEST['blog_id'];
 	$special = $_REQUEST['special'];	//Flag to tell if editing special page (header, footer, side panel...).
+	$source = $_REQUEST['source'];
 	if ($mode == "blog")
 	{
 		$_SESSION['last_blog_edited'] = $blog_id;
@@ -44,7 +47,11 @@
 			$result = $bwb_dbh->query($query);
 			$row = $result->fetch(PDO::FETCH_ASSOC);
 			$page_name = $row['page_name'];
+			$blog_revised = $row['revised'];
 		}
+		else
+			$blog_revised = date("Y-m-d");
+			
 		$_SESSION['last_page_edited'] = $page_name;
 		$special = 0;
 	}
@@ -188,6 +195,9 @@
 	echo "	var NO_WORD = \"" . NO_WORD . "\";\n";
 	echo "	var OK_WORD = \"" . OK_WORD . "\";\n";
 	echo "	var CANCEL_WORD = \"" . CANCEL_WORD . "\";\n";
+	
+	echo "	var BWB_BASE_DIR = \"" . BWB_BASE_DIR . "\";\n";
+	echo "	var BWB_WEBPAGE_DIR = \"" . BWB_WEBPAGE_DIR . "\";\n";
 ?>
 </script>
 
@@ -210,7 +220,28 @@
 	if ($disable_site_styles != 1)
 	{
 		echo "			contentsCss : [";
-		$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "style_sheets";
+									   
+		if (isset($_SESSION['style_mode']) && ($_SESSION['style_mode'] == 1))
+		{
+			$where = " WHERE";
+			$where_clause = "";
+			$and = "";
+			$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "style_sheets";
+			$query2 = "SELECT * FROM " . BWB_TABLE_PREFIX . "style_sheets WHERE `name` LIKE '%_mobile%' ORDER BY sort_order";
+			$result = $bwb_dbh->query($query2);
+			while ($row = $result->fetch(PDO::FETCH_ASSOC))
+			{
+				$name = $row["name"];
+				$name = str_replace("_mobile", "", $name);
+				$where_clause .= $where . $and . " (`name` <> '" . $name . "')";
+				$and = " AND";
+				$where = "";
+			}
+			$query .= $where_clause . " ORDER BY sort_order";
+		}
+		else
+			$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "style_sheets WHERE `name` NOT LIKE '%_mobile%' ORDER BY sort_order";
+		
 		$result = $bwb_dbh->query($query);
 		$delim = "";
 		while ($row = $result->fetch(PDO::FETCH_ASSOC))
@@ -303,7 +334,7 @@
 		var bwb_ckeditor = CKEDITOR.instances['editorContainer'];
 		
 		function somethingChanged()	{
-			if ( bwb_ckeditor.checkDirty() )
+			if ( bwb_ckeditor.checkDirty() && !lockoutChangeCheck )
 			{
 				saved = false;
 				window.parent.SetWorkSavedNotSaved(saved);
@@ -317,7 +348,7 @@
 		}
 
 		function somethingHappened(e)	{
-			if ( bwb_ckeditor.checkDirty() )
+			if ( bwb_ckeditor.checkDirty() && !lockoutChangeCheck )
 				window.parent.SetWorkSavedNotSaved(true);
 				
 			if (e.data.name == "newpage")
@@ -344,8 +375,6 @@
 			}
 		}
 		
-//		LoadPage();
-		
 		bwb_ckeditor.on( 'saveSnapshot', function(e) { somethingChanged(); });
 		bwb_ckeditor.on( 'beforeCommandExec', function(e) { somethingHappened(e); });
 		
@@ -355,11 +384,13 @@
       
 	  <table width="100%" align="center" id="btn_table"><tr>
 	  <td align="left" class="medium_message" width="9%">
-      <?php echo EDITOR_PAGE_NAME; ?>:<br/><span id="page_name_label"><?php echo $page_name; ?></span>
+      <?php echo EDITOR_PAGE_NAME; ?>:<br/><span id="page_name_label"><?php echo $page_name; if ($mode == "blog") echo " $blog_revised"; ?></span>
 	  </td>
+<?php if ($mode != "mega_menu")	{	?>
       <td align="center" style="min-width:90px;">
       <div class='button_console_preview_sm' style="min-width:90px;" onClick="Preview('<?php echo $page_name; ?>', 0);"><span class='button_console_text_w_sm_icon'><?php echo EDITOR_PREVIEW; ?></span></div>
 	  </td>
+<?php }	?>
       <td align="center" style="min-width:80px;">
       <div class='button_console_save_sm' style="min-width:80px;" onClick="Save('save_draft');"><span class='button_console_text_w_sm_icon'><?php echo EDITOR_SAVE; ?></span></div>
 	  </td>
@@ -408,6 +439,9 @@
 <?php if ($access_level != "restricted") { ?>
       <div class='button_console_edit_sm' style="min-width:115px;" onClick="window.open('edit_css.php?style_sheet=site','_blank');"><span class='button_console_text_w_sm_icon'><?php echo EDITOR_EDIT_STYLES; ?></span></div>
 <?php } else echo "&nbsp;"; ?>
+      </td>
+      <td align="center" style="min-width:125px;">
+      <div class='button_console_back_sm' style="min-width:125px;" onClick="window.location='<?php echo $source; ?>';"><span class='button_console_text_w_sm_icon'><?php echo EDITOR_BACK_TO_SELECT; ?></span></div>
       </td>
       <td width="1%">&nbsp;</td>
       <td align="center" width="2%">
@@ -423,7 +457,7 @@
 <?php include("lib/popup_msg.html"); ?>
 
 <script language="javascript" type="text/javascript">
-	HidePopupMsg();
+	popup_msg.HidePopupMsg();
 	
 <?php 
 	if ($refresh_buttons)	{
@@ -431,8 +465,6 @@
 	}
 ?>
 	mTimer3 = setTimeout("LoadPage();", 2000);
-	mTimer = setTimeout("bwb_ckeditor.commands.save.disable(); saved = true; window.parent.SetWorkSavedNotSaved(true);", 4000);
-	mTimerCheckDirty = setInterval("somethingChanged();", 8000);
 	
 	if (document.body.scrollWidth > document.body.clientWidth)
 		CKEDITOR.config.height = CKEDITOR.config.height - 40;
