@@ -9,6 +9,13 @@
 // without modification.
 error_reporting (E_ALL ^ E_NOTICE);
 
+if ((isset($_FILES)) && (count($_FILES) > 0) && ($_FILES["upload_file"]["name"] != ""))	{
+	ini_set('max_execution_time', 21600);
+	set_time_limit(21600);
+	ini_set('memory_limit','512M');
+	ini_set('post_max_size','128M');
+}
+
 // Modify the line below for your particular website.  This will eliminate attacks from remote servers.
 //$referers = array('www.example.com', 'example.com');
 $server_name = $_SERVER['SERVER_NAME'];
@@ -33,7 +40,7 @@ if ($_POST['alt_go_back'])
 	{
 		if (!in_array($key, $ignore_fields) || ($key == "redirect") || ($key == "redirect2") || ($key == "redirect3"))
 		{
-			if ((strpos($key, "password") === false) && (isset($val) && ($val != "")))
+			if ((isset($val) && ($val != "")))
 			{
 				$go_back .= $delim . $key . "=" . $val;
 				$delim = "&";
@@ -97,18 +104,18 @@ if ($_POST['html'])
 	$html = 1;	// html
 else
 	$html = 0;	// text
-if (($_POST['no_mime']) || ((isset($_FILES)) && (count($_FILES) > 0) && ($_FILES["upload_file"]["name"] != "")))
+if ($_POST['no_mime'])
 	$no_mime = 1;	// Certain servers can't handle mime messages such as GoDaddy hosting.
 else
 	$no_mime = 0;
-if (($_POST['octet_stream']) || ((isset($_FILES)) && (count($_FILES) > 0) && ($_FILES["upload_file"]["name"] != "")))
-	$octet_stream = 1;	// If adding attachments, then it might be necessary to set the content type to application/octet-stream.
-else
-	$octet_stream = 0;
 if ($_POST['html_msg_as_text'])
 	$html_msg_as_text = 1;	// Override to send HTML message to form user as text instead.
 else
 	$html_msg_as_text = 0;
+$attachment_application = $_POST['attachment_application'];
+$charset = $_POST['charset'];
+$encode_type = $_POST['encode_type'];
+$transfer_encoding = $_POST['transfer_encoding'];
 	
 // Special flag to denote that 'email' is a required field.  If 'email' is required here, 'email_confirm'
 // will also be required.  If you do not need email confirm, then add "email" to the 'required_fields'
@@ -332,8 +339,9 @@ foreach ( $msg as $key => $value )
 	{
 		if (!CheckPhoneField($value))
 		{
-			header("Location: $redirect");
-			exit;
+			$err_code = "bad_phone&field=$key";
+			$err_msg = "The phone number $value is not a valid phone number.  Please go back and type your phone number again.";
+			DisplayError($redirect_err_to_src, $err_msg, $err_code, $go_back);
 		}
 	}
 	
@@ -347,78 +355,141 @@ else
 	$msg = "$subject$lf" . $msg;
 
 /////////// Check for robots by counting URLs. ////////////////////
-$http_cnt = 0;
-$pos = stripos($msg, "http");
-if ($pos !== false)
+if (isset($_POST['max_url']) && ($_POST['max_url'] > -1))
 {
-	$http_cnt++;
-	$pos2 = stripos($msg, "http", $pos + 1);
-	if ($pos2 !== false)
+	$http_cnt = 0;
+	$pos = stripos($msg, "http");
+	if ($pos !== false)
+	{
 		$http_cnt++;
-}
-if ($http_cnt > 1)
-{
-	header("Location: $redirect");
-	exit;
+		$pos2 = stripos($msg, "http", $pos + 1);
+		if ($pos2 !== false)
+			$http_cnt++;
+	}
+	if ($http_cnt >= $_POST['max_url'])
+	{
+		if (isset($redirect) && ($redirect != ""))
+			header("Location: $redirect");
+		exit;
+	}
 }
 /////////// Check for robots by counting URLs. ////////////////////
 
 // If attachements, then get files onto server.
-if (isset($_FILES))	{;
-	$bad_file_ext = array("php", "PHP", "htm", "html", "js", "asp", "exe", "cf", "jsp", "sh");
+if (isset($_FILES))	{
+	$bad_file_ext = array("php", "htm", "html", "js", "asp", "exe", "cf", "jsp", "sh");
+	if (isset($_POST['allowed_file_ext']))	{
+		$_POST['allowed_file_ext'] = str_replace(array(".", " "), "", $_POST['allowed_file_ext']);
+		$allowed_file_ext = explode(",", $_POST['allowed_file_ext']);
+	}
+	//////////////////////////////////////////////////////
+	if ((isset($_POST['image_width']) && ($_POST['image_width'] != "")) || (isset($_POST['image_height']) && ($_POST['image_height'] != "")))	{
+		include("image_processing.php");
+		$process_images = true;
+		$image_ext = array("jpg", "gif", "png", "jpeg");
+		if (isset($_POST['image_width']) && ($_POST['image_width'] != ""))
+			$max_width = $_POST['image_width'];
+		else
+			$max_width = 1000000;
+		if (isset($_POST['image_height']) && ($_POST['image_height'] != ""))
+			$max_height = $_POST['image_height'];
+		else
+			$max_height = 1000000;
+		if (isset($_POST['preserve_aspect_ratio']) && ($_POST['preserve_aspect_ratio'] != ""))
+			$preserve_aspect_ratio = $_POST['preserve_aspect_ratio'];
+		else
+			$preserve_aspect_ratio = 1;
+	}
+	//////////////////////////////////////////////////////
+	
 	foreach($_FILES as $file_key => $file)	{
 		if (basename($file["name"] == ""))	{
-			// If not file was selected, can't upload it. Unset files and get out of here.
-			unset($_FILES);
-			break;
+			// If no file was selected, can't upload it. Unset files and get out of here.
+			if (count($_FILES) < 2)	{
+				unset($_FILES);
+				break;
+			}
+			else
+				unset($_FILES[$file_key]);
+				continue;
 		}
-		$_POST[$file_key] = $file["name"];
-		$target_dir = "uploads";
+		$_POST[$file_key] = basename($file["name"]);
+
+		if (isset($_POST["uploads_dir"]) && ($_POST["uploads_dir"] != ""))
+			$uploads_dir = "../" . $_POST["uploads_dir"];
+		else
+			$uploads_dir = "../uploads";
+		$target_dir = $uploads_dir;
+		
 		if (!file_exists($target_dir))
 			mkdir($target_dir);
 		$target_file = $target_dir . "/" . basename($file["name"]);
+		// Allow certain file formats
+		$file_parts = explode(".", $target_file);
+		$ext = $file_parts[count($file_parts) - 1];
+		if ((in_array(strtolower($ext), $bad_file_ext)) || (isset($allowed_file_ext) && !in_array(strtolower($ext), $allowed_file_ext)))	{
+			$err_code = "file_type";
+			$err_msg = "The file you are trying to send is of a type that is not allowed to be be emailed.  Please select a different file.";
+			DisplayError($redirect_err_to_src, $err_msg, $err_code, $go_back);
+		}
 		// Check if file already exists
-		if (file_exists($target_file))
-			unlink($target_file);
+		if (file_exists($target_file))	{
+			$NUM = time();		
+			$target_file = str_replace("." . $ext, "", basename($file["name"]));
+			$target_file .= "_" . $NUM . "." .  $ext;
+			$_POST[$file_key] = $target_file;
+			$target_file = $target_dir . "/" . $target_file;
+		}
 		// Check file size
 		if ($file["size"] > 50000000) {
 			$err_code = "file_size";
 			$err_msg = "The file you are trying to send is too large for email.  Please select a different file.";
 			DisplayError($redirect_err_to_src, $err_msg, $err_code, $go_back);
 		}
-		// Allow certain file formats
-		$file_parts = explode(".", $target_file);
-		$ext = $file_parts[count($file_parts) - 1];
-		if (in_array($ext, $bad_file_ext))	{
-			$err_code = "file_type";
-			$err_msg = "The file you are trying to send is of a type that is not allowed to be be emailed.  Please select a different file.";
-			DisplayError($redirect_err_to_src, $err_msg, $err_code, $go_back);
-		}
 		// if everything is ok, try to upload file
 		if (!move_uploaded_file($file["tmp_name"], $target_file)) {
 			$err_code = "upload";
 			$err_msg = "There was an error uploading your file.  Please try again.";
 			DisplayError($redirect_err_to_src, $err_msg, $err_code, $go_back);
 		}
+		///////////////////////////////////////////
+		if (($process_images === true) && in_array(strtolower($ext), $image_ext))	{
+			if (resize_image($target_file, $max_width, $max_height, $target_file, 1, $preserve_aspect_ratio) != 1)	{
+				$err_code = "img_resize";
+				$err_msg = "There was an error resizing your image.  Please try again.";
+				DisplayError($redirect_err_to_src, $err_msg, $err_code, $go_back);
+			}
+		}
+		///////////////////////////////////////////
 	}
 }
 
 $mail->from = $from_email;
 $mail->to = $to_email;
 $mail->cc = $cc_email;
-$mail->replyto = $reply_to;
+if (isset($_POST['set_reply_to_as_email']) && ($_POST['set_reply_to_as_email'] == 1) && isset($email) && ($email != ""))
+	$mail->replyto = $email;
+else
+	$mail->replyto = $reply_to;
 $mail->subject = $subject;
 $mail->body = $msg;
 $mail->html = $html;
 $mail->no_mime = $no_mime;
-$mail->octet_stream = $octet_stream;
-if (isset($_FILES))	{
+if (isset($_FILES) && ($_POST["store_uploads_instead"] < 1))	{
 	$i = 0;
 	foreach($_FILES as $file)	{
-		$mail->attachment[$i] = "uploads/" . $file["name"];
+		$mail->attachment[$i] = $uploads_dir . "/" . $file["name"];
 		$i++;
 	}
 }
+if (isset($attachment_application) && ($attachment_application != ""))
+	$mail->attachment_application = $attachment_application;
+if (isset($charset) && ($charset != ""))
+	$mail->charset = $charset;
+if (isset($encode_type) && ($encode_type != ""))
+	$mail->encode_type = $encode_type;
+if (isset($transfer_encoding) && ($transfer_encoding != ""))
+	$mail->transfer_encoding = $transfer_encoding;
 
 $mail->send();
 
@@ -478,7 +549,6 @@ if (isset($table_name) && ($table_name != ""))
 						$query .= "`" . $key . "[" . $k . "]` varchar(255) default NULL, ";
 				}
 			}
-			
 		}
 		// Add created field.
 		$query .= "`created` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP, ";
@@ -616,8 +686,13 @@ if (isset($table_name) && ($table_name != ""))
 	
 			if ((!is_array($value)) && (!is_object($value)))	{
 				if (!$first) $query .= ", "; else $first = false;
-				if (strpos($value, "'") !== false)
-					$value = addslashes($value);
+				if (strpos($value, "'") !== false)	{
+					// Optionally, replace all single quotes with HTLM ampersand code.
+					if (isset($_POST['replace_single_quotes']) && ($_POST['replace_single_quotes'] > 0))
+						$value = str_replace("'", "&#39;", $value);
+					else
+						$value = addslashes($value);
+				}
 				$query .= "`$key` = '$value'";
 			}
 			else	{
@@ -764,24 +839,31 @@ if (isset($html_message_page) && ($html_message_page != ""))
 		$mail->to = $email;
 		$mail->replyto = $reply_to;
 		$mail->subject = $subject;
-		$mail->body = $html_msg;
-		if ($html_msg_as_text == 1)
+		if ($html_msg_as_text == 1)	{
 			$mail->html = 0;
-		else
+			$mail->body = strip_tags($html_msg);
+		}
+		else	{
 			$mail->html = 1;
+			$mail->body = $html_msg;
+		}
 		$mail->no_mime = $no_mime;
-		$mail->octet_stream = $octet_stream;
 		
 		$mail->send();
 		
-//		$email_ext = substr($email, strlen($email) - 8);
-//		if ($email_ext == "@aol.com")	// AOL emails
-//			mail($email, $subject, $html_msg);
+		if (isset($attachment_application) && ($attachment_application != ""))
+			$mail->attachment_application = $attachment_application;
+		if (isset($charset) && ($charset != ""))
+			$mail->charset = $charset;
+		if (isset($encode_type) && ($encode_type != ""))
+			$mail->encode_type = $encode_type;
+		if (isset($transfer_encoding) && ($transfer_encoding != ""))
+			$mail->transfer_encoding = $transfer_encoding;
 	}
 }
 
 // If attachements sent, then delete them off of server.
-if (isset($_FILES))	{
+if (isset($_FILES) && ($_POST["store_uploads_instead"] < 1))	{
 	foreach($_FILES as $file)	{
 		$target_file = $target_dir . "/" . basename($file["name"]);
 		if (file_exists($target_file)) {
@@ -792,16 +874,19 @@ if (isset($_FILES))	{
 
 /////////////////////////////////////////////////////////////////////////
 // If data stored in table, then pass along last id to next page.
-if (isset($table_name) && ($table_name != ""))
+if (isset($redirect) && ($redirect != ""))
 {
-	if (strpos($redirect, "?") > 0)
-		$redirect .= "&last_id=" . $last_id;
-	else
-		$redirect .= "?last_id=" . $last_id;
+	if (isset($table_name) && ($table_name != ""))
+	{
+		if (strpos($redirect, "?") > 0)
+			$redirect .= "&last_id=" . $last_id;
+		else
+			$redirect .= "?last_id=" . $last_id;
+	}
+		
+	// Go to desired next page.
+	header("Location: $redirect");
 }
-	
-// Go to desired next page.
-header("Location: $redirect");
 exit;
 
 /////////////////////////////////////////////////////////////////////////
@@ -833,7 +918,7 @@ function check_referer($referers)
 					$found = true;
 			}
 			if (!$found) {
-				$errors[] = '1|You are coming from an unauthorized domain.  Please read the manual section titled &quot;<a href="' . MANUAL . '#setting_up" target="_blank">Setting Up the PHPFormMail Script</a>&quot;.';
+				$errors[] = '1|You are coming from an unauthorized domain.';
 				error_log('[PHPFormMail] Illegal Referer. (' . getenv('HTTP_REFERER') . ')', 0);
 			}
 			return $found;
@@ -843,7 +928,7 @@ function check_referer($referers)
 			return false;
 		}
 	} else {
-		$errors[] = '1|There are no referers defined.  All submissions will be denied.  Please read the manual section titled &quot;<a href="' . MANUAL . '#setting_up" target="_blank">Setting Up the PHPFormMail Script</a>&quot;.';
+		$errors[] = '1|There are no referers defined.  All submissions will be denied.';
 		error_log('[PHPFormMail] You have no referers defined.  All submissions will be denied.', 0);
 		return false;
 	}
