@@ -37,4 +37,38 @@ function GeneratePassword()
 function rand ( n, m )
 {
   return ( n + Math.floor ( Math.random ( ) * (m - n + 1)) );
+}
+
+function convertType(elem)
+{
+	var input = document.createElement('input');
+	input.id = elem.id;
+	input.value = elem.value;
+	input.onfocus = elem.onfocus;
+	input.onblur = elem.onblur;
+	input.className = elem.className;
+	if (elem.type == 'text' )
+	  { input.type = 'password'; }
+	else
+	  { input.type = 'text'; }
+	
+	elem.parentNode.replaceChild(input, elem);         
+	return input;
+}
+
+function convertToTxt(elem)
+{
+	var input = document.createElement('input');
+	input.id = elem.id;
+	input.value = elem.value;
+	input.onfocus = elem.onfocus;
+	input.onblur = elem.onblur;
+	input.className = elem.className;
+	if (elem.type == 'text' )
+	  { return elem; }
+	else
+	  { input.type = 'text'; }
+	
+	elem.parentNode.replaceChild(input, elem);         
+	return input;
 }
\ No newline at end of file
