@@ -13,11 +13,19 @@
 	$user_table = $_POST['user_table'];
 	$_SESSION['last_user_table'] = $user_table;
 	
+	$query = "SHOW TABLES LIKE '" . $user_table . "'";
+	$result = $bwb_dbh->query($query);
+	if ($result->rowCount() < 1)
+	{
+		echo "-no data-";
+		exit;
+	}
+	
 	$query = "SELECT * FROM " . $user_table;
 	$result = $bwb_dbh->query($query);
 	
 	$num_rows = $result->rowCount();
-	if ($num_rows === false)
+	if ($num_rows < 1)
 	{
 		echo "-no data-";
 		exit;
