@@ -9,6 +9,9 @@
 	include ("./check_session.php");
 	
 	$table = $_REQUEST['table'];
+	$fields = $_REQUEST['fields'];
+	if (!isset($fields) || ($fields == ""))
+		$fields = "*";
 	$where = $_REQUEST['where'];
 	$order_by = $_REQUEST['order_by'];
 	$no_prefix = $_REQUEST['no_prefix'];
@@ -17,7 +20,7 @@
 	else
 		$prefix = BWB_TABLE_PREFIX;
 	
-	$query = "SELECT * FROM " . $prefix . $table;
+	$query = "SELECT " . $fields . " FROM " . $prefix . $table;
 	if (isset($where) && ($where != ""))
 		$query .= " WHERE " . $where;
 	if (isset($order_by) && ($order_by != ""))
