@@ -13,6 +13,8 @@
 // Added link for "forgot password".
 // Revised: 4/13/2015	ELL
 // Fixed bug with refresh CAPTCHA routine sucking up tons of bandwidth if login screen left open.
+// Revised: 11/20/2016	ELL
+// Modified reset password to store temp password in temp users table, then update users table upon logging in with temp password to new temp password.
 //
 	
 	session_start();
@@ -67,6 +69,7 @@
 		$use_captcha = false;
 		
 	$err_code = $_GET['err'];
+	$password_reset = $_GET['password_reset'];
 	
 	$query = "SELECT `option_value` FROM `" . BWB_TABLE_PREFIX . "options_selected` WHERE `option_name`='Theme'";
 	$result = $bwb_dbh->query($query);
@@ -209,6 +212,9 @@ function ResetRefreshTimer()
         <td>
         	<input type="password" name="password_input" id="password_input" onKeyDown="checkForEnter(event);" />
             <input type="hidden" name="password" id="password" />
+<?php if (isset($password_reset) && ($password_reset == 1))	{	?>
+			<input type="hidden" name="password_reset" id="password_reset" value="1" />
+<?php	}	?>
         </td>
       </tr>
       <tr>
@@ -282,7 +288,7 @@ function ResetRefreshTimer()
 
 <script language="javascript" type="text/javascript">
 	document.getElementById("javascript_warning").innerHTML = "";
-	HidePopupMsg();
+	popup_msg.HidePopupMsg();
 	
 	if (err_code != "")
 	{
