@@ -9,6 +9,9 @@
 	
 	
 	include ("check_session.php");
+	
+	if ($access_level != "admin")
+		exit;
 		
 	$password = $_REQUEST['password'];
 	
@@ -80,7 +83,7 @@ function checkForEnter(e) {
 	}
 	else
 	{
-		$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "users WHERE `UserID` = 'admin'";
+		$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "users WHERE `UserID` = '" . $userid . "'";
 		$result = $bwb_dbh->query($query);
 		$row = $result->fetch(PDO::FETCH_ASSOC);
 		
