@@ -5,15 +5,15 @@
 // For licensing, see license.txt.
 // Created: 11/30/2013	ELL
 -->
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
-<html xmlns="http://www.w3.org/1999/xhtml">
+<!DOCTYPE html>
+<html>
   <head>
     <meta http-equiv="content-type" content="application/xhtml+xml; charset=utf-8" />
     <title>Breeze Website Builder Install</title>
     <link type="text/css" href="/manage/theme/classic/manager.css" rel="stylesheet" />
     <link type="image/x-icon" href="/manage/images/favicon.ico" rel="shortcut icon" />
     
-    <style type="text/css">
+    <style>
 	.requires_input	{
 		border-style:solid;
 		border-color:#FFFF00;
@@ -34,7 +34,7 @@
 		margin-right:10px;
 	}
     </style>
-    <script language="javascript" type="text/javascript">
+    <script>
 	function Initialize()
 	{
 		GenerateSalts();
@@ -137,12 +137,12 @@
 	
 	</script>
   </head>
-<body onload="Initialize();">
+<body onLoad="Initialize();">
     <div align="center" id="login_logo"><img alt="Breeze Website Builder" src="/manage/theme/classic/images/Breeze_header_logo.png" /></div>
   <div id="header_divider_login"> </div>
-    <p>Thank you for downloading the Breeze Website Builder™. If you are reading
-      this page from your computer, you have successfully unzipped the Breeze
-      Website Builder™ files, but you will need to FTP all of the extracted
+    <p>Thank you for downloading the Breeze™ Website Builder. If you are reading
+      this page from your computer, you have successfully unzipped the Breeze™
+      Website Builder files, but you will need to FTP all of the extracted
       files to the web root of your hosting account. Your web server will need
       to be running <strong>PHP 5 or later</strong>, and <strong>MySQL 5 or
         later</strong>. Then go to <strong>http://<em>mydomain.com</em>/install/install.php</strong>
@@ -152,7 +152,7 @@
       and a <strong>database user with read and write privileges</strong> to
       that database before your can continue. Please do that first
       before continuing. If you have already created a database,
-    enter the information requested below. The fields that you need to fill in are <span class="requires_input">highlighted</span>. Typically, you will need to fill in the <span class="usually_requires_input">database prefix</span>, but not always. If your database is running on a different server from your website server, you will need to provide the IP address or server name of your <span class="may_require_input">database server</span>. You may leave the default values in the other fields.</p>
+    enter the information requested below. The fields that you need to fill in are <span class="requires_input" style="padding-left:5px; padding-right:5px;">highlighted</span>. Typically, you will need to fill in the <span class="usually_requires_input" style="padding-left:5px; padding-right:5px;">database prefix</span>, but not always. If your database is running on a different server from your website server, you will need to provide the IP address or server name of your <span class="may_require_input" style="padding-left:5px; padding-right:5px;">database server</span>. You may leave the default values in the other fields.</p>
     <form action="do_install.php" method="post" name="form1" id="form1">
       <table align="center" width="90%" border="0">
         <tbody>
@@ -263,7 +263,7 @@
           <tr>
             <td><span class="sub_title">Email: </span></td>
             <td><input type="text" name="email" id="email" style="width:200px;" class="requires_input" /></td>
-            <td class="medium_message">User for password reset.</td>
+            <td class="medium_message">Email for password reset.</td>
           </tr>
           <tr>
             <td><span class="sub_title">Name: </span></td>
@@ -278,7 +278,30 @@
             <td><span class="sub_title">Language: </span></td>
             <td>
             	<select name="language" id="language">
-					<option value="en">English</option>
+<?php
+	$languages = array();
+	$path = "languages.txt";
+	$fh = fopen($path, "r");
+	$contents = fread($fh, filesize($path));
+	fclose($fh);
+	
+	$rows = explode("\n", $contents);
+	foreach($rows as $row)
+	{
+		$lang_pair = explode(";", $row);
+		$lang_pair[0] = trim($lang_pair[0]);
+		$lang_pair[1] = trim($lang_pair[1]);
+		$languages[] = $lang_pair;
+	}
+	foreach($languages as $language)
+	{
+		if ($language[0] == "en")
+			$selected = " selected='selected'";
+		else
+			$selected = "";
+		echo "		<option value='" . $language[0] . "'" . $selected . ">" . $language[1] . "</option>\n";
+	}
+?>
                 </select>
             </td>
             <td class="medium_message">Laguage used for management side.</td>
