@@ -24,7 +24,7 @@ function DeleteConfirm()
 	popup_msg.popup_button_1_span = NO_WORD;
 	popup_msg.popup_timeout = -1;
 	popup_msg.ShowPopupMsg();
-	document.getElementById("popup_button_2_span").onclick = function () { HidePopupMsg(); };
+	document.getElementById("popup_button_2_span").onclick = function () { popup_msg.HidePopupMsg(); };
 	document.getElementById("popup_button_1_span").onclick = function () { UncheckDelete(); };
 
 }
@@ -32,7 +32,7 @@ function DeleteConfirm()
 function UncheckDelete()
 {
 	document.getElementById("delete_all_pages").checked = false;
-	HidePopupMsg();
+	popup_msg.HidePopupMsg();
 }
 
 function ShowUploadingMsg()
