@@ -13,6 +13,14 @@
 // Replaced JavaScript AJAX with JQuery AJAX.
 // Converted from form post to (JQuery) AJAX.
 // Added style-sheet switching.
+// Revised: 4/28/2016	ELL
+// Added trapping of adding blank class or ID namse.
+// Revised: 5/27/2016	ELL
+// Added class-name copy button for copy/rename class.
+// Revised: 2/3/2017	ELL
+// Added ability to copy from all classes by checking checkbox.
+// Modified: 11/14/2017	ELL
+// Added checking between class prefix and class to avoid redundancy and inconsistency.
 
 
 var param_array = {'popup_msg_type' : 1, 'status_msg' : '', 'popup_timeout' : -1};
@@ -48,15 +56,22 @@ function PopulateClassLists(data)
 
 	var class_list_sort_1 = lists[0].split(row_delim);
 	var html = "<select name='class' id='class'>\n";
+	if (document.getElementById("show_all_classes").checked == true)	{
+		var html_copy_from = "<select name='copy_from_class' id='copy_from_class' onChange='CheckClassNames();'>\n";
+		html_copy_from = html_copy_from + "<option>-not selected-</option>\n";
+	}
 	for (var i = 0; i < class_list_sort_1.length; i++)
 	{
 		JSON_class_row = JSON.parse(class_list_sort_1[i]);
 		html = html + "<option value='" + JSON_class_row.class + "'>" + JSON_class_row.class + "</option>\n";
+		if (document.getElementById("show_all_classes").checked == true)
+			html_copy_from = html_copy_from + "<option value='" + JSON_class_row.class + "'>" + JSON_class_row.class + "</option>\n";
 	}
 	html = html + "</select>\n";
+	if (document.getElementById("show_all_classes").checked == true)
+		html_copy_from = html_copy_from + "</select>\n";
 	document.getElementById("class_td").innerHTML = html;
 	
-	
 	var class_list_sort_2 = lists[1].split(row_delim);
 	var html_subclass = "<select name='subclass' id='subclass' onChange='CheckForParam(this.value);'>\n";
 	html_subclass = html_subclass + "<option value=':link'>:link</option>\n";
@@ -109,7 +124,7 @@ function PopulateClassLists(data)
 	
 	var html_sort = "<table width='100%' border='0' cellspacing='0' cellpadding='0'>\n";
   	html_sort = html_sort + "<tr>\n";
-    html_sort = html_sort + "<td colspan='4' class='sub_title' style='padding-left:5px;'><?php echo CLASSES_SET_CLASS_SORT_ORDER; ?></td>\n";
+    html_sort = html_sort + "<td colspan='4' class='sub_title' style='padding-left:5px;'>" + CLASSES_SET_CLASS_SORT_ORDER + "</td>\n";
   	html_sort = html_sort + "</tr>\n";
   	html_sort = html_sort + "<tr bgcolor='#CCCCCC'>\n";
   	html_sort = html_sort + "<td>&nbsp;&nbsp;&nbsp;&nbsp;</td>\n";
@@ -157,23 +172,28 @@ function PopulateClassLists(data)
 		var html_edit = "<select name='class_edit' id='class_edit' onChange='PopulateDescription();'>\n";
 		html_edit = html_edit + "<option>-not selected-</option>\n";
 		
-		var html_copy_from = "<select name='copy_from_class' id='copy_from_class' onChange='CheckClassNames();'>\n";
-		html_copy_from = html_copy_from + "<option>-not selected-</option>\n";
+		if (document.getElementById("show_all_classes").checked != true)	{
+			var html_copy_from = "<select name='copy_from_class' id='copy_from_class' onChange='CheckClassNames();'>\n";
+			html_copy_from = html_copy_from + "<option>-not selected-</option>\n";
+		}
 		
 		for (var i = 0; i < custom_class_list.length; i++)
 		{
 			JSON_class_row = JSON.parse(custom_class_list[i]);
 			html_delete = html_delete + "<option value='" + JSON_class_row.class + "'>" + JSON_class_row.class + " / " + JSON_class_row.description + "</option>\n";
 			html_edit = html_edit + "<option value='" + JSON_class_row.class + "'>" + JSON_class_row.class + "</option>\n";
-			html_copy_from = html_copy_from + "<option value='" + JSON_class_row.class + "'>" + JSON_class_row.class + "</option>\n";
+			if (document.getElementById("show_all_classes").checked != true)
+				html_copy_from = html_copy_from + "<option value='" + JSON_class_row.class + "'>" + JSON_class_row.class + "</option>\n";
 		}
 		html_delete = html_delete + "</select>\n";
 		html_edit = html_edit + "</select>\n";
-		html_copy_from = html_copy_from + "</select>\n";
+		if (document.getElementById("show_all_classes").checked != true)
+			html_copy_from = html_copy_from + "</select>\n";
 		
 		document.getElementById("class_delete_div").innerHTML = html_delete;
 		document.getElementById("class_edit_div").innerHTML = html_edit;
-		document.getElementById("copy_from_class_td").innerHTML = html_copy_from;
+		if (document.getElementById("show_all_classes").checked != true)
+			document.getElementById("copy_from_class_td").innerHTML = html_copy_from;
 	}
 	else
 	{
@@ -181,6 +201,8 @@ function PopulateClassLists(data)
 		document.getElementById("class_edit_div").innerHTML = "<div class='no_custom_class'>" + CLASSES_NO_CUSTOM_CLASSES_DEFINED + "</div>";
 		document.getElementById("copy_from_class_td").innerHTML = "<div class='no_custom_class'>" + CLASSES_NO_CUSTOM_CLASSES_DEFINED + "</div>";
 	}
+	if (document.getElementById("show_all_classes").checked == true)
+		document.getElementById("copy_from_class_td").innerHTML = html_copy_from;
 }
 
 //////////////////////////////////////////////////////////////////////////////////////
@@ -197,14 +219,14 @@ function DeleteConfirm()
 	popup_msg.popup_timeout = -1;
 	popup_msg.ShowPopupMsg();
 	document.getElementById("popup_button_2_span").onclick = function () { DeleteClass(); };
-	document.getElementById("popup_button_1_span").onclick = function () { HidePopupMsg(); };
+	document.getElementById("popup_button_1_span").onclick = function () { popup_msg.HidePopupMsg(); };
 }
 
 function DeleteClass()
 {
 	var class_delete = document.getElementById("class_delete").value;
 	class_delete = EscapeClass(class_delete);
-	HidePopupMsg();
+	popup_msg.HidePopupMsg();
 	
 	$.post( "delete_class.php", { class: class_delete, style_sheet: style_sheet } ).done(CompleteDeleteClass) ;
 }
@@ -361,8 +383,16 @@ function ChangeSort(bAlpha)
 ///////////////////////////////////////////////////////////////////////////////////////
 function CopyClass()
 {
+	if (document.getElementById("copy_rename_btn").className == "button_console_edit_disabled")
+		return;
+		
 	var copy_from_class = document.getElementById("copy_from_class").value;
-	var copy_to_class = document.getElementById("copy_to_class_prefix").value + document.getElementById("copy_to_class").value;
+	var copy_to_class = document.getElementById("copy_to_class").value;
+	var copy_to_class_prefix = document.getElementById("copy_to_class_prefix").value;
+	if ((copy_to_class_prefix != "") && (copy_to_class.charAt(0) != "#") && (copy_to_class.charAt(0) != "."))
+		copy_to_class = copy_to_class_prefix + copy_to_class;
+	else if ((copy_to_class_prefix != "") && ((copy_to_class.charAt(0) == "#") || (copy_to_class.charAt(0) == ".")))
+		copy_to_class = copy_to_class_prefix + copy_to_class.substring(1);
 	var to_style_sheet = document.getElementById("to_style_sheet").value;
 	
 	if ((copy_from_class == "-not selected-") || (copy_from_class == ""))
@@ -443,9 +473,27 @@ function CheckClassNames()
 }
 
 ///////////////////////////////////////////////////////////////////////////////////////////////////////////
+function CheckClassName(class_el)
+{
+	var class_name = class_el.value;
+	var letters = /^[A-Za-z]+$/;
+	var first_char = class_name.substr(0, 1);
+	if(!first_char.match(letters) && (first_char != ".") && (first_char != "#") && (first_char != "@") && (first_char != "*") && (first_char != "["))
+		class_el.value = class_name.substr(1);
+}
+
 function AddClass()
 {
-	$.ajax({type:'POST', url: 'add_class.php', data:$('#formAddTag').serialize(), success: function(response) {
+	if (document.getElementById("class").value == "")	{
+		popup_msg.top_offset = 0;
+		popup_msg.left_offset = 320;
+		popup_msg.popup_msg_type = 1;
+		popup_msg.popup_timeout = 4000;
+		popup_msg.status_msg = CLASSES_ADD_CLASS_CANNOT_BE_BLANK_MSG;
+		popup_msg.ShowPopupMsg();
+		return;
+	}
+			$.ajax({type:'POST', url: 'add_class.php', data:$('#formAddTag').serialize(), success: function(response) {
 		CompleteAddClass(response);
 	}});
 }
@@ -510,6 +558,15 @@ function CompleteSetSortOrder(response)
 	GetClassLists();
 }
 
+///////////////////////////////////////////////////////////////////////////////////////////////////////////
+function CopyClassName()
+{
+	document.getElementById("copy_to_class_prefix").value = "";
+	document.getElementById("copy_to_class").value = document.getElementById("copy_from_class").value;
+	
+	CheckClassNames();
+}
+
 ///////////////////////////////////////////////////////////////////////////////////////////////////////////
 function ResizeWorkspace(mainWidth, mainHeight, menuWidth, headerHeight) {
 
