@@ -49,13 +49,32 @@
 // Revised: 3/25/2016	ELL
 // Replace numeric placeholders of -1 and -1000000 for not set with "-not set".  Added code to clear "-not set-" when user wants to type
 // and code to re-apply "-not set-" when user clears the field.
+// Revised: 11/3/2016	ELL
+// Added ability to set both min and max widths simultaneously, and both min and max heights simultaneously.
+// Revised: 11/10/2016	ELL
+// Adding alfa sort style sheets.
+// Modified: 12/1/2016	ELL
+// Consolidated all class tables into site_classes table indexed by style_sheet field.
+// Consolidated all CSS tables into site_css table indexed by style_sheet field.
+// Revised: 2/2/2017	ELL
+// Modified to utilize separate browser reset table for browser reset CSS.
+// Revised: 4/22/2017	ELL
+// Added background RGBA labeled as "Foreground Opaque".
+// Revised: 5/25/2017	ELL
+// Added various transition, flex and content attributes.
+// Added text-transform.
+// Revised: 7/17/2017	ELL
+// Added button for setting important CSS attributes.
+// Revised: 12/29/2017	ELL
+// Added quick-setup button to set header as 'sticky'.
+
 
 var param_array = {'popup_msg_type' : 1, 'status_msg' : '', 'popup_timeout' : -1};
 var popup_msg = new PopupMsg(param_array);
 
 window.parent.document.title = document.title;
 
-function popupcolorpicker(form_name, field_name)
+function popupcolorpicker(form_name, field_name, top_offset)
 {
 	var start_color = document.getElementById(field_name).value;
 	if (start_color == "")
@@ -64,12 +83,37 @@ function popupcolorpicker(form_name, field_name)
 		start_color = start_color.replace("#", "");
 	
 	var URL = "colorpicker.php?form_name=" + form_name + "&field_name=" + field_name + "&source_page=edit_css.php&start_color=" + start_color;
-	
-	window.open (URL, "colorpicker", "alwaysRaised=0,dependent=1,menubar=0,resizable=0,width=450,height=350,scrollbars=0,location=0");
+
+	if ((typeof top_offset == 'undefined') || isNaN(top_offset))
+		top_offset = 0;
+	var ntop = parseInt(tempY) + parseInt(top_offset);
+	var nleft = tempX;
+
+	window.open (URL, "colorpicker", "alwaysRaised=0,dependent=1,menubar=0,resizable=0,width=450,height=350,scrollbars=0,location=0,top=" + ntop + ",left=" + nleft);
 }
 
 function enable_disable_controls(ShowMessage)
-{	
+{
+	if ((document.getElementById("update_btn").className == "button_console_save_disabled") && (ShowMessage == 1))	{
+		document.getElementById("use_table_data").checked = false;
+		return;
+	}
+		
+	if (document.getElementById("goto_class").value == "")	{
+		document.getElementById("update_btn").className = "button_console_save_disabled";
+		document.getElementById("update_btn_2").className = "button_console_save_disabled";
+		document.getElementById("important_btn").className = "button_console_important_disabled";
+		document.getElementById("preview_btn").className = "button_console_preview_disabled";
+		document.getElementById("set_display_flex_btn").className = "button_console_disabled";
+	}
+	else	{
+		document.getElementById("update_btn").className = "button_console_save";
+		document.getElementById("update_btn_2").className = "button_console_save";
+		document.getElementById("important_btn").className = "button_console_important";
+		document.getElementById("preview_btn").className = "button_console_preview";
+		document.getElementById("set_display_flex_btn").className = "button_console";
+	}
+		
 	if (document.getElementById("use_table_data").checked == true)
 	{
 		document.getElementById("font").disabled = false;
@@ -98,6 +142,7 @@ function enable_disable_controls(ShowMessage)
 		document.getElementById("bkgd_color").disabled = false;
 		document.getElementById("bkgd_transparent").disabled = false;
 		document.getElementById("bkgd_opacity").disabled = false;
+		document.getElementById("bkgd_rgba").disabled = false;
 		document.getElementById("border").disabled = false;
 		document.getElementById("border_units").disabled = false;
 		document.getElementById("border_color").disabled = false;
@@ -120,9 +165,13 @@ function enable_disable_controls(ShowMessage)
 		document.getElementById("width").disabled = false;
 		document.getElementById("width_units").disabled = false;
 		document.getElementById("width_prefix").disabled = false;
+		document.getElementById("max_width").disabled = false;
+		document.getElementById("max_width_units").disabled = false;
 		document.getElementById("height").disabled = false;
 		document.getElementById("height_units").disabled = false;
 		document.getElementById("height_prefix").disabled = false;
+		document.getElementById("max_height").disabled = false;
+		document.getElementById("max_height_units").disabled = false;
 		document.getElementById("background_image").disabled = false;
 		document.getElementById("file_browse1").disabled = false;
 		document.getElementById("background_attachment").disabled = false;
@@ -188,18 +237,43 @@ function enable_disable_controls(ShowMessage)
 		
 		document.getElementById("visibility").disabled = false;
 		
+		document.getElementById("text_transform").disabled = false;
+				
+		document.getElementById("justify_content").disabled = false;
+		document.getElementById("content").disabled = false;
+		document.getElementById("content_text").disabled = false;
+		
+		document.getElementById("transition_property").disabled = false;
+		document.getElementById("transition_timing_function").disabled = false;
+		document.getElementById("transition_duration").disabled = false;
+		document.getElementById("transition_duration_units").disabled = false;
+		document.getElementById("transition_delay").disabled = false;
+		document.getElementById("transition_delay_units").disabled = false;
+		
+		document.getElementById("flex_basis").disabled = false;
+		document.getElementById("flex_grow").disabled = false;
+		document.getElementById("flex_shrink").disabled = false;
+		document.getElementById("flex_direction").disabled = false;
+		document.getElementById("flex_wrap").disabled = false;
+		
+		document.getElementById("gradient_type").disabled = false;
+		
 		enable_disable_shadow();
 		margin_auto_clicked("top");
 		margin_auto_clicked("bottom");
 		margin_auto_clicked("left");
 		margin_auto_clicked("right");
-		enable_disable_background_color();
+		enable_disable_background_color("bkgd_transparent");
 		enable_disable_background_positions();
 		enable_disable_background_sizes();
 		enable_disable_letter_spacing();
 		enable_disable_line_height();
 		enable_disable_font_size();
-		
+		ShowHideMaxWidthHeight(document.getElementById("width_prefix").value, "width");
+		ShowHideMaxWidthHeight(document.getElementById("height_prefix").value, "height");
+		enable_disable_content_text();
+		enable_disable_flex_basis_length();
+		enable_disable_gradient();
 		
 		CheckFormatOnUnitSelect("border_units", "border", 0);
 		CheckFormatOnUnitSelect("padding_top_units", "padding_top", 0);
@@ -216,6 +290,8 @@ function enable_disable_controls(ShowMessage)
 		CheckFormatOnUnitSelect("margin_left_units", "margin_left", 0);
 		CheckFormatOnUnitSelect("width_units", "width", 0);
 		CheckFormatOnUnitSelect("height_units", "height", 0);
+		CheckFormatOnUnitSelect("max_width_units", "max_width", 0);
+		CheckFormatOnUnitSelect("max_height_units", "max_height", 0);
 		CheckFormatOnUnitSelect("position_left_units", "position_left", 0);
 		CheckFormatOnUnitSelect("position_top_units", "position_top", 0);
 		CheckFormatOnUnitSelect("position_right_units", "position_right", 0);
@@ -230,6 +306,7 @@ function enable_disable_controls(ShowMessage)
 		CheckFormatOnUnitSelect("background_height_units", "background_height", 0);
 		CheckFormatOnUnitSelect("letter_spacing_units", "letter_spacing", 1);
 		CheckFormatOnUnitSelect("line_height_units", "line_height", 2);
+		CheckFormatOnUnitSelect("flex_basis_length_units", "flex_basis_length", 0);
 		
 		document.getElementById("text_table").style.backgroundColor = "#FFCCCC";
 		document.getElementById("background_table").style.backgroundColor = "#CCFFCC";
@@ -239,6 +316,9 @@ function enable_disable_controls(ShowMessage)
 		document.getElementById("background_img_table").style.backgroundColor = "#AAFFFF";
 		document.getElementById("list_table").style.backgroundColor = "#FFBB99";
 		document.getElementById("box_shadow_table").style.backgroundColor = "#99BBFF";
+		document.getElementById("content_table").style.backgroundColor = "#FF99BB";
+		document.getElementById("transition_table").style.backgroundColor = "#99FFBB";
+		document.getElementById("flex_table").style.backgroundColor = "#BB99FF";
 	}
 	else
 	{
@@ -275,6 +355,7 @@ function enable_disable_controls(ShowMessage)
 		document.getElementById("bkgd_color").disabled = true;
 		document.getElementById("bkgd_transparent").disabled = true;
 		document.getElementById("bkgd_opacity").disabled = true;
+		document.getElementById("bkgd_rgba").disabled = true;
 		document.getElementById("border").disabled = true;
 		document.getElementById("border_units").disabled = true;
 		document.getElementById("border_color").disabled = true;
@@ -301,9 +382,13 @@ function enable_disable_controls(ShowMessage)
 		document.getElementById("width").disabled = true;
 		document.getElementById("width_units").disabled = true;
 		document.getElementById("width_prefix").disabled = true;
+		document.getElementById("max_width").disabled = true;
+		document.getElementById("max_width_units").disabled = true;
 		document.getElementById("height").disabled = true;
 		document.getElementById("height_units").disabled = true;
 		document.getElementById("height_prefix").disabled = true;
+		document.getElementById("max_height").disabled = true;
+		document.getElementById("max_height_units").disabled = true;
 		document.getElementById("background_image").disabled = true;
 		document.getElementById("file_browse1").disabled = true;
 		document.getElementById("background_attachment").disabled = true;
@@ -380,6 +465,47 @@ function enable_disable_controls(ShowMessage)
 		
 		document.getElementById("visibility").disabled = true;
 		
+		document.getElementById("text_transform").disabled = true;
+				
+		document.getElementById("justify_content").disabled = true;
+		document.getElementById("content").disabled = true;
+		document.getElementById("content_text").disabled = true;
+		
+		document.getElementById("transition_property").disabled = true;
+		document.getElementById("transition_timing_function").disabled = true;
+		document.getElementById("transition_duration").disabled = true;
+		document.getElementById("transition_duration_units").disabled = true;
+		document.getElementById("transition_delay").disabled = true;
+		document.getElementById("transition_delay_units").disabled = true;
+		
+		document.getElementById("flex_basis").disabled = true;
+		document.getElementById("flex_basis_length").disabled = true;
+		document.getElementById("flex_basis_length_units").disabled = true;
+		document.getElementById("flex_grow").disabled = true;
+		document.getElementById("flex_shrink").disabled = true;
+		document.getElementById("flex_direction").disabled = true;
+		document.getElementById("flex_wrap").disabled = true;
+		
+		document.getElementById("gradient_type").disabled = true;
+		document.getElementById("gradient_angle").disabled = true;
+		document.getElementById("gradient_color_1").disabled = true;
+		document.getElementById("gradient_color_2").disabled = true;
+		document.getElementById("gradient_color_3").disabled = true;
+		document.getElementById("gradient_color_4").disabled = true;
+		document.getElementById("gradient_color_5").disabled = true;
+		document.getElementById("gradient_color_6").disabled = true;
+		document.getElementById("gradient_color_7").disabled = true;
+		document.getElementById("gradient_color_8").disabled = true;
+		document.getElementById("gradient_opacity_1").disabled = true;
+		document.getElementById("gradient_opacity_2").disabled = true;
+		document.getElementById("gradient_opacity_3").disabled = true;
+		document.getElementById("gradient_opacity_4").disabled = true;
+		document.getElementById("gradient_opacity_5").disabled = true;
+		document.getElementById("gradient_opacity_6").disabled = true;
+		document.getElementById("gradient_opacity_7").disabled = true;
+		document.getElementById("gradient_opacity_8").disabled = true;
+		document.getElementById("gradient_repeat").disabled = true;
+		
 		document.getElementById("text_table").style.backgroundColor = "#D9D9D9";
 		document.getElementById("background_table").style.backgroundColor = "#D9D9D9";
 		document.getElementById("border_table").style.backgroundColor = "#D9D9D9";
@@ -387,7 +513,10 @@ function enable_disable_controls(ShowMessage)
 		document.getElementById("position_table").style.backgroundColor = "#D9D9D9";
 		document.getElementById("background_img_table").style.backgroundColor = "#D9D9D9";
 		document.getElementById("list_table").style.backgroundColor = "#D9D9D9";
-		document.getElementById("box_shadow_table").style.backgroundColor = "#D9D9D9";
+		document.getElementById("box_shadow_table").style.backgroundColor = "#D9D9D9";		
+		document.getElementById("content_table").style.backgroundColor = "#D9D9D9";
+		document.getElementById("transition_table").style.backgroundColor = "#D9D9D9";
+		document.getElementById("flex_table").style.backgroundColor = "#D9D9D9";
 	}
 	if (ShowMessage == 1)
 	{
@@ -547,7 +676,7 @@ function LoadBrowserResetParams()
 
 		params = "submit=Update";
 		params = params + "&quick_setup=1";
-		params = params + "&style_sheet=site";
+		params = params + "&style_sheet=browser_reset";
 		params = params + "&class=html";
 		params = params + "&use_table_data=1";
 		params = params + "&margin_top=0";
@@ -580,11 +709,11 @@ function LoadBrowserResetParams()
 	{
 		xmlhttp2.open("POST","save_css.php",true);
 		xmlhttp2.setRequestHeader('Content-Type','application/x-www-form-urlencoded');
-		xmlhttp2 = UpdateMessage(xmlhttp2);
+		xmlhttp2 = UpdateMessage(xmlhttp2, false);
 
 		params = "submit=Update";
 		params = params + "&quick_setup=1";
-		params = params + "&style_sheet=site";
+		params = params + "&style_sheet=browser_reset";
 		params = params + "&class=body";
 		params = params + "&use_table_data=1";
 		params = params + "&margin_top=0";
@@ -785,6 +914,45 @@ function LoadStickyFooterParams()
 	mTimer2 = setTimeout(function() { DisplayFinalMsg(msg) }, 5000);
 }
 
+//////////////////////////////////////////////////////////////////////////////////////
+function LoadStickyHeaderParams()
+{
+	alert(EDIT_CSS_LOAD_STICKY_HEADERS_ALERT_MSG);
+	
+	var params = "";
+	
+	popup_msg.popup_msg_type = 1;
+	popup_msg.status_msg = EDITOR_STARTING_UPDATE_MSG;
+	popup_msg.popup_timeout = -1;
+	popup_msg.top_offset = 0;
+	popup_msg.left_offset = 500;
+	popup_msg.ShowPopupMsg();
+		
+	var xmlhttp;
+	xmlhttp = getXmlHttpRequestObject();
+	if (xmlhttp.readyState == 4 || xmlhttp.readyState == 0)
+	{
+		xmlhttp.open("POST","save_css.php",true);
+		xmlhttp.setRequestHeader('Content-Type','application/x-www-form-urlencoded');
+		xmlhttp = UpdateMessage(xmlhttp, false);
+
+		params = "submit=Update";
+		params = params + "&quick_setup=1";
+		params = params + "&style_sheet=site";
+		params = params + "&class=header";
+		params = params + "&use_table_data=1";
+		params = params + "&position=sticky";
+		params = params + "&position_top=0";
+		params = params + "&position_top_units=0";
+		params = params + "&submit_action=Update";
+		
+		xmlhttp.send(params);
+	}
+		
+	var msg = EDIT_CSS_LOAD_STICKY_HEADERS_COMPLETE_MSG;
+	mTimer2 = setTimeout(function() { DisplayFinalMsg(msg) }, 5000);
+}
+
 function DisplayFinalMsg(msg)
 {
 	popup_msg.status_msg = msg;
@@ -1002,6 +1170,17 @@ function CheckBkgndImage(image_path, photo_img)
 }
 
 ///////////////////////////////////////////////////////////////////////////////////////////
+function ChangeStyleSheetSort(bAlpha)
+{
+	var sort_alpha = 0;
+	if (bAlpha === true)
+		sort_alpha = 1;
+		
+	var style_sheet = document.getElementById('style_sheet').value;
+	
+	window.location = "edit_css.php?style_sheet_sort_method=" + sort_alpha + "&style_sheet=" + style_sheet;
+}
+
 function ChangeSort(bAlpha)
 {
 	var sort_alpha = 0;
@@ -1086,11 +1265,20 @@ function CheckFormatOnUnitSelect(unit_el_id, length_el_id, offset)
 {
 	var units = document.getElementById(unit_el_id).value;
 	var length = "";
-			
+
 	if (units < (2 + offset))	{
 		length = document.getElementById(length_el_id).value;
 		var length_arr = length.split(".");
-		document.getElementById(length_el_id).value = length_arr[0];
+		var length_str = length_arr[0];
+		if (((units == (1 + offset)) && (length_arr.length > 1)) || ((unit_el_id == "line_height_units") && (units == 1)))	{
+			var decimal = "";
+			if ((length_el_id == "width") || (length_el_id == "height"))
+				decimal = length_arr[1].substr(0, 2);
+			else
+				decimal = length_arr[1].substr(0, 1);
+			length_str = length_str + "." + decimal;
+		}
+		document.getElementById(length_el_id).value = length_str;
 	}
 }
 
@@ -1105,22 +1293,50 @@ function CheckOverflowLists(selection, list)
 	}
 }
 
-function enable_disable_background_color()
+function enable_disable_background_color(el_id)
 {
-	if (document.getElementById("bkgd_transparent").checked)	{
-		document.getElementById("bkgd_color").value = "-not set-";
-		document.getElementById("bkgd_color").disabled = true;
-		document.getElementById("bkgd_opacity").value = -1;
-		document.getElementById("bkgd_opacity").disabled = true;
+	if (el_id == "bkgd_transparent")	{
+		if (document.getElementById("bkgd_transparent").checked)	{
+			document.getElementById("bkgd_color").value = _NOT_SET_;
+			document.getElementById("bkgd_color").disabled = true;
+			document.getElementById("bkgd_color").className = "not_set";
+			document.getElementById("bkgd_opacity").value = _NOT_SET_;
+			document.getElementById("bkgd_opacity").disabled = true;
+			document.getElementById("bkgd_rgba").checked = false;
+			document.getElementById("bkgd_rgba").disabled = true;
+		}
+		else	{
+			document.getElementById("bkgd_color").disabled = false;
+			if (document.getElementById("bkgd_color").value != _NOT_SET_)
+				document.getElementById("bkgd_color").className = "";
+			else
+				document.getElementById("bkgd_color").className = "not_set";
+			document.getElementById("bkgd_opacity").disabled = false;
+			document.getElementById("bkgd_rgba").disabled = false;
+		}
 	}
 	else	{
-		document.getElementById("bkgd_color").disabled = false;
-		document.getElementById("bkgd_opacity").disabled = false;
+		if (document.getElementById("bkgd_rgba").checked)	{
+			document.getElementById("bkgd_color").disabled = false;
+			if (document.getElementById("bkgd_color").value != _NOT_SET_)
+				document.getElementById("bkgd_color").className = "";
+			else
+				document.getElementById("bkgd_color").className = _NOT_SET_;
+			document.getElementById("bkgd_opacity").disabled = false;
+			document.getElementById("bkgd_transparent").checked = false;
+			document.getElementById("bkgd_transparent").disabled = true;
+		}
+		else	{
+			document.getElementById("bkgd_transparent").disabled = false;
+		}
 	}
 }
 
 function PreviewPageSelect()
 {
+	if (document.getElementById("preview_btn").className == "button_console_preview_disabled")
+		return;
+
 	var ntop = tempY - 1600;
 	var strtop = ntop + "px";
 	document.getElementById("page_select_div").style.display = "block";
@@ -1166,6 +1382,136 @@ function TextFieldBlur(el)
 	}
 }
 
+function ShowHideMaxWidthHeight(prefix, dimension)
+{
+	if (prefix == "min-max")	{
+		document.getElementById("min_" + dimension + "_label").style.display = "inline";
+		document.getElementById(dimension + "_label").style.display = "none";
+		document.getElementById("max_" + dimension + "_label").style.visibility = "visible";
+		document.getElementById("max_" + dimension + "").style.visibility = "visible";
+		document.getElementById("max_" + dimension + "_units").style.visibility = "visible";
+		TextFieldBlur(document.getElementById("max_" + dimension + ""));
+	}
+	else	{
+		document.getElementById("min_" + dimension + "_label").style.display = "none";
+		document.getElementById(dimension + "_label").style.display = "inline";
+		document.getElementById("max_" + dimension + "_label").style.visibility = "hidden";
+		document.getElementById("max_" + dimension + "").style.visibility = "hidden";
+		document.getElementById("max_" + dimension + "_units").style.visibility = "hidden";
+	}
+}
+
+function SetDisplayFlex()
+{
+	if (document.getElementById("set_display_flex_btn").className == "button_console_disabled")
+		return;
+
+	document.getElementById("display").value = "flex";
+	popup_msg.popup_msg_type = 1;
+	popup_msg.status_msg = EDIT_CSS_DISPLAY_SET_TO_FLEX;
+	popup_msg.popup_timeout = 2000;
+	popup_msg.top_offset = 0;
+	popup_msg.left_offset = 500;
+	popup_msg.ShowPopupMsg();
+}
+
+function enable_disable_content_text()
+{
+	if ((document.getElementById("content").value == "string") || (document.getElementById("content").value == "url") || (document.getElementById("content").value == "attr"))
+		document.getElementById("content_text").disabled = false;
+	else
+		document.getElementById("content_text").disabled = true;		
+}
+
+function display_text_instructions(selection)
+{
+	if (selection == "string")
+		popup_msg.status_msg = EDIT_CSS_ENTER_STR_MSG;
+	else if (selection == "url")
+		popup_msg.status_msg = EDIT_CSS_ENTER_URL_MSG;
+	else if (selection == "attr")
+		popup_msg.status_msg = EDIT_CSS_ENTER_ATTR_MSG;
+
+	if ((selection == "string")	|| (selection == "url") || (selection == "attr"))
+	{
+		popup_msg.popup_timeout = -1;
+		popup_msg.popup_msg_type = 2;
+		popup_msg.top_offset = 0;
+		popup_msg.left_offset = 500;
+		popup_msg.popup_timeout = 8000;
+		popup_msg.ShowPopupMsg();
+	}
+}
+
+function enable_disable_flex_basis_length()
+{		
+	if (document.getElementById("flex_basis").value == "length")	{
+		document.getElementById("flex_basis_length").disabled = false;
+		document.getElementById("flex_basis_length_units").disabled = false;
+	}
+	else	{
+		document.getElementById("flex_basis_length").disabled = true;
+		document.getElementById("flex_basis_length_units").disabled = true;
+	}
+}
+
+function enable_disable_gradient()
+{
+	if (document.getElementById("gradient_type").value == 0)	{
+		document.getElementById("gradient_angle").disabled = true;
+		document.getElementById("gradient_color_1").disabled = true;
+		document.getElementById("gradient_color_2").disabled = true;
+		document.getElementById("gradient_color_3").disabled = true;
+		document.getElementById("gradient_color_4").disabled = true;
+		document.getElementById("gradient_color_5").disabled = true;
+		document.getElementById("gradient_color_6").disabled = true;
+		document.getElementById("gradient_color_7").disabled = true;
+		document.getElementById("gradient_color_8").disabled = true;
+		document.getElementById("gradient_opacity_1").disabled = true;
+		document.getElementById("gradient_opacity_2").disabled = true;
+		document.getElementById("gradient_opacity_3").disabled = true;
+		document.getElementById("gradient_opacity_4").disabled = true;
+		document.getElementById("gradient_opacity_5").disabled = true;
+		document.getElementById("gradient_opacity_6").disabled = true;
+		document.getElementById("gradient_opacity_7").disabled = true;
+		document.getElementById("gradient_opacity_8").disabled = true;
+		document.getElementById("gradient_repeat").disabled = true;
+	}
+	else	{
+		if (document.getElementById("gradient_type").value == 2)
+			document.getElementById("gradient_angle").disabled = true;
+		else
+			document.getElementById("gradient_angle").disabled = false;
+		document.getElementById("gradient_color_1").disabled = false;
+		document.getElementById("gradient_color_2").disabled = false;
+		document.getElementById("gradient_color_3").disabled = false;
+		document.getElementById("gradient_color_4").disabled = false;
+		document.getElementById("gradient_color_5").disabled = false;
+		document.getElementById("gradient_color_6").disabled = false;
+		document.getElementById("gradient_color_7").disabled = false;
+		document.getElementById("gradient_color_8").disabled = false;
+		document.getElementById("gradient_opacity_1").disabled = false;
+		document.getElementById("gradient_opacity_2").disabled = false;
+		document.getElementById("gradient_opacity_3").disabled = false;
+		document.getElementById("gradient_opacity_4").disabled = false;
+		document.getElementById("gradient_opacity_5").disabled = false;
+		document.getElementById("gradient_opacity_6").disabled = false;
+		document.getElementById("gradient_opacity_7").disabled = false;
+		document.getElementById("gradient_opacity_8").disabled = false;
+		document.getElementById("gradient_repeat").disabled = false;
+	}
+}
+
+function ManageImportantCSS()
+{
+	if (document.getElementById("important_btn").className == "button_console_important_disabled")
+		return;
+		
+	var style_sheet = document.getElementById("style_sheet").value;
+	var goto_class = document.getElementById("goto_class").value;
+		
+	window.location = "manage_important_css.php?style_sheet=" + style_sheet + "&class=" + goto_class;
+}
 
 ///////////////////////////////////////////////////////////////////////////////////////////////////////////
 function ResizeWorkspace(mainWidth, mainHeight, menuWidth, headerHeight) {
