@@ -19,22 +19,34 @@ function  LoadOrientationDefaults(orientation)
 {
 	if (orientation == "vertical")
 	{
-		document.getElementById("menu_width").value = -1;
-		document.getElementById("sub_level_offset_top").value = -5;
-		document.getElementById("sub_level_offset_left").value = 80;	
+		if (load_defaults == 1)	{
+			document.getElementById("menu_width").value = -1;
+			document.getElementById("sub_level_offset_top").value = -5;
+			document.getElementById("sub_level_offset_left").value = 80;	
+		}
+		document.getElementById("menu_width").disabled = true;
+		document.getElementById("menu_width_units").disabled = true;
 	}
 	else if (orientation == "horizontal_fixed_width")
 	{
-		document.getElementById("menu_width").value = -1;
-		document.getElementById("sub_level_offset_top").value = 0;
-		document.getElementById("sub_level_offset_left").value = 20;
+		if (load_defaults == 1)	{
+			document.getElementById("menu_width").value = 100;
+			document.getElementById("menu_width_units").value = 1;
+			document.getElementById("sub_level_offset_top").value = 0;
+			document.getElementById("sub_level_offset_left").value = 20;
+		}
+		document.getElementById("menu_width").disabled = false;
+		document.getElementById("menu_width_units").disabled = false;
 	}
 	else if (orientation == "horizontal_variable_width")
 	{
-		document.getElementById("menu_width").value = 100;
-		document.getElementById("menu_width_units").value = 1;
-		document.getElementById("sub_level_offset_top").value = 0;
-		document.getElementById("sub_level_offset_left").value = 20;
+		if (load_defaults == 1)	{
+			document.getElementById("menu_width").value = -1;
+			document.getElementById("sub_level_offset_top").value = 0;
+			document.getElementById("sub_level_offset_left").value = 20;
+		}
+		document.getElementById("menu_width").disabled = true;
+		document.getElementById("menu_width_units").disabled = true;
 	}
 }
 
@@ -186,32 +198,58 @@ function InitializeForm()
 	CheckFormatOnUnitSelect("menu_right_units", "menu_right", 0);
 	CheckFormatOnUnitSelect("menu_width_units", "menu_width", 0);
 	CheckFormatOnUnitSelect("top_level_item_width_units", "top_level_item_width", 0);
-	CheckFormatOnUnitSelect("top_level_item_height_units", "top_level_item_height", 0);
+	CheckFormatOnUnitSelect("top_level_item_height_units", "top_level_item_height", 2);
 	CheckFormatOnUnitSelect("top_level_padding_top_units", "top_level_padding_top", 0);
 	CheckFormatOnUnitSelect("top_level_padding_right_units", "top_level_padding_right", 0);
 	CheckFormatOnUnitSelect("top_level_padding_bottom_units", "top_level_padding_bottom", 0);
 	CheckFormatOnUnitSelect("top_level_padding_left_units", "top_level_padding_left", 0);
-	CheckFormatOnUnitSelect("sub_level_item_width_units", "sub_level_item_width", 0);
-	CheckFormatOnUnitSelect("sub_level_item_height_units", "sub_level_item_height", 0);
-	CheckFormatOnUnitSelect("sub_level_padding_top_units", "sub_level_padding_top", 0);
-	CheckFormatOnUnitSelect("sub_level_padding_right_units", "sub_level_padding_right", 0);
-	CheckFormatOnUnitSelect("sub_level_padding_bottom_units", "sub_level_padding_bottom", 0);
-	CheckFormatOnUnitSelect("sub_level_padding_left_units", "sub_level_padding_left", 0);
-	CheckFormatOnUnitSelect("sub_level_offset_top_units", "sub_level_offset_top", 0);
-	CheckFormatOnUnitSelect("sub_level_offset_left_units", "sub_level_offset_left", 0);
+	CheckFormatOnUnitSelect("sub_level_1_item_width_units", "sub_level_1_item_width", 0);
+	CheckFormatOnUnitSelect("sub_level_1_item_height_units", "sub_level_1_item_height", 2);
+	CheckFormatOnUnitSelect("sub_level_1_padding_top_units", "sub_level_1_padding_top", 0);
+	CheckFormatOnUnitSelect("sub_level_1_padding_right_units", "sub_level_1_padding_right", 0);
+	CheckFormatOnUnitSelect("sub_level_1_padding_bottom_units", "sub_level_1_padding_bottom", 0);
+	CheckFormatOnUnitSelect("sub_level_1_padding_left_units", "sub_level_1_padding_left", 0);
+	CheckFormatOnUnitSelect("sub_level_1_offset_top_units", "sub_level_1_offset_top", 0);
+	CheckFormatOnUnitSelect("sub_level_1_offset_left_units", "sub_level_1_offset_left", 0);
+	CheckFormatOnUnitSelect("sub_level_2_offset_top_units", "sub_level_2_offset_top", 0);
+	CheckFormatOnUnitSelect("sub_level_2_offset_left_units", "sub_level_2_offset_left", 0);
+	CheckFormatOnUnitSelect("sub_level_2_item_width_units", "sub_level_2_item_width", 0);
+	CheckFormatOnUnitSelect("sub_level_2_item_height_units", "sub_level_2_item_height", 2);
+	CheckFormatOnUnitSelect("sub_level_2_padding_top_units", "sub_level_2_padding_top", 0);
+	CheckFormatOnUnitSelect("sub_level_2_padding_right_units", "sub_level_2_padding_right", 0);
+	CheckFormatOnUnitSelect("sub_level_2_padding_bottom_units", "sub_level_2_padding_bottom", 0);
+	CheckFormatOnUnitSelect("sub_level_2_padding_left_units", "sub_level_2_padding_left", 0);
+	
+	CheckFormatOnUnitSelect("top_level_item_spacing_units", "top_level_item_spacing", 0);
+	CheckFormatOnUnitSelect("sub_level_1_item_spacing_units", "sub_level_1_item_spacing", 0);
+	CheckFormatOnUnitSelect("sub_level_2_item_spacing_units", "sub_level_2_item_spacing", 0);
 	
 	if (document.getElementById("top_level_item_width").value == _NOT_SET_)
 		document.getElementById("top_level_item_width").className = "not_set";
 	else
 		document.getElementById("top_level_item_width").className = "";
+	if (document.getElementById("sub_level_1_item_width").value == _NOT_SET_)
+		document.getElementById("sub_level_1_item_width").className = "not_set";
+	else
+		document.getElementById("sub_level_1_item_width").className = "";
+		
+	if (document.getElementById("sub_level_2_item_width").value == _NOT_SET_)
+		document.getElementById("sub_level_2_item_width").className = "not_set";
+	else
+		document.getElementById("sub_level_2_item_width").className = "";
+		
 	if (document.getElementById("top_level_item_height").value == _NOT_SET_)
 		document.getElementById("top_level_item_height").className = "not_set";
 	else
 		document.getElementById("top_level_item_height").className = "";
-	if (document.getElementById("sub_level_item_height").value == _NOT_SET_)
-		document.getElementById("sub_level_item_height").className = "not_set";
+	if (document.getElementById("sub_level_1_item_height").value == _NOT_SET_)
+		document.getElementById("sub_level_1_item_height").className = "not_set";
 	else
-		document.getElementById("sub_level_item_height").className = "";
+		document.getElementById("sub_level_1_item_height").className = "";
+	if (document.getElementById("sub_level_2_item_height").value == _NOT_SET_)
+		document.getElementById("sub_level_2_item_height").className = "not_set";
+	else
+		document.getElementById("sub_level_2_item_height").className = "";
 	if (document.getElementById("menu_top").value == _NOT_SET_)
 		document.getElementById("menu_top").className = "not_set";
 	else
@@ -228,14 +266,93 @@ function InitializeForm()
 		document.getElementById("menu_right").className = "not_set";
 	else
 		document.getElementById("menu_right").className = "";
-	if (document.getElementById("sub_level_offset_top").value == _NOT_SET_)
-		document.getElementById("sub_level_offset_top").className = "not_set";
+	if (document.getElementById("sub_level_1_offset_top").value == _NOT_SET_)
+		document.getElementById("sub_level_1_offset_top").className = "not_set";
 	else
-		document.getElementById("sub_level_offset_top").className = "";
-	if (document.getElementById("sub_level_offset_left").value == _NOT_SET_)
-		document.getElementById("sub_level_offset_left").className = "not_set";
+		document.getElementById("sub_level_1_offset_top").className = "";
+	if (document.getElementById("sub_level_2_offset_top").value == _NOT_SET_)
+		document.getElementById("sub_level_2_offset_top").className = "not_set";
 	else
-		document.getElementById("sub_level_offset_left").className = "";
+		document.getElementById("sub_level_2_offset_top").className = "";
+	if (document.getElementById("sub_level_1_offset_left").value == _NOT_SET_)
+		document.getElementById("sub_level_1_offset_left").className = "not_set";
+	else
+		document.getElementById("sub_level_1_offset_left").className = "";
+	if (document.getElementById("sub_level_2_offset_left").value == _NOT_SET_)
+		document.getElementById("sub_level_2_offset_left").className = "not_set";
+	else
+		document.getElementById("sub_level_2_offset_left").className = "";
+		
+	if (document.getElementById("top_level_item_spacing").value == _NOT_SET_)
+		document.getElementById("top_level_item_spacing").className = "not_set";
+	else
+		document.getElementById("top_level_item_spacing").className = "";
+	if (document.getElementById("sub_level_1_item_spacing").value == _NOT_SET_)
+		document.getElementById("sub_level_1_item_spacing").className = "not_set";
+	else
+		document.getElementById("sub_level_1_item_spacing").className = "";
+	if (document.getElementById("sub_level_2_item_spacing").value == _NOT_SET_)
+		document.getElementById("sub_level_2_item_spacing").className = "not_set";
+	else
+		document.getElementById("sub_level_2_item_spacing").className = "";
+		
+	if (document.getElementById("top_level_padding_top").value == _NOT_SET_)
+		document.getElementById("top_level_padding_top").className = "not_set";
+	else
+		document.getElementById("top_level_padding_top").className = "";
+	if (document.getElementById("top_level_padding_right").value == _NOT_SET_)
+		document.getElementById("top_level_padding_right").className = "not_set";
+	else
+		document.getElementById("top_level_padding_right").className = "";
+	if (document.getElementById("top_level_padding_bottom").value == _NOT_SET_)
+		document.getElementById("top_level_padding_bottom").className = "not_set";
+	else
+		document.getElementById("top_level_padding_bottom").className = "";
+	if (document.getElementById("top_level_padding_left").value == _NOT_SET_)
+		document.getElementById("top_level_padding_left").className = "not_set";
+	else
+		document.getElementById("top_level_padding_left").className = "";
+		
+	if (document.getElementById("sub_level_1_padding_top").value == _NOT_SET_)
+		document.getElementById("sub_level_1_padding_top").className = "not_set";
+	else
+		document.getElementById("sub_level_1_padding_top").className = "";
+	if (document.getElementById("sub_level_1_padding_right").value == _NOT_SET_)
+		document.getElementById("sub_level_1_padding_right").className = "not_set";
+	else
+		document.getElementById("sub_level_1_padding_right").className = "";
+	if (document.getElementById("sub_level_1_padding_bottom").value == _NOT_SET_)
+		document.getElementById("sub_level_1_padding_bottom").className = "not_set";
+	else
+		document.getElementById("sub_level_1_padding_bottom").className = "";
+	if (document.getElementById("sub_level_1_padding_left").value == _NOT_SET_)
+		document.getElementById("sub_level_1_padding_left").className = "not_set";
+	else
+		document.getElementById("sub_level_1_padding_left").className = "";
+		
+	if (document.getElementById("sub_level_2_padding_top").value == _NOT_SET_)
+		document.getElementById("sub_level_2_padding_top").className = "not_set";
+	else
+		document.getElementById("sub_level_2_padding_top").className = "";
+	if (document.getElementById("sub_level_2_padding_right").value == _NOT_SET_)
+		document.getElementById("sub_level_2_padding_right").className = "not_set";
+	else
+		document.getElementById("sub_level_2_padding_right").className = "";
+	if (document.getElementById("sub_level_2_padding_bottom").value == _NOT_SET_)
+		document.getElementById("sub_level_2_padding_bottom").className = "not_set";
+	else
+		document.getElementById("sub_level_2_padding_bottom").className = "";
+	if (document.getElementById("sub_level_2_padding_left").value == _NOT_SET_)
+		document.getElementById("sub_level_2_padding_left").className = "not_set";
+	else
+		document.getElementById("sub_level_2_padding_left").className = "";
+		
+	if (document.getElementById("OrientationGroup_0").checked)
+		LoadOrientationDefaults('vertical');
+	else if (document.getElementById("OrientationGroup_1").checked)
+		LoadOrientationDefaults('horizontal_fixed_width');
+	else if (document.getElementById("OrientationGroup_2").checked)
+		LoadOrientationDefaults('horizontal_variable_width');
 }
 
 function SaveMenuParams()
@@ -246,6 +363,7 @@ function SaveMenuParams()
 }
 function CompleteSaveMenuParams(response)
 {
+//alert(response);
 	if (response == 1)
 		popup_msg.status_msg = EDIT_JS_MENU_PARAMETERS_SAVE_SUCCESS_MSG;
 	else
