@@ -10,6 +10,7 @@
 // 
 
 var mTimer;
+var lockoutChangeCheck = true;
 
 var browser = BrowserDetect.browser;
 var browser_version = BrowserDetect.version;
@@ -33,6 +34,19 @@ function CompleteLoadFile(data)
 {
 //	alert(data);
 	CKEDITOR.instances['editorContainer'].setData(data);
+	
+	mTimer = setTimeout("StartChangeCheckTimer();", 4000);
+	bwb_ckeditor.commands.save.disable();
+}
+
+function StartChangeCheckTimer()
+{
+	bwb_ckeditor.commands.save.disable();
+	saved = true;
+	window.parent.SetWorkSavedNotSaved(true);
+	bwb_ckeditor.resetDirty();
+	mTimerCheckDirty = setInterval("somethingChanged();", 8000);
+	lockoutChangeCheck = false;
 }
 
 function Save(action)
@@ -51,7 +65,6 @@ function Save(action)
 	popup_msg.top_offset = 0;
 	popup_msg.left_offset = 500;
 	popup_msg.ShowPopupMsg();
-	
 	$.post( "save_file.php", { file_name: file_name, folder: folder, file_content: file_content, action: action } ).done(CompleteSave) ;
 }
 function CompleteSave(data)	{
@@ -76,7 +89,7 @@ function RevertConfirm()
 	
 	popup_msg.popup_msg_cell = EDITOR_REVERT_FILE_CONFIRM_1_MSG + " <b>" + file_name + "</b> " + EDITOR_REVERT_FILE_CONFIRM_2_MSG;
 	document.getElementById("popup_button_2_span").onclick = function() { Revert(); };
-	document.getElementById("popup_button_1_span").onclick = function () { HidePopupMsg(); };
+	document.getElementById("popup_button_1_span").onclick = function () { popup_msg.HidePopupMsg(); };
 	popup_msg.ShowPopupMsg();
 }
 function Revert()
@@ -90,10 +103,12 @@ function Revert()
 }
 function CompleteRevert(data)
 {
-	if ((data == "No draft found") || (data == "Error: no folder specified") || (data == "Error opening file"))
+	if ((data == "Error: no folder specified") || (data == "Error opening file"))
 		popup_msg.status_msg = data;
 	else	{
 		popup_msg.status_msg = EDITOR_REVERT_COMPLETE_MSG;
+		if (data.indexOf("No draft found") == 0)
+			data = data.replace("No draft found", "");
 		CKEDITOR.instances['editorContainer'].setData(data);
 	}
 	popup_msg.popup_timeout = 2000;
@@ -131,14 +146,16 @@ function DisplayNotSavedMessage(btn)
 	popup_msg.top_offset = 0;
 	popup_msg.left_offset = 300;
 	popup_msg.popup_msg_type = 3;
-	popup_msg.popup_btn_cnt = 2;
+	popup_msg.popup_btn_cnt = 3;
 	popup_msg.popup_msg_cell = EDITOR_FILE_NOT_SAVED_MSG;
 	popup_msg.popup_button_2_span = YES_WORD;
 	popup_msg.popup_button_1_span = NO_WORD;
+	popup_msg.popup_button_3_span = CANCEL_WORD;
 	popup_msg.popup_timeout = -1;
 	popup_msg.ShowPopupMsg();
 	document.getElementById("popup_button_2_span").onclick = function () { SaveBeforeMain(); };
 	document.getElementById("popup_button_1_span").onclick = function () { DoMainMenuAction(); };
+	document.getElementById("popup_button_3_span").onclick = function () { popup_msg.HidePopupMsg(); };
 }
 
 function SaveBeforeMain()
@@ -165,7 +182,7 @@ function ShowSaveAsMsg()
 	popup_msg.popup_button_1_span = OK_WORD;
 	popup_msg.popup_timeout = -1;
 	popup_msg.ShowPopupMsg();
-	document.getElementById("popup_button_2_span").onclick = function () { HidePopupMsg(); };
+	document.getElementById("popup_button_2_span").onclick = function () { popup_msg.HidePopupMsg(); };
 	document.getElementById("popup_button_1_span").onclick = function () { SaveAs(); };
 }
 
@@ -173,12 +190,13 @@ function SaveAs()
 {
 	var old_file_name = file_name;
 	var new_file_name = document.getElementById("popup_prompt_textbox").value;
+
 	if ((new_file_name == null) || (new_file_name == ""))
 	{
 		alert(EDITOR_FILE_BLANK_ERR);
 		return;
 	}
-	var page_exists;
+
 	var new_page_name;
 	var old_page_name;
 	var old_ext;
@@ -194,35 +212,38 @@ function SaveAs()
 	else
 		new_ext = new_file_parts[1];
 		
-	if (folder == "pages")	{
+	var old_file_path_parts = old_file_name.split("/");
+	var sub_path = old_file_name.replace(old_file_path_parts[old_file_path_parts.length - 1], "");
+		
+	if ((folder.indexOf(BWB_SCRIPTS_DIR) !== 0) && (folder.indexOf(BWB_SCRIPTS_DIR) !== 1) && (folder.indexOf(BWB_LIB_DIR) !== 0) && (folder.indexOf(BWB_LIB_DIR) !== 1))	{
 		new_page_name = new_file_name.replace(".php", "");
 		if ((old_ext == "php") && (new_ext == "php"))
-			$.post( "check_page_exists.php", { page_name: new_page_name, special: 0 }, function(data){ page_exists = data; }, "text" ) ;
+			$.post( "check_page_exists.php", { page_name: new_page_name, special: 0 }, function(data){ CompleteSaveAs(data, old_page_name, new_file_name, old_ext, new_ext, sub_path, old_page_name, new_page_name); }, "text" ) ;
 		else
-			$.post( "check_file_exists.php", { file_name: new_file_name, folder: folder }, function(data){ page_exists = data; }, "text" ) ;
+			$.post( "check_file_exists.php", { file_name: new_file_name, folder: folder }, function(data){ CompleteSaveAs(data, old_page_name, new_file_name, old_ext, new_ext, sub_path, old_page_name, new_page_name); }, "text" ) ;
 	}
 	else
-		$.post( "check_file_exists.php", { file_name: new_file_name, folder: folder }, function(data){ page_exists = data; }, "text" ) ;
-		
-	if (page_exists == "1")
+		$.post( "check_file_exists.php", { file_name: new_file_name, folder: folder }, function(data){CompleteSaveAs(data, old_page_name, new_file_name, old_ext, new_ext, sub_path, old_page_name, new_page_name); }, "text" ) ;
+}
+function CompleteSaveAs(data, old_page_name, new_file_name, old_ext, new_ext, sub_path, old_page_name, new_page_name)
+{
+	if (data == "1")
 		alert(EDITOR_FILE_ALREADY_EXISTS_1_ERR + " " + new_file_name + " " + EDITOR_FILE_ALREADY_EXISTS_2_ERR);
 	else
 	{
-		
-		if ((folder == "pages") && (old_ext == "php") && (new_ext == "php"))
+		if (((folder.indexOf(BWB_SCRIPTS_DIR) !== 0) && (folder.indexOf(BWB_SCRIPTS_DIR) !== 1) && (folder.indexOf(BWB_LIB_DIR) !== 0) && (folder.indexOf(BWB_LIB_DIR) !== 1)) && (old_ext == "php") && (new_ext == "php"))
 			$.post( "copy_rename_page.php", { page_name: old_page_name, new_name: new_page_name, copy_mode: "copy", overwrite: 0, overwrite_content_only: 0, create_new_template: 0 } ) ;	
 		
 		document.getElementById("page_name_label").innerHTML = new_file_name;
-	
-		file_name = new_file_name;	
+		
+		file_name = sub_path + new_file_name;
 		Save('publish');
 		
 		var new_title = file_name + " - Editing | Breeze Website Builder";
 		document.title = new_title;
 		window.parent.document.title = document.title;
+		popup_msg.HidePopupMsg();
 	}
-	
-	HidePopupMsg();
 }
 
 ///////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -238,15 +259,24 @@ function DeleteConfirm()
 	
 	popup_msg.popup_msg_cell = EDITOR_DELETE_FILE_CONFIRM_1_MSG + " <b>" + file_name + "</b> " + EDITOR_DELETE_FILE_CONFIRM_2_MSG;
 	document.getElementById("popup_button_2_span").onclick = function() { DeletePage(); };
-	document.getElementById("popup_button_1_span").onclick = function () { HidePopupMsg(); };
+	document.getElementById("popup_button_1_span").onclick = function () { popup_msg.HidePopupMsg(); };
 	popup_msg.ShowPopupMsg();
 }
 
 function DeletePage()
 {
+	if ((typeof redirect == 'undefined') || (redirect == ""))
+		redirect = "edit_file_select.php";
 	var page_name = file_name.replace(".php", "");
-	HidePopupMsg();
-	var url = "delete_page.php?page_name=" + page_name + "&file_name=" + file_name + "&folder=" + folder + "&redirect=edit_file_select.php";
+	popup_msg.HidePopupMsg();
+	if (page_name.indexOf("/") > -1)	{
+		var page_name_arr = page_name.split("/");
+		page_name = page_name_arr[page_name_arr.length - 1];
+	}
+	page_name = page_name.replace("/", "");
+	var url_file_name = file_name.replace(/\//g, "%2F");
+	var url_folder = folder.replace("/", "%2F");
+	var url = "delete_page.php?page_name=" + page_name + "&file_name=" + url_file_name + "&folder=" + url_folder + "&redirect=" + redirect;
 	window.location = url;
 }
 
