@@ -21,6 +21,13 @@
 // Added code to hide/show new NEW SESSION button. Fixed bug with sliver of LOGOUT button showing with collapsed header.
 // Revised: 1/18/2016	ELL
 // Added ability to put custom in any button group.
+// Revined: 4/18/2016	ELL
+// Fixed bug with menu groups locking up due to plugin_button = notdefined.
+// Removed "Manage Head Code" from main menu which is now consolidated with "Edit Head Code".  Renamed "Edit Head Code" to "Manage Head Code".
+// "Manage Head Code" now exists as "Manage Custom Head Code" under "Manage Head Code".
+// Added ability to switch CSS menu tools and JS menu tools on or off.
+// Revised: 11/22/2017	ELL
+// Made "Users & Site Options" button modal switchig to "Manage My Account" when logged in as non-admin but at least user access level.
 // 
 // 
 var browser = BrowserDetect.browser;
@@ -167,9 +174,11 @@ function ExpandContentFunctions()
 	for (i = 0; i < plugin_button_cnt; i++)
 	{
 		plugin_button = plugin_buttons[i];
-		if ((plugin_button[0] == i) && (plugin_button[1] == "content_functions"))	{
-			btn_custom_str = "btn_custom_" + parseInt(i);
-			document.getElementById(btn_custom_str).style.height = strHeight;
+		if (typeof plugin_button != 'undefined')	{
+			if ((plugin_button[0] == i) && (plugin_button[1] == "content_functions"))	{
+				btn_custom_str = "btn_custom_" + parseInt(i);
+				document.getElementById(btn_custom_str).style.height = strHeight;
+			}
 		}
 	}
 	
@@ -194,9 +203,11 @@ function ExpandContentFunctions()
 		for (i = 0; i < plugin_button_cnt; i++)
 		{
 			plugin_button = plugin_buttons[i];
-			if ((plugin_button[0] == i) && (plugin_button[1] == "content_functions"))	{
-				btn_custom_str = "btn_custom_" + parseInt(i);
-				document.getElementById(btn_custom_str).style.display = inherit;
+			if (typeof plugin_button != 'undefined')	{
+				if ((plugin_button[0] == i) && (plugin_button[1] == "content_functions"))	{
+					btn_custom_str = "btn_custom_" + parseInt(i);
+					document.getElementById(btn_custom_str).style.display = inherit;
+				}
 			}
 		}
 	}
@@ -232,9 +243,11 @@ function CollapseContentFunctions()
 	for (i = 0; i < plugin_button_cnt; i++)
 	{
 		plugin_button = plugin_buttons[i];
-		if ((plugin_button[0] == i) && (plugin_button[1] == "content_functions"))	{
-			btn_custom_str = "btn_custom_" + parseInt(i);
-			document.getElementById(btn_custom_str).style.height = strHeight;
+		if (typeof plugin_button != 'undefined')	{
+			if ((plugin_button[0] == i) && (plugin_button[1] == "content_functions"))	{
+				btn_custom_str = "btn_custom_" + parseInt(i);
+				document.getElementById(btn_custom_str).style.height = strHeight;
+			}
 		}
 	}
 	
@@ -251,9 +264,11 @@ function CollapseContentFunctions()
 		for (i = 0; i < plugin_button_cnt; i++)
 		{
 			plugin_button = plugin_buttons[i];
-			if ((plugin_button[0] == i) && (plugin_button[1] == "content_functions"))	{
-				btn_custom_str = "btn_custom_" + parseInt(i);
-				document.getElementById(btn_custom_str).style.display = "none";
+			if (typeof plugin_button != 'undefined')	{
+				if ((plugin_button[0] == i) && (plugin_button[1] == "content_functions"))	{
+					btn_custom_str = "btn_custom_" + parseInt(i);
+					document.getElementById(btn_custom_str).style.display = "none";
+				}
 			}
 		}
 	}
@@ -277,16 +292,16 @@ function ExpandMenuFunctions()
 		document.getElementById("btn_manage_menu_assignments").style.height = strHeight;
 		document.getElementById("btn_edit_css_menu_params").style.height = strHeight;
 		document.getElementById("btn_edit_css_menu_styles").style.height = strHeight;
-		document.getElementById("btn_edit_js_menu_params").style.height = strHeight;
-		document.getElementById("btn_edit_js_menu_styles").style.height = strHeight;
 	}
 	
 	for (i = 0; i < plugin_button_cnt; i++)
 	{
 		plugin_button = plugin_buttons[i];
-		if ((plugin_button[0] == i) && (plugin_button[1] == "menu_functions"))	{
-			btn_custom_str = "btn_custom_" + parseInt(i);
-			document.getElementById(btn_custom_str).style.height = strHeight;
+		if (typeof plugin_button != 'undefined')	{
+			if ((plugin_button[0] == i) && (plugin_button[1] == "menu_functions"))	{
+				btn_custom_str = "btn_custom_" + parseInt(i);
+				document.getElementById(btn_custom_str).style.height = strHeight;
+			}
 		}
 	}
 	
@@ -298,16 +313,16 @@ function ExpandMenuFunctions()
 			document.getElementById("btn_manage_menu_assignments").style.display = inherit;
 			document.getElementById("btn_edit_css_menu_params").style.display = inherit;
 			document.getElementById("btn_edit_css_menu_styles").style.display = inherit;
-			document.getElementById("btn_edit_js_menu_params").style.display = inherit;
-			document.getElementById("btn_edit_js_menu_styles").style.display = inherit;
 		}
 		
 		for (i = 0; i < plugin_button_cnt; i++)
 		{
 			plugin_button = plugin_buttons[i];
-			if ((plugin_button[0] == i) && (plugin_button[1] == "menu_functions"))	{
-				btn_custom_str = "btn_custom_" + parseInt(i);
-				document.getElementById(btn_custom_str).style.display = inherit;
+			if (typeof plugin_button != 'undefined')	{
+				if ((plugin_button[0] == i) && (plugin_button[1] == "menu_functions"))	{
+					btn_custom_str = "btn_custom_" + parseInt(i);
+					document.getElementById(btn_custom_str).style.display = inherit;
+				}
 			}
 		}
 	}
@@ -330,16 +345,16 @@ function CollapseMenuFunctions()
 		document.getElementById("btn_manage_menu_assignments").style.height = strHeight;
 		document.getElementById("btn_edit_css_menu_params").style.height = strHeight;
 		document.getElementById("btn_edit_css_menu_styles").style.height = strHeight;
-		document.getElementById("btn_edit_js_menu_params").style.height = strHeight;
-		document.getElementById("btn_edit_js_menu_styles").style.height = strHeight;
 	}
 	
 	for (i = 0; i < plugin_button_cnt; i++)
 	{
 		plugin_button = plugin_buttons[i];
-		if ((plugin_button[0] == i) && (plugin_button[1] == "menu_functions"))	{
-			btn_custom_str = "btn_custom_" + parseInt(i);
-			document.getElementById(btn_custom_str).style.height = strHeight;
+		if (typeof plugin_button != 'undefined')	{
+			if ((plugin_button[0] == i) && (plugin_button[1] == "menu_functions"))	{
+				btn_custom_str = "btn_custom_" + parseInt(i);
+				document.getElementById(btn_custom_str).style.height = strHeight;
+			}
 		}
 	}
 	
@@ -349,15 +364,15 @@ function CollapseMenuFunctions()
 		document.getElementById("btn_manage_menu_assignments").style.display = "none";
 		document.getElementById("btn_edit_css_menu_params").style.display = "none";
 		document.getElementById("btn_edit_css_menu_styles").style.display = "none";
-		document.getElementById("btn_edit_js_menu_params").style.display = "none";
-		document.getElementById("btn_edit_js_menu_styles").style.display = "none";
 		
 		for (i = 0; i < plugin_button_cnt; i++)
 		{
 			plugin_button = plugin_buttons[i];
-			if ((plugin_button[0] == i) && (plugin_button[1] == "menu_functions"))	{
-				btn_custom_str = "btn_custom_" + parseInt(i);
-				document.getElementById(btn_custom_str).style.display = "none";
+			if (typeof plugin_button != 'undefined')	{
+				if ((plugin_button[0] == i) && (plugin_button[1] == "menu_functions"))	{
+					btn_custom_str = "btn_custom_" + parseInt(i);
+					document.getElementById(btn_custom_str).style.display = "none";
+				}
 			}
 		}
 	}
@@ -377,15 +392,16 @@ function ExpandStyleFunctions()
 	var plugin_button;
 	document.getElementById("btn_edit_styles").style.height = strHeight;
 	document.getElementById("btn_edit_head_code").style.height = strHeight;
-	document.getElementById("btn_manage_head_code").style.height = strHeight;
 	document.getElementById("btn_edit_favicon").style.height = strHeight;
 	
 	for (i = 0; i < plugin_button_cnt; i++)
 	{
 		plugin_button = plugin_buttons[i];
-		if ((plugin_button[0] == i) && (plugin_button[1] == "style_functions"))	{
-			btn_custom_str = "btn_custom_" + parseInt(i);
-			document.getElementById(btn_custom_str).style.height = strHeight;
+		if (typeof plugin_button != 'undefined')	{
+			if ((plugin_button[0] == i) && (plugin_button[1] == "style_functions"))	{
+				btn_custom_str = "btn_custom_" + parseInt(i);
+				document.getElementById(btn_custom_str).style.height = strHeight;
+			}
 		}
 	}
 	
@@ -393,15 +409,16 @@ function ExpandStyleFunctions()
 	{
 		document.getElementById("btn_edit_styles").style.display = inherit;
 		document.getElementById("btn_edit_head_code").style.display = inherit;
-		document.getElementById("btn_manage_head_code").style.display = inherit;
 		document.getElementById("btn_edit_favicon").style.display = inherit;
 		
 		for (i = 0; i < plugin_button_cnt; i++)
 		{
 			plugin_button = plugin_buttons[i];
-			if ((plugin_button[0] == i) && (plugin_button[1] == "style_functions"))	{
-				btn_custom_str = "btn_custom_" + parseInt(i);
-				document.getElementById(btn_custom_str).style.display = inherit;
+			if (typeof plugin_button != 'undefined')	{
+				if ((plugin_button[0] == i) && (plugin_button[1] == "style_functions"))	{
+					btn_custom_str = "btn_custom_" + parseInt(i);
+					document.getElementById(btn_custom_str).style.display = inherit;
+				}
 			}
 		}
 	}
@@ -420,15 +437,16 @@ function CollapseStyleFunctions()
 	var plugin_button;
 	document.getElementById("btn_edit_styles").style.height = strHeight;
 	document.getElementById("btn_edit_head_code").style.height = strHeight;
-	document.getElementById("btn_manage_head_code").style.height = strHeight;
 	document.getElementById("btn_edit_favicon").style.height = strHeight;
 	
 	for (i = 0; i < plugin_button_cnt; i++)
 	{
 		plugin_button = plugin_buttons[i];
-		if ((plugin_button[0] == i) && (plugin_button[1] == "style_functions"))	{
-			btn_custom_str = "btn_custom_" + parseInt(i);
-			document.getElementById(btn_custom_str).style.height = strHeight;
+		if (typeof plugin_button != 'undefined')	{
+			if ((plugin_button[0] == i) && (plugin_button[1] == "style_functions"))	{
+				btn_custom_str = "btn_custom_" + parseInt(i);
+				document.getElementById(btn_custom_str).style.height = strHeight;
+			}
 		}
 	}
 	
@@ -436,15 +454,16 @@ function CollapseStyleFunctions()
 	{
 		document.getElementById("btn_edit_styles").style.display = "none";
 		document.getElementById("btn_edit_head_code").style.display = "none";
-		document.getElementById("btn_manage_head_code").style.display = "none";
 		document.getElementById("btn_edit_favicon").style.display = "none";
 		
 		for (i = 0; i < plugin_button_cnt; i++)
 		{
 			plugin_button = plugin_buttons[i];
-			if ((plugin_button[0] == i) && (plugin_button[1] == "style_functions"))	{
-				btn_custom_str = "btn_custom_" + parseInt(i);
-				document.getElementById(btn_custom_str).style.display = "none";
+			if (typeof plugin_button != 'undefined')	{
+				if ((plugin_button[0] == i) && (plugin_button[1] == "style_functions"))	{
+					btn_custom_str = "btn_custom_" + parseInt(i);
+					document.getElementById(btn_custom_str).style.display = "none";
+				}
 			}
 		}
 	}
@@ -477,9 +496,11 @@ function ExpandPageFunctions()
 	for (i = 0; i < plugin_button_cnt; i++)
 	{
 		plugin_button = plugin_buttons[i];
-		if ((plugin_button[0] == i) && (plugin_button[1] == "page_functions"))	{
-			btn_custom_str = "btn_custom_" + parseInt(i);
-			document.getElementById(btn_custom_str).style.height = strHeight;
+		if (typeof plugin_button != 'undefined')	{
+			if ((plugin_button[0] == i) && (plugin_button[1] == "page_functions"))	{
+				btn_custom_str = "btn_custom_" + parseInt(i);
+				document.getElementById(btn_custom_str).style.height = strHeight;
+			}
 		}
 	}
 	
@@ -500,9 +521,11 @@ function ExpandPageFunctions()
 		for (i = 0; i < plugin_button_cnt; i++)
 		{
 			plugin_button = plugin_buttons[i];
-			if ((plugin_button[0] == i) && (plugin_button[1] == "page_functions"))	{
-				btn_custom_str = "btn_custom_" + parseInt(i);
-				document.getElementById(btn_custom_str).style.display = inherit;
+			if (typeof plugin_button != 'undefined')	{
+				if ((plugin_button[0] == i) && (plugin_button[1] == "page_functions"))	{
+					btn_custom_str = "btn_custom_" + parseInt(i);
+					document.getElementById(btn_custom_str).style.display = inherit;
+				}
 			}
 		}
 	}
@@ -534,9 +557,11 @@ function CollapsePageFunctions()
 	for (i = 0; i < plugin_button_cnt; i++)
 	{
 		plugin_button = plugin_buttons[i];
-		if ((plugin_button[0] == i) && (plugin_button[1] == "page_functions"))	{
-			btn_custom_str = "btn_custom_" + parseInt(i);
-			document.getElementById(btn_custom_str).style.height = strHeight;
+		if (typeof plugin_button != 'undefined')	{
+			if ((plugin_button[0] == i) && (plugin_button[1] == "page_functions"))	{
+				btn_custom_str = "btn_custom_" + parseInt(i);
+				document.getElementById(btn_custom_str).style.height = strHeight;
+			}
 		}
 	}
 	
@@ -554,9 +579,11 @@ function CollapsePageFunctions()
 		for (i = 0; i < plugin_button_cnt; i++)
 		{
 			plugin_button = plugin_buttons[i];
-			if ((plugin_button[0] == i) && (plugin_button[1] == "page_functions"))	{
-				btn_custom_str = "btn_custom_" + parseInt(i);
-				document.getElementById(btn_custom_str).style.display = "none";
+			if (typeof plugin_button != 'undefined')	{
+				if ((plugin_button[0] == i) && (plugin_button[1] == "page_functions"))	{
+					btn_custom_str = "btn_custom_" + parseInt(i);
+					document.getElementById(btn_custom_str).style.display = "none";
+				}
 			}
 		}
 	}
@@ -580,16 +607,17 @@ function ExpandOtherFunctions()
 	{
 		if (enable_wizard == 1)
 			document.getElementById("btn_show_wizard").style.height = strHeight;;
-		if (access_level == "admin")
-			document.getElementById("btn_users_site_options").style.height = strHeight;
+		document.getElementById("btn_users_site_options").style.height = strHeight;
 	}
 	
 	for (i = 0; i < plugin_button_cnt; i++)
 	{
 		plugin_button = plugin_buttons[i];
-		if ((plugin_button[0] == i) && ((plugin_button[1] == "other_functions") || (plugin_button[1] == "")))	{
-			btn_custom_str = "btn_custom_" + parseInt(i);
-			document.getElementById(btn_custom_str).style.height = strHeight;
+		if (typeof plugin_button != 'undefined')	{
+			if ((plugin_button[0] == i) && ((plugin_button[1] == "other_functions") || (plugin_button[1] == "")))	{
+				btn_custom_str = "btn_custom_" + parseInt(i);
+				document.getElementById(btn_custom_str).style.height = strHeight;
+			}
 		}
 	}
 	
@@ -599,16 +627,17 @@ function ExpandOtherFunctions()
 		{
 			if (enable_wizard == 1)
 				document.getElementById("btn_show_wizard").style.display = inherit;
-			if (access_level == "admin")
-				document.getElementById("btn_users_site_options").style.display = inherit;
+			document.getElementById("btn_users_site_options").style.display = inherit;
 		}
 			
 		for (i = 0; i < plugin_button_cnt; i++)
 		{
 			plugin_button = plugin_buttons[i];
-			if ((plugin_button[0] == i) && ((plugin_button[1] == "other_functions") || (plugin_button[1] == "")))	{
-				btn_custom_str = "btn_custom_" + parseInt(i);
-				document.getElementById(btn_custom_str).style.display = inherit;
+			if (typeof plugin_button != 'undefined')	{
+				if ((plugin_button[0] == i) && ((plugin_button[1] == "other_functions") || (plugin_button[1] == "")))	{
+					btn_custom_str = "btn_custom_" + parseInt(i);
+					document.getElementById(btn_custom_str).style.display = inherit;
+				}
 			}
 		}
 	}
@@ -630,16 +659,17 @@ function CollapseOtherFunctions()
 	{
 		if (enable_wizard == 1)
 			document.getElementById("btn_show_wizard").style.height = strHeight;
-		if (access_level == "admin")
-			document.getElementById("btn_users_site_options").style.height = strHeight;
+		document.getElementById("btn_users_site_options").style.height = strHeight;
 	}
 		
 	for (i = 0; i < plugin_button_cnt; i++)
 	{
 		plugin_button = plugin_buttons[i];
-		if ((plugin_button[0] == i) && ((plugin_button[1] == "other_functions") || (plugin_button[1] == "")))	{
-			btn_custom_str = "btn_custom_" + parseInt(i);
-			document.getElementById(btn_custom_str).style.height = strHeight;
+		if (typeof plugin_button != 'undefined')	{
+			if ((plugin_button[0] == i) && ((plugin_button[1] == "other_functions") || (plugin_button[1] == "")))	{
+				btn_custom_str = "btn_custom_" + parseInt(i);
+				document.getElementById(btn_custom_str).style.height = strHeight;
+			}
 		}
 	}
 	
@@ -655,9 +685,11 @@ function CollapseOtherFunctions()
 		for (i = 0; i < plugin_button_cnt; i++)
 		{
 			plugin_button = plugin_buttons[i];
-			if ((plugin_button[0] == i) && ((plugin_button[1] == "other_functions") || (plugin_button[1] == "")))	{
-				btn_custom_str = "btn_custom_" + parseInt(i);
-				document.getElementById(btn_custom_str).style.display = "none";
+			if (typeof plugin_button != 'undefined')	{
+				if ((plugin_button[0] == i) && ((plugin_button[1] == "other_functions") || (plugin_button[1] == "")))	{
+					btn_custom_str = "btn_custom_" + parseInt(i);
+					document.getElementById(btn_custom_str).style.display = "none";
+				}
 			}
 		}
 	}
@@ -860,11 +892,8 @@ function SetBtnDown(btn)
 	document.getElementById("btn_manage_menu_assignments").className =	"button_top_level";
 	document.getElementById("btn_edit_css_menu_params").className =	"button_top_level";
 	document.getElementById("btn_edit_css_menu_styles").className =	"button_top_level";
-	document.getElementById("btn_edit_js_menu_params").className =	"button_top_level";
-	document.getElementById("btn_edit_js_menu_styles").className =	"button_top_level";
 	document.getElementById("btn_edit_styles").className =	"button_top_level";
 	document.getElementById("btn_edit_head_code").className =	"button_top_level";
-	document.getElementById("btn_manage_head_code").className =	"button_top_level";
 	document.getElementById("btn_edit_favicon").className =	"button_top_level";
 	document.getElementById("btn_edit_page_titles").className =	"button_top_level";
 	document.getElementById("btn_edit_meta_tags").className =	"button_top_level";
