@@ -11,6 +11,9 @@
 // Converted from HTML/PHP POST application to AJAX application.
 // Revised: 12/2/2015	ELL
 // Fixed bug save not working when not all border areas are present on a page.
+// Revised: 10/28/2016	ELL
+// Added list of pages to auto-populate suffix for new border areas to make creating border areas with meaningful names as default behavior,
+// and to allow for automatic assignment at border area creation.
 
 var param_array = {'popup_msg_type' : 1, 'status_msg' : '', 'popup_timeout' : -1};
 var popup_msg = new PopupMsg(param_array);
@@ -24,6 +27,13 @@ function OpenHelpWindow()
 	window.open("http://breezewebsitebuilder.com/docs/cms/help.html#manage_special", "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
 }
 
+function UpdateSuffix(suffix)
+{
+	document.getElementById("suffix").value = suffix;
+	if (suffix == "")
+		GetNextIndex(border_area);
+}
+
 function DeleteConfirm()
 {
 	popup_msg.top_offset = 0;
@@ -36,13 +46,13 @@ function DeleteConfirm()
 	popup_msg.popup_timeout = -1;
 	popup_msg.ShowPopupMsg();
 	document.getElementById("popup_button_2_span").onclick = function () { DeletePage(); };
-	document.getElementById("popup_button_1_span").onclick = function () { HidePopupMsg(); };
+	document.getElementById("popup_button_1_span").onclick = function () { popup_msg.HidePopupMsg(); };
 }
 
 function DeletePage()
 {
 	var area_name = document.getElementById("area_name_delete").value;
-	HidePopupMsg();
+	popup_msg.HidePopupMsg();
 	$.post( "delete_border_area.php", { area_name: area_name, redirect: "-no redirect-" } ).done(CompleteDeletePage) ;
 }
 function CompleteDeletePage(data)
@@ -98,7 +108,7 @@ function GetAreaFromName(page_name)
 ///////////////////////////////////////////////////////////////////////////////////////////////////////////
 function GetBorderAreas()
 {
-	$.post( "get_rows.php", { table: "page_data_special", order_by: "page_name" } ).done(PopulateBorderAreas) ;
+	$.post( "get_rows.php", { table: "page_data_special", order_by: "page_name", where: "page_name NOT LIKE 'mm_%'" } ).done(PopulateBorderAreas) ;
 }
 function PopulateBorderAreas(data)
 {
@@ -344,6 +354,8 @@ function AssignBordersComplete(data)
 	popup_msg.popup_timeout = 3000;
 	if (data_arr[0] > 0)
 		popup_msg.status_msg = MANAGE_CUSTOM_BORDER_AREA_ASSIGNED_1_MSG + " <b>" + data_arr[1] + "</b> " + MANAGE_CUSTOM_BORDER_AREA_ASSIGNED_2_MSG;
+	else if (data_arr[0] == 0)
+		popup_msg.status_msg = MANAGE_CUSTOM_BORDER_AREA_ALREADY_ASSIGNED_1_ERR + " <b>" + data_arr[1] + "</b> " + MANAGE_CUSTOM_BORDER_AREA_ALREADY_ASSIGNED_3_ERR;
 	else
 		popup_msg.status_msg = MANAGE_CUSTOM_BORDER_AREA_ASSIGNED_1_ERR + " <b>" + data_arr[1] + "</b> " + MANAGE_CUSTOM_BORDER_AREA_ASSIGNED_2_ERR;
 		
@@ -354,24 +366,41 @@ function AssignBordersComplete(data)
 ///////////////////////////////////////////////////////////////////////////////////////////////////////////
 function GetNextIndex(area_type)
 {
-	$.post( "get_next_index.php", { area_type: area_type } ).done(PopulateIndex) ;
+	if ((document.getElementById("suffix").value == "") || !isNaN(parseFloat(document.getElementById("suffix").value)))
+		$.post( "get_next_index.php", { area_type: area_type } ).done(PopulateIndex) ;
 }
 function PopulateIndex(data)
 {
-//	alert(data);
 	var data_arr = new Array();
 	data_arr = data.split("@@@@@");
 	var next_index = data_arr[0];
-	var area_type_suffix = data_arr[1] + "_suffix";
-	document.getElementById(area_type_suffix).value = next_index;
+	document.getElementById("suffix").value = next_index;
 }
 
 ///////////////////////////////////////////////////////////////////////////////////////////////////////////
-function AddBorderArea(area_type)
+function AddBorderArea()
 {
-	var suffix_el = area_type + "_suffix";
-	var suffix = document.getElementById(suffix_el).value;
-	$.post( "add_border_area.php", { area_type: area_type, suffix: suffix } ).done(CompleteAddBorderArea) ;
+	if (document.getElementById("btn_add_border_area").className == "button_console_add_disabled")
+		return;
+
+	if (document.getElementById("suffix").value == "")	{
+		document.getElementById("suffix").className = "highlight";
+		return;
+	}
+
+	var area_type_els = document.getElementsByName("area_type");
+	var area_type = "";
+	for (var i = 0; i < area_type_els.length; i++)
+	{
+		if (area_type_els[i].checked == true)
+			area_type = area_type_els[i].value;
+	}
+	
+	var suffix = document.getElementById("suffix").value;
+	var assign_border = 0;
+	if (document.getElementById("suffix").value == document.getElementById("new_suffix").value)
+		assign_border = 1;
+	$.post( "add_border_area.php", { area_type: area_type, suffix: suffix, assign_border: assign_border } ).done(CompleteAddBorderArea) ;
 }
 function CompleteAddBorderArea(data)
 {
@@ -421,17 +450,23 @@ function CompleteRenameBorderArea(data)
 	GetBorderAreaAssignments();
 }
 
+function SetBtnDownState(down_btn)
+{
+	var area_type_els = document.getElementsByName("area_type");
+	for (var i = 0; i < area_type_els.length; i++)
+	{
+		if (area_type_els[i].checked == true)
+			area_type_els[i].parentNode.className = "radio_button checked";
+		else
+			area_type_els[i].parentNode.className = "radio_button";
+	}
+}
+
 ///////////////////////////////////////////////////////////////////////////////////////////////////////////
 function InitializeConsole()
 {
 	GetBorderAreas();
 	GetBorderAreaAssignments();
-	GetNextIndex("right");
-	GetNextIndex("left");
-	GetNextIndex("top");
-	GetNextIndex("bottom");
-	GetNextIndex("header");
-	GetNextIndex("footer");
 	setTimeout("InitializePrefix();", 500);
 	
 }
