@@ -27,8 +27,6 @@ var popup_msg = new PopupMsg(param_array);
 
 window.parent.document.title = document.title;
 
-var no_plefix = 1;
-
 function OpenHelpWindow(topic)
 {
 	window.open("http://breezewebsitebuilder.com/docs/cms/help.html#" + topic, "Help", "scrollbars=1,resizable=1,status=0,toolbar=0,menubar=0,location=0,height=700,width=800");
@@ -48,7 +46,7 @@ function DeleteUserConfirm()
 	popup_msg.popup_timeout = -1;
 	popup_msg.ShowPopupMsg();
 	document.getElementById("popup_button_2_span").onclick = function () { DeleteUser(); };
-	document.getElementById("popup_button_1_span").onclick = function () { HidePopupMsg(); };
+	document.getElementById("popup_button_1_span").onclick = function () { popup_msg.HidePopupMsg(); };
 }
 function DeleteUser()
 {
@@ -67,7 +65,8 @@ function CompleteDeleteUser(data)
 	popup_msg.ShowPopupMsg();
 	
 	var user_table = document.getElementById("table_delete_user").value;
-	RetrieveUserLists(user_table, false);
+	var user_sort = document.getElementById("user_sort").value;
+	RetrieveUserLists(user_table, false, user_sort, 1);
 }
 
 function GeneratePassword(source)
@@ -122,7 +121,7 @@ function DeleteAccessLevelConfirm()
 	popup_msg.popup_timeout = -1;
 	popup_msg.ShowPopupMsg();
 	document.getElementById("popup_button_2_span").onclick = function () { AddRemoveAccessLevel('remove'); };
-	document.getElementById("popup_button_1_span").onclick = function () { HidePopupMsg(); };
+	document.getElementById("popup_button_1_span").onclick = function () { popup_msg.HidePopupMsg(); };
 }
 
 //////////////////////////////////////////////////////////////////////////////////////
@@ -446,7 +445,7 @@ function PopulateAccessLevels(rows_str)
 	
 	var output_str = "<select name='access_level_remove' id='access_level_remove'>\n";
 	var output_str2 = "<select name='selectAccessLevel' id='selectAccessLevelNewUser'>\n";
-	var output_str3 = "<select name='selectAccessLevel' id='selectAccessLevelEdit'>\n";
+	var output_str3 = "<select name='AccessLevel' id='selectAccessLevelEdit'>\n";
 	output_str = output_str + "<option>" + _NOT_SELECTED_ + "</option>\n";
 	output_str2 = output_str2 + "<option>" + _NOT_SELECTED_ + "</option>\n";
 	output_str3 = output_str3 + "<option>" + _NOT_SELECTED_ + "</option>\n";
@@ -491,8 +490,47 @@ function PopulateAccessLevels(rows_str)
 }
 
 ////////////////////////////////////////////////////////////////////////////////////////////////////
-function RetrieveUserLists(user_table, start)
-{	
+function RetrieveUserLists(user_table, start, user_sort, no_toggle_asc_desc)
+{
+	if ((user_table == "") || (user_table == "-not selected-"))	{
+		document.getElementById("user_nav_row_top").style.display = "none";
+		document.getElementById("user_nav_row_bot").style.display = "none";
+		document.getElementById("UsersTable").innerHTML = "&nbsp;";
+		return;
+	}
+	
+	if ((typeof user_sort == "undefined") || (user_sort == ""))
+		user_sort = document.getElementById("user_sort").value;
+	else if (document.getElementById("user_sort").value != user_sort)	{
+		document.getElementById("user_sort").value = user_sort;
+		document.getElementById("user_sort_desc").value = 0;
+	}
+	else	{
+		if ((typeof no_toggle_asc_desc == "undefined") || (no_toggle_asc_desc == "") || (no_toggle_asc_desc != 1))	{
+			if (document.getElementById("user_sort_desc").value == 1)
+				document.getElementById("user_sort_desc").value = 0;
+			else	{
+				document.getElementById("user_sort_desc").value = 1;
+				if (user_sort.indexOf(","))	{
+					var user_sort_parts = user_sort.split(",");
+					user_sort = user_sort_parts[0] + " DESC, " + user_sort_parts[0] + " DESC";
+				}
+				else
+					user_sort = user_sort + " DESC";
+			}
+		}
+		else	{
+			if (document.getElementById("user_sort_desc").value == 1)	{
+				if (user_sort.indexOf(","))	{
+					var user_sort_parts = user_sort.split(",");
+					user_sort = user_sort_parts[0] + " DESC, " + user_sort_parts[0] + " DESC";
+				}
+				else
+					user_sort = user_sort + " DESC";
+			}
+		}
+	}
+		
 	popup_msg.popup_msg_type = 1;
 	popup_msg.status_msg = MANAGE_PAGE_ACCESS_RETRIEVING_USERS_MSG;
 	popup_msg.popup_timeout = -1;
@@ -508,7 +546,7 @@ function RetrieveUserLists(user_table, start)
 		xmlhttp.open("POST","populate_users.php",true);
 		xmlhttp.setRequestHeader('Content-Type','application/x-www-form-urlencoded');
 		xmlhttp = UpdateMessage(xmlhttp, "PopulateUsers");
-		params = "user_table=" + user_table + "&page=" + page + "&max_rec=" + max_rec;
+		params = "user_table=" + user_table + "&page=" + page + "&max_rec=" + max_rec + "&user_sort=" + user_sort;
 		xmlhttp.send(params);
 	}
 	
@@ -529,30 +567,56 @@ function PopulateUserLists(rows_str)
 {
 //	alert(rows_str);
 	var rows = new Array();
+	
+	var user_table = document.getElementById("user_table_for_users_table").value;
 
 	var output_str = "<select name='selectUserName' id='selectUserNameExistingUser'>\n";
 	var output_str2 = "<select name='selectUserName' id='selectUserNameDelete'>\n";
-	var output_str3 = "<select name='selectUserName' id='selectUserNameEdit' onChange='GetUser(this.value);'>\n";
+	var output_str3 = "<select name='user_name' id='selectUserNameEdit' onChange='GetUser(this.value);'>\n";
 	var output_str4 =  "<table width='100%' border='0' cellspacing='0' cellpadding='0'>\n";
 	output_str = output_str + "<option>" + _NOT_SELECTED_ + "</option>\n";
 	output_str2 = output_str2 + "<option>" + _NOT_SELECTED_ + "</option>\n";
 	output_str3 = output_str3 + "<option>" + _NOT_SELECTED_ + "</option>\n";
 	output_str4 = output_str4 + "<tr bgcolor='#CCCCCC' class='header_row'>\n";
-	output_str4 = output_str4 + "<td class='header_row'><b>" + USER_WORD + "<\/b><\/td>\n";
+	output_str4 = output_str4 + "<td class='header_row' onclick=\"RetrieveUserLists('" + user_table + "', false, 'UserID', 0);\"><b><div class='column_heading_w_sort' id='UserID_column_heading'>" + USER_WORD + "</div><\/b><\/td>\n";
+	output_str4 = output_str4 + "<td class='header_row' onclick=\"RetrieveUserLists('" + user_table + "', false, 'first_name, last_name', 0);\"><b><div class='column_heading_w_sort' id='first_name_column_heading'>" + FIRST_NAME + "</div><\/b><\/td>\n";
+	output_str4 = output_str4 + "<td class='header_row' onclick=\"RetrieveUserLists('" + user_table + "', false, 'last_name, first_name', 0);\"><b><div class='column_heading_w_sort' id='last_name_column_heading'>" + LAST_NAME + "</div><\/b><\/td>\n";
+	
 	output_str4 = output_str4 + "<td class='header_row'><b>" + ACTIVE_WORD + "<\/b><\/td>\n";
-	output_str4 = output_str4 + "<td>&nbsp;<\/td>\n";
+	output_str4 = output_str4 + "<td colspan='2'>&nbsp;<\/td>\n";
 	output_str4 = output_str4 + "</tr>\n";
 
 	rows = rows_str.split("@@@@@");
+	var i;
 	if (rows[0] == "-no data-")	// If no pages yet (first time).
 	{
-		var i = 0;
+		i = 0;
 	}
+	else if (rows[0] == "-not user access table-")	// Selected table needs is missing users-access fields.
+	{
+		i = 0;
+		popup_msg.popup_msg_type = 2;
+		popup_msg.status_msg = MANAGE_PAGE_ACCESS_NO_LOGIN_FIELDS_IN_TABLE_ERR;
+		popup_msg.ClearPopupMsgTimer();
+		popup_msg.popup_timeout = -1;
+		popup_msg.top_offset = 0;
+		popup_msg.left_offset = 500;
+		if (page != 0)	{
+			popup_msg.ShowPopupMsg();
+			popup_msg.lockup_new_popups = true;
+		}
+	}	
 	else	// Create options for access level list.
 	{
 		for (var i in rows)
 		{
-			var JSON_row = JSON.parse(rows[i]);
+			try {
+				var JSON_row = JSON.parse(rows[i]);
+			}
+			catch(err) {
+//				alert(rows[i]);
+				continue;
+			}
 			//alert(JSON_row);
 			if (JSON_row.UserID)
 			{
@@ -574,14 +638,23 @@ function PopulateUserLists(rows_str)
 				else
 					bgclr = "#dddddd";
 			
-				output_str4 = output_str4 + "<tr bgcolor='" + bgclr + "'>\n<td>" + JSON_row.UserID + "<input type='hidden' value='" + JSON_row.UserID + "' id='user_id" + i + "' name='user_id" + i + "' /></td>\n<td>\n";
+				output_str4 = output_str4 + "<tr bgcolor='" + bgclr + "'>\n<td>" + JSON_row.UserID + "<input type='hidden' value='" + JSON_row.UserID + "' id='user_id" + i + "' name='user_id" + i + "' /></td>\n";
 				
-				output_str4 = output_str4 + " <input type='checkbox' name='active" + i + "' id='active" + i + "'";
+				if (JSON_row.first_name == null)
+					JSON_row.first_name = "";
+				if (JSON_row.last_name == null)
+					JSON_row.last_name = "";
+				output_str4 = output_str4 + "<td>" + JSON_row.first_name + "</td>\n";
+				output_str4 = output_str4 + "<td>" + JSON_row.last_name + "</td>\n";
+				
+				output_str4 = output_str4 + "<td>\n<input type='checkbox' name='active" + i + "' id='active" + i + "'";
 				if (JSON_row.Active == 1)
 					output_str4 = output_str4 + " checked='checked'";
 				output_str4 = output_str4 + " />\n</td>\n";
 				
 				output_str4 = output_str4 + "<td valign='top'>\n<img src='theme/" + theme + "/images/save.png' border=0 alt='Update' name='Update' onClick=\"UpdateUserStatus('" + JSON_row.UserID + "', " + i + ");\" style='cursor:pointer;' />\n<\/td>\n";
+				
+				output_str4 = output_str4 + "<td valign='top' style='text-decoration:none;'>\n<a href='#UserEdit'><img src='theme/" + theme + "/images/edit.png' border=0 alt='Update' name='Update' onClick=\"GetUser('" + JSON_row.UserID + "');\" style='cursor:pointer;' /></a>\n<\/td>\n";
 
 			}
 			if (JSON_row.welcome_message_page)
@@ -694,7 +767,7 @@ function AddRemoveAccessLevel(action)
 	}
 	else
 	{
-		HidePopupMsg();
+		popup_msg.HidePopupMsg();
 		popup_msg.status_msg = MANAGE_PAGE_ACCESS_REMOVING_ACCESS_LEVEL_MSG;
 	}
 	popup_msg.popup_msg_type = 1;
@@ -732,28 +805,32 @@ function moveFirst()
 {
 	page = 0;
 	var user_table = document.getElementById("user_table_for_fields").value;
-	RetrieveUserLists(user_table, false);
+	var user_sort = document.getElementById("user_sort").value;
+	RetrieveUserLists(user_table, false, user_sort, 1);
 }
 
 function movePrev()
 {
 	page = Math.max(0, (page - 1));
 	var user_table = document.getElementById("user_table_for_fields").value;
-	RetrieveUserLists(user_table, false);
+	var user_sort = document.getElementById("user_sort").value;
+	RetrieveUserLists(user_table, false, user_sort, 1);
 }
 
 function moveNext()
 {
 	page = Math.min(total_pages, (page + 1));
 	var user_table = document.getElementById("user_table_for_fields").value;
-	RetrieveUserLists(user_table, false);
+	var user_sort = document.getElementById("user_sort").value;
+	RetrieveUserLists(user_table, false, user_sort, 1);
 }
 
 function moveLast()
 {
 	page = total_pages;
 	var user_table = document.getElementById("user_table_for_fields").value;
-	RetrieveUserLists(user_table, false);
+	var user_sort = document.getElementById("user_sort").value;
+	RetrieveUserLists(user_table, false, user_sort, 1);
 }
 
 function GetNumUsers()
@@ -771,6 +848,30 @@ function GetNumUsers()
 		xmlhttp.send(params);
 //		alert(params);
 	}
+	
+	var user_sort = document.getElementById("user_sort").value;
+	var user_sort_desc = document.getElementById("user_sort_desc").value;
+	document.getElementById("UserID_column_heading").style.backgroundImage = "url('theme/" + theme + "/images/icon_sort.png')";
+	document.getElementById("first_name_column_heading").style.backgroundImage = "url('theme/" + theme + "/images/icon_sort.png')";
+	document.getElementById("last_name_column_heading").style.backgroundImage = "url('theme/" + theme + "/images/icon_sort.png')";
+	if (user_sort == "UserID")	{
+		if (user_sort_desc == 1)
+			document.getElementById("UserID_column_heading").style.backgroundImage = "url('theme/" + theme + "/images/icon_sort_desc.png')";
+		else
+			document.getElementById("UserID_column_heading").style.backgroundImage = "url('theme/" + theme + "/images/icon_sort_asc.png')";
+	}
+	else if (user_sort == "first_name, last_name")	{
+		if (user_sort_desc == 1)
+			document.getElementById("first_name_column_heading").style.backgroundImage = "url('theme/" + theme + "/images/icon_sort_desc.png')";
+		else
+			document.getElementById("first_name_column_heading").style.backgroundImage = "url('theme/" + theme + "/images/icon_sort_asc.png')";
+	}
+	else if (user_sort == "last_name, first_name")	{
+		if (user_sort_desc == 1)
+			document.getElementById("last_name_column_heading").style.backgroundImage = "url('theme/" + theme + "/images/icon_sort_desc.png')";
+		else
+			document.getElementById("last_name_column_heading").style.backgroundImage = "url('theme/" + theme + "/images/icon_sort_asc.png')";
+	}
 }
 
 function FinishGetNumUsers(xmlhttp)	{
@@ -835,6 +936,19 @@ function ShowHidePageBtns()
 		document.getElementById("next_bot").src = "./theme/" + theme + "/images/Next.gif";
 		document.getElementById("last_bot").src = "./theme/" + theme + "/images/Last.gif";
 	}
+	
+	var rcrd_start = (page * max_rec) + 1;
+	var rcrd_end = Math.min(rcrd_start - 1 + max_rec, num_users);
+	document.getElementById("page_num_top").innerHTML = page + 1;
+	document.getElementById("total_pages_top").innerHTML = total_pages + 1;
+	document.getElementById("rcrd_start_top").innerHTML = rcrd_start;
+	document.getElementById("rcrd_end_top").innerHTML = rcrd_end;
+	document.getElementById("total_rcrds_top").innerHTML = num_users;
+	document.getElementById("page_num_bot").innerHTML = page + 1;
+	document.getElementById("total_pages_bot").innerHTML = total_pages + 1;
+	document.getElementById("rcrd_start_bot").innerHTML = rcrd_start;
+	document.getElementById("rcrd_end_bot").innerHTML = rcrd_end;
+	document.getElementById("total_rcrds_bot").innerHTML = num_users;
 }
 
 /////////////////////////////////////////////////////////////////////////////////////////
@@ -888,7 +1002,8 @@ function CompleteAddUser(data)
 		document.getElementById('last_name_new_user').value = "";
 		
 		var user_table = document.getElementById("table_new_user").value;
-		RetrieveUserLists(user_table, false);
+		var user_sort = document.getElementById("user_sort").value;
+		RetrieveUserLists(user_table, false, user_sort, 1);
 	}
 }
 
@@ -922,15 +1037,9 @@ function CompleteChangePassword(data)
 
 function ModifyUser()
 {
-	var user_name = document.getElementById('selectUserNameEdit').value;
-	var AccessLevel = document.getElementById('selectAccessLevelEdit').value;
-	var email = document.getElementById('email_edit').value;
-	var first_name = document.getElementById('first_name_edit').value;
-	var last_name = document.getElementById('last_name_edit').value;
-	var table = document.getElementById('table_edit').value;
-	var website_user = 1;
-	
-	$.post( "modify_user.php", { user_name: user_name, AccessLevel: AccessLevel, email: email, first_name: first_name, last_name: last_name, table: table, website_user: website_user, no_prefix: 1 } ).done(CompleteModifyUser) ;
+	$.ajax({type:'POST', url: 'modify_user.php', data:$('#formModifyUser').serialize(), success: function(response) {
+		CompleteModifyUser(response);
+	}});
 }
 function CompleteModifyUser(data)
 {
@@ -958,7 +1067,10 @@ function CompleteModifyUser(data)
 function GetUser(user_name)
 {
 	var table = document.getElementById('table_edit').value;
-	$.post( "get_rows.php", { table: table, where: "`UserID` = '" + user_name + "'", no_prefix: 1 } ).done(PopulateUser) ;
+	if ((table != "") && (user_name != ""))	{
+		$.post( "get_rows.php", { table: table, where: "`UserID` = '" + user_name + "'", no_prefix: 1 } ).done(PopulateUser) ;
+		document.getElementById("selectUserNameEdit").value = user_name;
+	}
 }
 function PopulateUser(data)
 {
@@ -966,14 +1078,80 @@ function PopulateUser(data)
 		alert(MANAGE_PAGE_ACCESS_NO_DATA_FOUND_FOR_USER_ERR);
 	else
 	{
+		if (data.indexOf("@@@@@") > -1)	{
+			var rows = data.split("@@@@@");
+			data = rows[0];
+		}
 		var JSON_row = JSON.parse(data);
 		document.getElementById("selectAccessLevelEdit").value = JSON_row.AccessLevel;
 		document.getElementById("email_edit").value = JSON_row.email;
 		document.getElementById("first_name_edit").value = JSON_row.first_name;
 		document.getElementById("last_name_edit").value = JSON_row.last_name;
+		
+		var html = "";
+		var prop_str;
+		for (var property in JSON_row)
+		{
+			if (JSON_row.hasOwnProperty(property)) {
+				if ((property != "id") && (property != "password") && (property != "UserID") && (property != "first_name") && (property != "last_name") && (property != "email") && (property != "subject") && (property != "user_table") && (property != "AccessLevel") && (property != "created") && (property != "Active") && (property != "Session") && (property != "IP") && (property != "welcome_message_page") && (property != "preferred_phone") && (property != "best_time") && (property != "acct_id") && (property != "Password"))	{
+					prop_str = property.replace(/_/g, " ");
+					prop_str = titleCase(prop_str);
+					if (JSON_row[property] == null)
+						JSON_row[property] = "";
+					html = html + " " + prop_str + ": <input name='" + property + "' id='" + property + "' value='" + JSON_row[property] + "' />\n";
+				}
+			}
+		}
+		document.getElementById("additional_user_fields").style.display = "table-cell";
+		document.getElementById("additional_user_fields").innerHTML = html;
 	}
 }
 
+function titleCase(str) {
+   var splitStr = str.toLowerCase().split(' ');
+   for (var i = 0; i < splitStr.length; i++) {
+       // You do not need to check if i is larger than splitStr length, as your for does that for you
+       // Assign it back to the array
+       splitStr[i] = splitStr[i].charAt(0).toUpperCase() + splitStr[i].substring(1);     
+   }
+   // Directly return the joined string
+   return splitStr.join(' '); 
+}
+
+function convertType(elem)
+{
+	var input = document.createElement('input');
+	input.id = elem.id;
+	input.value = elem.value;
+	input.onfocus = elem.onfocus;
+	input.onblur = elem.onblur;
+	input.className = elem.className;
+	if (elem.type == 'text' )
+	  { input.type = 'password'; }
+	else
+	  { input.type = 'text'; }
+	
+	elem.parentNode.replaceChild(input, elem);         
+	return input;
+}
+
+function convertToTxt(elem)
+{
+	var input = document.createElement('input');
+	input.id = elem.id;
+	input.value = elem.value;
+	input.onfocus = elem.onfocus;
+	input.onblur = elem.onblur;
+	input.className = elem.className;
+	if (elem.type == 'text' )
+	  { return elem; }
+	else
+	  { input.type = 'text'; }
+	
+	elem.parentNode.replaceChild(input, elem);         
+	return input;
+}
+
 ///////////////////////////////////////////////////////////////////////////////////////////////////////////
 function ResizeWorkspace(mainWidth, mainHeight, menuWidth, headerHeight) {
 
