@@ -8,6 +8,8 @@
 // Off-loaded JavaScript.
 // Revised: 21/1/2014	ELL
 // Added edit is source view checkbox.
+// Revised: 4/28/2016	ELL
+// Added ability to use either desktop styles or mobile styles.
 // 
 
 	include ("check_session.php");
@@ -33,6 +35,12 @@
 	left:400px;
 <?php	} else	echo "	display:none;\n";	?>
 }
+
+#btn_manage_custom_border_areas	{
+	background-attachment:scroll;
+	background-repeat:no-repeat;
+	background-position: 5px -1px;
+}
 </style>
 </head>
 
@@ -41,7 +49,7 @@
 	 	
             <div class="button_heading_sub_level_1"><div class="button_heading_text_sub_level_1"><?php echo EDIT_BORDER_AREA_SELECT_HEADING; ?></div><div class="button_heading_help" onClick="OpenHelpWindow();">&nbsp;</div></div>
 		<?php
-			$query = "SELECT page_name FROM " . BWB_TABLE_PREFIX . "page_data_special ORDER BY page_name";
+			$query = "SELECT page_name FROM " . BWB_TABLE_PREFIX . "page_data_special WHERE page_name NOT LIKE 'mm_%' ORDER BY page_name";
 			$result = $bwb_dbh->query($query);
 			$num_results = $result->rowCount();
 			for ($i = 0; $i < $num_results; $i++)
@@ -60,13 +68,15 @@
 
 		<div class="button_heading_sub_level_1"><div class="button_heading_text_sub_level_1"><?php echo MANAGE_BORDER_AREA_HEADING; ?></div><div class="button_heading_help" onClick="OpenHelpWindow();">&nbsp;</div></div>
         
-        <div class='button_sub_level_1' onClick="window.location='manage_border_area.php';"><span class='button_text_sub_level_1'><?php echo MANAGE_BORDER_AREA_BTN; ?></span></div>
+        <div class='button_sub_level_1' onClick="window.location='manage_border_area.php';" id="btn_manage_custom_border_areas"><span class='button_text_sub_level_1' style="left:40px;"><?php echo MANAGE_BORDER_AREA_BTN; ?></span></div>
 </div>
      
      <div id="editor_options_div">
     <span class="bold"><?php echo EDIT_PAGE_SELECT_OPTIONS_HEADING; ?></span><br /><br />
-    <input type="checkbox" id="editor_mode" name="editor_mode" onChange="SetEditorMode();" <?php if (isset($_SESSION['editor_mode']) && ($_SESSION['editor_mode'] == 1)) echo "checked='checked'"; ?> />
-    <?php echo EDIT_PAGE_SELECT_SOURCE_VIEW_OPTION; ?><br /><br />
+    <input type="checkbox" id="editor_mode" name="editor_mode" onChange="SetEditorMode('editor_mode');" <?php if (isset($_SESSION['editor_mode']) && ($_SESSION['editor_mode'] == 1)) echo "checked='checked'"; ?> />
+    <?php echo EDIT_PAGE_SELECT_SOURCE_VIEW_OPTION; ?><br />
+    <input type="checkbox" id="style_mode" name="style_mode" onChange="SetEditorMode('style_mode');" <?php if (isset($_SESSION['style_mode']) && ($_SESSION['style_mode'] == 1)) echo "checked='checked'"; ?> />
+    <?php echo EDIT_PAGE_SELECT_MOBILE_STYLE_OPTION; ?><br /><br />
     </div>
 </body>
 </html>
\ No newline at end of file
