@@ -69,6 +69,8 @@
 	display:inline-block;
 	margin-left:30px;
 }
+
+#additional_user_fields	{	display:none;	}
 </style>
 
 <script type="text/javascript" src="js/json2.js"></script>
@@ -147,6 +149,9 @@
 	echo "	var NO_WORD = \"" . NO_WORD . "\";\n";
 	echo "	var MANAGE_PAGE_ACCESS_NO_TABLE_SELECTED_ERR = \"" . MANAGE_PAGE_ACCESS_NO_TABLE_SELECTED_ERR . "\";\n";
 	echo "	var MANAGE_PAGE_ACCESS_NO_LOGIN_PAGE_SELECTED_ERR = \"" . MANAGE_PAGE_ACCESS_NO_LOGIN_PAGE_SELECTED_ERR . "\";\n";
+	echo "	var MANAGE_PAGE_ACCESS_NO_LOGIN_FIELDS_IN_TABLE_ERR = \"" . MANAGE_PAGE_ACCESS_NO_LOGIN_FIELDS_IN_TABLE_ERR . "\";\n";
+	echo "	var FIRST_NAME = \"" . FIRST_NAME . "\";\n";
+	echo "	var LAST_NAME = \"" . LAST_NAME . "\";\n";
 ?>
 
 var pages = new Array();
@@ -289,6 +294,8 @@ var access_level_remove = "-not set-";
 	}
 ?>
     </select>
+    <input type="hidden" name="user_sort" id="user_sort" value="UserID" />
+    <input type="hidden" name="user_sort_desc" id="user_sort_desc" value="0" />
     </td>
   </tr>
   
@@ -296,16 +303,22 @@ var access_level_remove = "-not set-";
     <td colspan="3">  
      <table border="0" width="95%" align="center">
       <tr id="user_nav_row_top">
-        <td width="25%" align="center">
+        <td style="width:5%; text-align:center;">
          <img src="./theme/<?php echo $theme; ?>/images/First.gif" id="first_top" border="0" onClick="moveFirst();" style="cursor:default;" onMouseOver="this.style.cursor='pointer';" />
         </td>
-        <td width="25%" align="center">
+        <td style="width:5%; text-align:center;">
           <img src="./theme/<?php echo $theme; ?>/images/Previous.gif" id="prev_top" border="0" onClick="movePrev();" style="cursor:default;" onMouseOver="this.style.cursor='pointer';" />
         </td>
-        <td width="25%" align="center">
+        <td style="width:40%; text-align:center;" class="small_message">
+            <?php echo SHOWING_RECORDS; ?> <span id="rcrd_start_top">&nbsp;</span> <?php echo THRU_WORD; ?> <span id="rcrd_end_top">&nbsp;</span> <?php echo OF_WORD; ?> <span id="total_rcrds_top">&nbsp;</span>
+        </td>
+        <td style="width:40%; text-align:center;" class="small_message">
+        	<?php echo PAGE_1ST_CAP_WORD; ?> <span id="page_num_top">&nbsp;</span> <?php echo OF_WORD; ?> <span id="total_pages_top">&nbsp;</span>
+        </td>
+        <td style="width:5%; text-align:center;">
           <img src="./theme/<?php echo $theme; ?>/images/Next.gif" id="next_top" border="0" onClick="moveNext();" style="cursor:default;" onMouseOver="this.style.cursor='pointer';" />
         </td>
-        <td width="25%" align="center">
+        <td style="width:5%; text-align:center;">
           <img src="./theme/<?php echo $theme; ?>/images/Last.gif" id="last_top" border="0" onClick="moveLast();" style="cursor:default;" onMouseOver="this.style.cursor='pointer';" />
         </td>
       </tr>
@@ -321,16 +334,22 @@ var access_level_remove = "-not set-";
     <td colspan="3">  
      <table border="0" width="95%" align="center">
       <tr id="user_nav_row_bot">
-        <td width="25%" align="center">
+        <td style="width:5%; text-align:center;">
          <img src="./theme/<?php echo $theme; ?>/images/First.gif" id="first_bot" border="0" onClick="moveFirst();" style="cursor:default;" onMouseOver="this.style.cursor='pointer';" />
         </td>
-        <td width="25%" align="center">
+        <td style="width:5%; text-align:center;">
           <img src="./theme/<?php echo $theme; ?>/images/Previous.gif" id="prev_bot" border="0" onClick="movePrev();" style="cursor:default;" onMouseOver="this.style.cursor='pointer';" />
         </td>
-        <td width="25%" align="center">
+        <td style="width:40%; text-align:center;" class="small_message">
+            <?php echo SHOWING_RECORDS; ?> <span id="rcrd_start_bot">&nbsp;</span> <?php echo THRU_WORD; ?> <span id="rcrd_end_bot">&nbsp;</span> <?php echo OF_WORD; ?> <span id="total_rcrds_bot">&nbsp;</span>
+        </td>
+        <td style="width:40%; text-align:center;" class="small_message">
+        	<?php echo PAGE_1ST_CAP_WORD; ?> <span id="page_num_bot">&nbsp;</span> <?php echo OF_WORD; ?> <span id="total_pages_bot">&nbsp;</span>
+        </td>
+        <td style="width:5%; text-align:center;">
           <img src="./theme/<?php echo $theme; ?>/images/Next.gif" id="next_bot" border="0" onClick="moveNext();" style="cursor:default;" onMouseOver="this.style.cursor='pointer';" />
         </td>
-        <td width="25%" align="center">
+        <td style="width:5%; text-align:center;">
           <img src="./theme/<?php echo $theme; ?>/images/Last.gif" id="last_bot" border="0" onClick="moveLast();" style="cursor:default;" onMouseOver="this.style.cursor='pointer';" />
         </td>
       </tr>
@@ -350,7 +369,7 @@ var access_level_remove = "-not set-";
   <tr>
     <td align="right"><?php echo TABLE_WORD; ?>:&nbsp;</td>
     <td>
-    <select name="user_table_for_fields" id="user_table_for_fields" onChange="RetrieveUserLists(this.value);">
+    <select name="user_table_for_fields" id="user_table_for_fields" onChange="RetrieveUserLists(this.value, false);">
       <option><?php echo _NOT_SELECTED_; ?></option>
       <?php
 	for ($i = 0; $i < $table_cnt; $i++)
@@ -427,15 +446,20 @@ var access_level_remove = "-not set-";
 <form name="formAddUser" id="formAddUser" method="post" action="add_user.php">
 <table width="100%" class="layout_box_table" cellspacing="0" cellpadding="0">
   <tr>
-    <td colspan="9" class="sub_title"><?php echo ADD_USER; ?></td>
+    <td colspan="10" class="sub_title"><?php echo ADD_USER; ?></td>
   </tr>
   <tr>
     <td align="right"><?php echo USERNAME_WORD; ?>: </td>
     <td><input type="text" name="user_name" id="user_name_new_user"></td>
-    <td align="right" width="150"><?php echo PASSWORD_WORD; ?>: </td>
-    <td> <input type="text" name="password" id="password_new_user"></td>
+    <td align="right" style="width:150px;"><?php echo PASSWORD_WORD; ?>: </td>
+    <td style="width:144px;"><input type="password" name="password" id="password_new_user"></td>
+    <td style="width:22px;">
+        <div onClick="convertType(document.getElementById('password_new_user'));" class="reveal_pass_icon">
+          &nbsp;
+        </div>
+    </td>
     <td>
-    	 <div class='button_console_generate_password' id="generate_password_btn" onClick="GeneratePassword('new');"><span class='button_console_text_w_icon'><?php echo GENERATE_PASSWORD; ?></span></div>
+    	 <div class='button_console_generate_password' id="generate_password_btn" onClick="convertToTxt(document.getElementById('password_new_user')); GeneratePassword('new');"><span class='button_console_text_w_icon'><?php echo GENERATE_PASSWORD; ?></span></div>
     </td>
     <td align="right"><?php echo ACCESS_LEVEL_WORD; ?>: </td>
     <td>
@@ -451,7 +475,7 @@ var access_level_remove = "-not set-";
     </td>
     <td align="right"><?php echo TABLE_WORD; ?>: </td>
     <td>
-    <select name="table" id="table_new_user" onChange="RetrieveUserLists(this.value);">
+    <select name="table" id="table_new_user" onChange="RetrieveUserLists(this.value, false);">
     <option value="-not selected-"><?php echo _NOT_SELECTED_; ?></option>
 <?php
 	for ($i = 0; $i < $table_cnt; $i++)
@@ -466,7 +490,7 @@ var access_level_remove = "-not set-";
     </td>
   </tr>
   <tr>
-  	<td colspan="9" align="center">
+  	<td colspan="10" align="center">
     <table width="90%"><tr>
     <td align="right"><?php echo EMAIL_WORD; ?>:</td>
     <td><input type="text" name="email" id="email_new_user" /></td>
@@ -480,12 +504,12 @@ var access_level_remove = "-not set-";
     </td>
   </tr>
   <tr>
-    <td colspan="9" align="center">
+    <td colspan="10" align="center">
     <div class='button_console_add' id="add_user_btn" onClick="AddUser();"><span class='button_console_text_w_icon'><?php echo ADD_WORD; ?></span></div>
     </td>
   </tr>
   </table>
-  <input type="hidden" name="no_prefix" id="no_prefix" value="1" />
+  <input type="hidden" name="no_prefix" value="1" />
   </form>
   </td></tr></table>
   <br />
@@ -494,12 +518,12 @@ var access_level_remove = "-not set-";
   <form name="formChangePassword" id="formChangePassword" method="post" action="change_password.php">
   <table width="100%" class="layout_box_table" cellspacing="0" cellpadding="0">
   <tr>
-    <td colspan="7" class="sub_title"><?php echo CHANGE_PASSWORD; ?></td>
+    <td colspan="8" class="sub_title"><?php echo CHANGE_PASSWORD; ?></td>
   </tr>
   <tr>
   	<td align="right"><?php echo TABLE_WORD; ?>: </td>
     <td>
-    <select name="table" id="table_existing_user" onChange="RetrieveUserLists(this.value);">
+    <select name="table" id="table_existing_user" onChange="RetrieveUserLists(this.value, false);">
     <option value="-not selected-"><?php echo _NOT_SELECTED_; ?></option>
 <?php
 	for ($i = 0; $i < $table_cnt; $i++)
@@ -521,21 +545,26 @@ var access_level_remove = "-not set-";
     </div>
     </td>
     <td align="right"><?php echo NEW_PASSWORD; ?>: </td>
-    <td width="150">
-    	<input type="text" name="password" id="password_existing_user">
+    <td style="width:150px; text-align:right;">
+    	<input type="password" name="password" id="password_existing_user">
+    </td>
+    <td style="width:22px;">
+        <div onClick="convertType(document.getElementById('password_existing_user'));" class="reveal_pass_icon">
+          &nbsp;
+        </div>
     </td>
     <td>
-        <div class='button_console_generate_password' id="generate_password_btn2" onClick="GeneratePassword('existing');"><span class='button_console_text_w_icon'><?php echo GENERATE_PASSWORD; ?></span></div>
+        <div class='button_console_generate_password' id="generate_password_btn2" onClick="convertToTxt(document.getElementById('password_existing_user')); GeneratePassword('existing');"><span class='button_console_text_w_icon'><?php echo GENERATE_PASSWORD; ?></span></div>
 	</td>
   </tr>
-  <tr><td colspan="7">&nbsp;</td></tr>
+  <tr><td colspan="8">&nbsp;</td></tr>
   <tr>
-    <td colspan="7" align="center">
+    <td colspan="8" align="center">
     <div class='button_console_edit' id="change_password_btn" onClick="ChangePassword();"><span class='button_console_text_w_icon'><?php echo CHANGE_PASSWORD; ?></span></div>
     </td>
   </tr>
   </table>
-  <input type="hidden" name="no_prefix" id="no_prefix" value="1" />
+  <input type="hidden" name="no_prefix" value="1" />
   </form>
   </td></tr></table>
   
@@ -549,7 +578,7 @@ var access_level_remove = "-not set-";
   <tr>
     <td align="right"><?php echo TABLE_WORD; ?>: </td>
     <td>
-    <select name="table" id="table_edit" onChange="RetrieveUserLists(this.value);">
+    <select name="table" id="table_edit" onChange="RetrieveUserLists(this.value, false);">
     <option value="-not selected-"><?php echo _NOT_SELECTED_; ?></option>
 <?php
 	for ($i = 0; $i < $table_cnt; $i++)
@@ -565,7 +594,7 @@ var access_level_remove = "-not set-";
     <td align="right"><?php echo USERNAME_WORD; ?>: </td>
     <td>
     <div id="UsersEdit">
-    <select name="selectUserName" id="selectUserNameEdit" onChange="GetUser(this.value);">
+    <select name="user_name" id="selectUserNameEdit" onChange="GetUser(this.value);">
     <option value="-not selected-"><?php echo _NOT_SELECTED_; ?></option>
     </select>
     </div>
@@ -573,7 +602,7 @@ var access_level_remove = "-not set-";
     <td align="right"><?php echo ACCESS_LEVEL_WORD; ?>: </td>
     <td>
     <div id="AccessLevelEditUserDiv">
-    <select name="selectAccessLevel" id="selectAccessLevelEdit">
+    <select name="AccessLevel" id="selectAccessLevelEdit">
     <option value="blogger"><?php echo BLOGGER_WORD; ?></option>
 	<option value="restricted"><?php echo RESTRICTED_WORD; ?></option>
     <option value="user"><?php echo USER_WORD; ?></option>
@@ -589,8 +618,10 @@ var access_level_remove = "-not set-";
     <td>
     	<input type="text" name="first_name" id="first_name_edit" />
         <input type="text" name="last_name" id="last_name_edit" />
+        <input type="hidden" name="website_user" value="1" />
     </td>
   </tr>
+  <tr><td colspan="6" id="additional_user_fields">&nbsp;</td></tr>
   <tr><td colspan="6">&nbsp;</td></tr>
   <tr>
     <td colspan="6" align="center">
@@ -598,8 +629,9 @@ var access_level_remove = "-not set-";
     </td>
   </tr>
 </table>
-<input type="hidden" name="no_prefix" id="no_prefix" value="1" />
+<input type="hidden" name="no_prefix" value="1" />
 </form>
+<a name="UserEdit">
   </td></tr></table>
   <br>
 
@@ -612,7 +644,7 @@ var access_level_remove = "-not set-";
   <tr>
   	<td align="right"><?php echo TABLE_WORD; ?>: </td>
     <td>
-    <select name="table" id="table_delete_user" onChange="RetrieveUserLists(this.value);">
+    <select name="table" id="table_delete_user" onChange="RetrieveUserLists(this.value, false);">
     <option value="-not selected-"><?php echo _NOT_SELECTED_; ?></option>
 <?php
 	for ($i = 0; $i < $table_cnt; $i++)
@@ -653,11 +685,11 @@ var access_level_remove = "-not set-";
    if (document.getElementById("user_table_for_fields").value != "")
 	last_user_table = document.getElementById("user_table_for_fields").value;
    if (last_user_table != "")
-   	RetrieveUserLists(last_user_table);
+   	RetrieveUserLists(last_user_table, false);
    else
    	ShowHidePageBtns();
 	
-	HidePopupMsg();
+	popup_msg.HidePopupMsg();
 </script>
 </body>
 </html>
