@@ -33,7 +33,7 @@
 	$language_folder = $row['language_folder'];
 	
 	$document_root = $_SERVER['DOCUMENT_ROOT'];
-	if (defined("BWB_LANG"))
+	if ((defined("BWB_LANG")) && (file_exists($document_root . "/" . $language_folder . "/" . BWB_LANG . ".php")))
 		include_once ($document_root . "/" . $language_folder . "/" . BWB_LANG . ".php");
 	else
 		include_once ($document_root . "/" . $language_folder . "/en.php");
@@ -375,7 +375,7 @@ var pages = new Array();
 <?php include("../lib/popup_msg.html"); ?>
 
 <script language="JavaScript" type="text/javascript">
-	HidePopupMsg();
+	popup_msg.HidePopupMsg();
 
 window.onload = function(){
 <?php
