@@ -33,7 +33,7 @@ function DeleteConfirm(desc_remove, ID, y_offset)
 	popup_msg.msg_width = 450;
 	popup_msg.ShowPopupMsg();
 	document.getElementById("popup_button_2_span").onclick = function () { DeleteEvent(ID, desc_remove, y_offset); };
-	document.getElementById("popup_button_1_span").onclick = function () { HidePopupMsg(); };
+	document.getElementById("popup_button_1_span").onclick = function () { popup_msg.HidePopupMsg(); };
 }
 
 function DeleteEvent(event_ID, desc_remove, row_to_delete)
@@ -60,7 +60,7 @@ function DeleteEvent(event_ID, desc_remove, row_to_delete)
 		xmlhttp.send(params);
 	}
 
-	HidePopupMsg();
+	popup_msg.HidePopupMsg();
 }
 
 //////////////////////////////////////////////////////////////////////////////////////
