@@ -6,6 +6,8 @@
 // Created: 12/14/2010	ELL
 // Revised: 2/8/2012	ELL
 // Added table prefix handling.
+// Modified: 12/2/2016	ELL
+// Consolidated all menu items tables into menu_items.
 // 
 // 
 	
@@ -17,9 +19,7 @@
 	else
 		$_SESSION['last_menu_edited'] = $menu;
 	
-	$suffix = substr($menu, 4);
-	$menu_source  = "menu" . $suffix . "_items";
-	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . $menu_source . " ORDER BY sort_order";
+	$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "menu_items WHERE menu = '" . $menu . "' ORDER BY sort_order";
 	$result = $bwb_dbh->query($query);
 	
 	if ($result->rowCount() < 1)
@@ -31,8 +31,6 @@
 	$row_delim = "";
 	while ($row = $result->fetch(PDO::FETCH_ASSOC))
 	{
-//		$row['item_text'] = str_replace('AMPERSAND', '&', $row['item_text']);
-//		$row['item_text'] = str_replace('SEMICOLON', ';', $row['item_text']);
 		$row['item_text'] = stripslashes($row['item_text']);
 		$table .= $row_delim . json_encode($row);
 		$row_delim = "@@@@@";
