@@ -5,6 +5,8 @@
 // Security enhancements for PDO.
 // Revised 9/10/2014	BAK
 // Added link back to website to a page as denfined by the 'email_link_page' hidden field.
+// Revised: 11/23/2016	ELL
+// Modified reset password to store temp password in temp users table, then update users table upon logging in with temp password to new temp password.
 //
 // 
 $server_name = $_SERVER['SERVER_NAME'];
@@ -199,7 +201,9 @@ $salted_pass = $pass1 . BWB_PUB_SALT . $pass2;
 // Encrypt password.
 $encrypt_password = doEncrypt($salted_pass, $UserID);
 // Update user table with new password.
-$query = "UPDATE `" . $user_table . "` SET `password`='" . $encrypt_password . "' WHERE `UserID`='" . $UserID . "'";
+$query = "CREATE TABLE IF NOT EXISTS `" . $bwb_database . "`.`tmp_users` ( `UserID` VARCHAR(50) NOT NULL , `password` VARCHAR(255) NOT NULL , `created` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP , PRIMARY KEY (`UserID`))";
+$cnt = $bwb_dbh->exec($query);
+$query = "REPLACE INTO `tmp_users` (`password`, `UserID`) VALUES ('" . $encrypt_password . "', '" . $UserID . "')";
 $cnt = $bwb_dbh->exec($query);
 
 
@@ -296,7 +300,7 @@ function check_referer($referers)
 					$found = true;
 			}
 			if (!$found) {
-				$errors[] = '1|You are coming from an unauthorized domain.  Please read the manual section titled &quot;<a href="' . MANUAL . '#setting_up" target="_blank">Setting Up the PHPFormMail Script</a>&quot;.';
+				$errors[] = '1|You are coming from an unauthorized domain.';
 				error_log('[PHPFormMail] Illegal Referer. (' . getenv('HTTP_REFERER') . ')', 0);
 			}
 			return $found;
@@ -306,7 +310,7 @@ function check_referer($referers)
 			return false;
 		}
 	} else {
-		$errors[] = '1|There are no referers defined.  All submissions will be denied.  Please read the manual section titled &quot;<a href="' . MANUAL . '#setting_up" target="_blank">Setting Up the PHPFormMail Script</a>&quot;.';
+		$errors[] = '1|There are no referers defined.  All submissions will be denied.';
 		error_log('[PHPFormMail] You have no referers defined.  All submissions will be denied.', 0);
 		return false;
 	}
