@@ -10,30 +10,11 @@
 	$file_name = $_POST['file_name'];
 	$folder = $_POST["folder"];
 	
+	if (strpos($file_name, "/") === 0)
+		$file_name = substr($file_name, 1);
+	
 	$document_root = $_SERVER['DOCUMENT_ROOT'];
-	if ($folder == "pages")
-	{
-		if ((BWB_BASE_DIR == '') && (BWB_WEBPAGE_DIR == ''))
-			$path = $document_root . "/";
-		elseif (BWB_BASE_DIR == '')
-			$path = $document_root . "/" . BWB_WEBPAGE_DIR . "/";
-		else
-			$path = $document_root . "/" . BWB_BASE_DIR . "/" . BWB_WEBPAGE_DIR . "/";
-	}
-	elseif ($folder == "scripts")
-	{
-		if (BWB_BASE_DIR == '')
-			$path = $document_root . "/" . BWB_SCRIPTS_DIR . "/";
-		else
-			$path = $document_root . "/" . BWB_BASE_DIR . "/" . BWB_SCRIPTS_DIR . "/";
-	}
-	elseif ($folder == "php")
-		$path = $document_root . "/php/";
-	else
-	{
-		echo "Error: no folder specified";
-		exit;
-	}
+	$path = $document_root . "/" . $folder . "/";
 	
 	$save_file_path = $path . "." . $file_name . "_save";
 	if (file_exists($save_file_path))
