@@ -10,6 +10,11 @@
 // Converted save functions to JQuery AJAX operations.
 // Revised: 11/6/2014	ELL
 // Added save to backup everytime save or publish is clicked.
+// Revised: 11/10/2016	ELL
+// Modified custom CSS editing to allow for any number of custom CSS records associated with custom style sheets.
+// Modified: 12/2/2016	ELL
+// Consolidated all class tables into site_classes table indexed by style_sheet field.
+// Consolidated all CSS tables into site_css table indexed by style_sheet field.
 // 
 //
 //
@@ -17,10 +22,7 @@
 	include("lib/build_css_string.php");
 
 	$style_sheet = $_POST['style_sheet'];
-	$site_css_table = $style_sheet . "_css";
-	$custom_site_css_table = $_POST['custom_site_css_table'];
 	$css_file = $style_sheet. ".css";
-	$class_table = $style_sheet . "_classes";
 	$action = $_POST['action'];
 	
 	// Custom CSS
@@ -31,53 +33,60 @@
 	
 	if ($action == "Preview")
 	{
-		//Start by deleting all old data in table.
-		$query = "TRUNCATE TABLE " . BWB_TABLE_PREFIX . "custom_site_css_preview";
-		$cnt = $bwb_dbh->exec($query);
-		
 		//Insert new data into table.
-		$query = "INSERT INTO " . BWB_TABLE_PREFIX . "custom_site_css_preview (custom_css, revised) VALUES ('" . $custom_css . "', '" . $today . "')";
+		$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "custom_site_css WHERE name = 'site_css_preview'";
+		$result = $bwb_dbh->query($query);
+		if ($result->rowCount() > 0)
+			$query = "UPDATE " . BWB_TABLE_PREFIX . "custom_site_css SET custom_css = '" . $custom_css . "', revised = '" . $today . "' WHERE name = 'site_css_preview'";
+		else
+			$query = "INSERT INTO " . BWB_TABLE_PREFIX . "custom_site_css SET custom_css = '" . $custom_css . "', revised = '" . $today . "', name = 'site_css_preview'";
 		$cnt = $bwb_dbh->exec($query);
 		
-		if ((strpos($site_css_table, "site_css") !== false) || (strpos($site_css_table, "site_mobile_css") !== false))
-		{
-			include ("lib/copy_table.php");
-			
 			//Start by deleting all old data in table.
-			$query = "TRUNCATE TABLE " . BWB_TABLE_PREFIX . "site_css_preview";
-			$cnt = $bwb_dbh->exec($query);
+		$query = "DELETE FROM " . BWB_TABLE_PREFIX . "site_css WHERE `style_sheet` = 'site_css_preview'";
+		$cnt = $bwb_dbh->exec($query);
 			
 			//Get data from live table and move to preview table.
-			if (strpos(css_table, "site_mobile_css") === false)
-				copy_table(BWB_TABLE_PREFIX . "site_css", BWB_TABLE_PREFIX . "site_css_preview", $bwb_dbh, $bwb_database);
-			else
-				copy_table(BWB_TABLE_PREFIX . "site_mobile_css", BWB_TABLE_PREFIX . "site_css_preview", $bwb_dbh, $bwb_database);
+		$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "site_css WHERE style_sheet = '$style_sheet'";
+		$result = $bwb_dbh->query($query);
+		$comma = ", ";
+		while ($row = $result->fetch(PDO::FETCH_ASSOC))
+		{
+			$sql = "REPLACE INTO " . BWB_TABLE_PREFIX . "site_css SET style_sheet = 'site_css_preview'";
+			foreach ($row as $field => $val)
+			{
+				if ($field != "style_sheet")	{
+					$sql .= $comma . "`" . $field . "` = '" . $val . "'";
+				}
+			}
+			$cnt = $bwb_dbh->exec($sql);
 		}
 	}
 	else
 	{
 		// Whether saving draft of publishing, save latest revision to draft table.
-		$query = "SELECT page_name FROM " . BWB_TABLE_PREFIX . "page_data_draft WHERE page_name='$custom_site_css_table' AND `source`=3";
+		$query = "SELECT page_name FROM " . BWB_TABLE_PREFIX . "page_data_draft WHERE page_name='$style_sheet' AND `source`=3";
 		$result = $bwb_dbh->query($query);
 		if ($result->rowCount() > 0)	
-			$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data_draft SET page_content=:custom_css, revised='$today', `source`=3 WHERE page_name='$custom_site_css_table'";
+			$query = "UPDATE " . BWB_TABLE_PREFIX . "page_data_draft SET page_content=:custom_css, revised='$today', `source`=3 WHERE page_name='$style_sheet'";
 		else
-			$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data_draft SET page_name='$custom_site_css_table', page_content=:custom_css, revised='$today', `source`=3";
+			$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data_draft SET page_name='$style_sheet', page_content=:custom_css, revised='$today', `source`=3";
 		$stmt = $bwb_dbh->prepare($query);
 		$cnt = $stmt->execute(array(':custom_css' => $custom_css));
 	
 		if ($action == "Publish")	// Publish latest changes.
 		{
-			//Start by deleting all old data in table.
-			$query = "TRUNCATE TABLE " . BWB_TABLE_PREFIX . $custom_site_css_table;
-			$cnt = $bwb_dbh->exec($query);
-			
 			//Insert new data into table.
-			$query = "INSERT INTO " . BWB_TABLE_PREFIX . $custom_site_css_table . " (custom_css, revised) VALUES ('" . $custom_css  . "', '" . $today . "')";
+			$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "custom_site_css WHERE name = '" . $style_sheet . "'";
+			$result = $bwb_dbh->query($query);
+			if ($result->rowCount() > 0)
+				$query = "UPDATE " . BWB_TABLE_PREFIX . "custom_site_css SET custom_css = '" . $custom_css . "', revised = '" . $today . "' WHERE name = '" . $style_sheet . "'";
+			else
+				$query = "INSERT INTO " . BWB_TABLE_PREFIX . "custom_site_css SET custom_css = '" . $custom_css . "', revised = '" . $today . "', name = '" . $style_sheet . "'";
 			$cnt = $bwb_dbh->exec($query);
 		}
 		
-		$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data_bkup SET page_name='$custom_site_css_table', page_content=:custom_css, revised='$today', source=3";
+		$query = "INSERT INTO " . BWB_TABLE_PREFIX . "page_data_bkup SET page_name='$style_sheet', page_content=:custom_css, revised='$today', source=3";
 		$stmt = $bwb_dbh->prepare($query);
 		$stmt->execute(array(':custom_css' => $custom_css));
 	}
@@ -85,9 +94,9 @@
 	/////////////////////////////////////////////
 	// Build string for site.css file /////
 	if ($action == "Preview")
-		$site_css_table = "site_css_preview";
+		$style_sheet = "site_css_preview";
 	
-	$css_string = BuildCSSString(BWB_TABLE_PREFIX . $site_css_table, BWB_TABLE_PREFIX . $class_table, $bwb_dbh, BWB_BASE_DIR, BWB_IMAGE_DIR, BWB_TABLE_PREFIX . "fonts");
+	$css_string = BuildCSSString($style_sheet, $bwb_dbh, BWB_BASE_DIR, BWB_IMAGE_DIR, BWB_TABLE_PREFIX);
 			
 
 	////////////////////////////////////////////////////////
