@@ -8,12 +8,15 @@
 // 
 	include ("check_session.php");
 ?>
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
-<html xmlns="http://www.w3.org/1999/xhtml">
+<!DOCTYPE html>
+<html>
 <head>
 <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
-<title>Server Information</title>
-<link rel="stylesheet" href="manager.css" type="text/css">
+<title>Server Information | Breeze Website Builder</title>
+<link rel="stylesheet" href="theme/<?php echo $theme; ?>/manager.css" type="text/css">
+<script>
+	window.parent.document.title = document.title;
+</script>
 </head>
 
 <body id="workspace_body">
