@@ -8,6 +8,8 @@
 // Added table prefix handling.
 // Revised: 3/23/2015	ELL
 // Added updating of mobile menu description.
+// Revised: 2/26/2018	ELL
+// Added 3rd menu category for systems that ane not mobile (cell phones) but have touchscreens.
 // 
 // 
 	include ("check_session.php");
@@ -22,6 +24,9 @@
 		
 		$query = "UPDATE `" . BWB_TABLE_PREFIX . "menus` SET `description` = '" . $description . " Mobile' WHERE `menu_name` = '" . $menu_name . "_mobile'";
 		$cnt = $bwb_dbh->exec($query);
+		
+		$query = "UPDATE `" . BWB_TABLE_PREFIX . "menus` SET `description` = '" . $description . " Touchscreen' WHERE `menu_name` = '" . $menu_name . "_touchscreen'";
+		$cnt = $bwb_dbh->exec($query);
 	}
 	
 	header("Location: manage_menu.php?menu=$menu_name");
