@@ -62,5 +62,5 @@
 		header("Location: edit_favicon.php?favicon_uploaded=1");
 	}
 	else
-		echo EDIT_FAVICON_UPLOAD_FAIL_ERR . " " . CLICK_WORD " <a href='edit_favicon.php'>" . HERE_WORD . "</a> " . TO_TRY_AGAIN;
+		echo EDIT_FAVICON_UPLOAD_FAIL_ERR . " " . CLICK_WORD . " <a href='edit_favicon.php'>" . HERE_WORD . "</a> " . TO_TRY_AGAIN;
 ?>
