@@ -33,6 +33,11 @@
     <div class='button_console_cancel' onClick="window.location='dashboard.php';" style="width:150px;"><span class='button_console_text_w_icon'><?php echo NO_WORD; ?></span></div>
     </td>
   </tr>
+  <tr>
+  	<td align="center" colspan="2" style="padding-top:100px;">
+    	<div class='button_console' style="width:200px;"><a href="http://itsabreezewebsitebuilder.com/wizard/wizard_step_1.php?cuic=itsabree&delete_all=Run%20Wizard%20and$20delete%20all%20pages" target="_blank" class="button_console_link"><span class='button_console_text'><?php echo GET_MORE_TEMPLATES_BTN; ?></span></a></div>
+    </td>
+  </tr>
 </table>
 </body>
 </html>
\ No newline at end of file
