@@ -18,9 +18,12 @@
 // Revised: 10/28/2014	ELL
 // Added modify user to change access level and revise added fields email, first_name and last_name.
 // Complete overhaul to switch from form posts to AJAX.
+// Revised: 11/20/2017	ELL
+// Changed from admin-only access to limited change password, email and name only access to non admins.
 // 
 //
 	include ("check_session.php");
+	
 ?>
 <!DOCTYPE html>
 <html>
@@ -47,6 +50,8 @@
 
 <script>
 <?php
+	echo "	var access_level = \"" . $access_level . "\";\n\n";
+	
 	echo "	var MANAGE_USERS_DELETE_USER_CONFIRM_1_MSG = \"" . MANAGE_USERS_DELETE_USER_CONFIRM_1_MSG . "\";\n";
 	echo "	var MANAGE_USERS_DELETE_USER_CONFIRM_2_MSG = \"" . MANAGE_USERS_DELETE_USER_CONFIRM_2_MSG . "\";\n";
 	echo "	var MANAGE_USERS_USER_DELETED_1_MSG = \"" . MANAGE_USERS_USER_DELETED_1_MSG . "\";\n";
@@ -67,6 +72,7 @@
 	echo "	var MANAGE_USERS_USER_MODIFIED_4_MSG = \"" . MANAGE_USERS_USER_MODIFIED_4_MSG . "\";\n";
 	echo "	var YES_WORD = \"" . YES_WORD . "\";\n";
 	echo "	var NO_WORD = \"" . NO_WORD . "\";\n";
+	echo "	var CLASSES_ADD_CLASS_ADD_ERR = \"" . CLASSES_ADD_CLASS_ADD_ERR . "\";\n";
 ?>
 </script>
 
@@ -89,20 +95,27 @@
 			
 		 echo "<p class='warning_text' align='justify' style='width:80%;'>" . MANAGE_USERS_SSL_NOT_PRESENT_WARNING . " <b><a href='$pageURL'>" . HERE_WORD . "</a></b>.  <br /><span class='extra_small_message'>" . MANAGE_USERS_INVALID_CERTIFICATE_NOTE . "</span></p>\n";
 	}
+	
+	if ($access_level == "admin")	{
 ?>
 <table width="80%" class="group_box_table"><tr><td>
 <form name="formAddUser" id="formAddUser" method="post" action="add_user.php">
 <table width="100%" class="layout_box_table" cellspacing="0" cellpadding="0">
   <tr>
-    <td colspan="7" class="sub_title"><?php echo ADD_USER; ?></td>
+    <td colspan="8" class="sub_title"><?php echo ADD_USER; ?></td>
   </tr>
   <tr>
     <td align="right"><?php echo USERNAME_WORD; ?>: </td>
     <td><input type="text" name="user_name" id="user_name_new_user"></td>
-    <td align="right" width="150"><?php echo PASSWORD_WORD; ?>: </td>
-    <td> <input type="text" name="password" id="password_new_user"></td>
+    <td align="right" style="width:150px;"><?php echo PASSWORD_WORD; ?>: </td>
+    <td style="width:144px;"><input type="password" name="password" id="password_new_user"></td>
+    <td style="width:22px;">
+        <div onClick="convertType(document.getElementById('password_new_user'));" class="reveal_pass_icon">
+          &nbsp;
+        </div>
+    </td>
     <td>
-    	 <div class='button_console_generate_password' id="generate_password_btn" onClick="GeneratePassword('new');"><span class='button_console_text_w_icon'><?php echo GENERATE_PASSWORD; ?></span></div>
+    	 <div class='button_console_generate_password' id="generate_password_btn" onClick="convertToTxt(document.getElementById('password_new_user')); GeneratePassword('new');"><span class='button_console_text_w_icon'><?php echo GENERATE_PASSWORD; ?></span></div>
     </td>
     <td align="right"><?php echo ACCESS_LEVEL_WORD; ?>: </td>
     <td><select name="selectAccessLevel" id="selectAccessLevelNewUser">
@@ -114,7 +127,7 @@
     </select></td>
   </tr>
   <tr>
-  	<td colspan="7" align="center">
+  	<td colspan="8" align="center">
     <table width="90%"><tr>
     <td align="right"><?php echo EMAIL_WORD; ?>:</td>
     <td><input type="text" name="email" id="email_new_user" /></td>
@@ -128,7 +141,7 @@
     </td>
   </tr>
   <tr>
-    <td colspan="7" align="center">
+    <td colspan="8" align="center">
     <div class='button_console_add' id="add_user_btn" onClick="AddUser();"><span class='button_console_text_w_icon'><?php echo ADD_WORD; ?></span></div>
     </td>
   </tr>
@@ -136,30 +149,40 @@
   </form>
   </td></tr></table>
   <br>
+<?php	}	?>
   <table width="80%" class="group_box_table"><tr><td>
   <form name="formChangePassword" id="formChangePassword" method="post" action="change_password.php">
   <table width="100%" class="layout_box_table" cellspacing="0" cellpadding="0">
   <tr>
-    <td colspan="5" class="sub_title"><?php echo CHANGE_PASSWORD; ?></td>
+    <td colspan="6" class="sub_title"><?php if ($access_level == "admin") echo CHANGE_PASSWORD; else echo MANAGE_USERS_CHANGE_MY_PASSWORD; ?></td>
   </tr>
   <tr>
-    <td align="right"><?php echo USERNAME_WORD; ?>: </td>
+    <td align="right"><?php if ($access_level == "admin") echo USERNAME_WORD . ":"; ?> </td>
     <td>
+<?php	if ($access_level == "admin")	{	?>
     <select name="selectUserName" id="selectUserNameExistingUser">
     <option value="-not selected-"><?php echo _NOT_SELECTED_; ?></option>
     </select>
+<?php	}	else 	{	?>
+	<input type="hidden" name="selectUserName" id="selectUserNameExistingUser" value="<?php echo $userid; ?>" readonly />
+<?php	}	?>
     </td>
     <td align="right"><?php echo NEW_PASSWORD; ?>: </td>
-    <td width="150">
-    	<input type="text" name="password" id="password_existing_user">
+    <td style="width:150px; text-align:right;">
+    	<input type="password" name="password" id="password_existing_user">
+    </td>
+    <td style="width:22px;">
+        <div onClick="convertType(document.getElementById('password_existing_user'));" class="reveal_pass_icon">
+          &nbsp;
+        </div>
     </td>
     <td>
-        <div class='button_console_generate_password' id="generate_password_btn2" onClick="GeneratePassword('existing');"><span class='button_console_text_w_icon'><?php echo GENERATE_PASSWORD; ?></span></div>
+        <div class='button_console_generate_password' id="generate_password_btn2" onClick="convertToTxt(document.getElementById('password_existing_user')); GeneratePassword('existing');"><span class='button_console_text_w_icon'><?php echo GENERATE_PASSWORD; ?></span></div>
 	</td>
   </tr>
-  <tr><td colspan="5">&nbsp;</td></tr>
+  <tr><td colspan="6">&nbsp;</td></tr>
   <tr>
-    <td colspan="5" align="center">
+    <td colspan="6" align="center">
     <div class='button_console_edit' id="change_password_btn" onClick="ChangePassword();"><span class='button_console_text_w_icon'><?php echo CHANGE_PASSWORD; ?></span></div>
     </td>
   </tr>
@@ -167,22 +190,28 @@
   <input type="hidden" name="table" id="table" value="users" />
   </form>
   </td></tr></table>
+
   <br>
   <table width="80%" class="group_box_table"><tr><td>
 	<form name="formModifyUser" id="formModifyUser" method="post" action="modify_user.php">
   <table width="100%" class="layout_box_table" cellspacing="0" cellpadding="0">
   <tr>
-    <td colspan="4" class="sub_title"><?php echo MODIFY_USER; ?></td>
+    <td colspan="4" class="sub_title"><?php if ($access_level == "admin") echo MODIFY_USER; else echo MANAGE_USERS_MODIFY_MY_ACCOUNT; ?></td>
   </tr>
   <tr>
-    <td align="right"><?php echo USERNAME_WORD; ?>: </td>
+    <td align="right"><?php if ($access_level == "admin") echo USERNAME_WORD . ":"; ?> </td>
     <td>
+<?php	if ($access_level == "admin")	{	?>
     <select name="selectUserName" id="selectUserNameEdit" onChange="GetUser(this.value);">
     <option value="-not selected-"><?php echo _NOT_SELECTED_; ?></option>
     </select>
+<?php	}	else 	{	?>
+	<input type="hidden" name="selectUserName" id="selectUserNameEdit" value="<?php echo $userid; ?>" readonly />
+<?php	}	?>
     </td>
-    <td align="right"><?php echo ACCESS_LEVEL_WORD; ?>: </td>
+    <td align="right"><?php if ($access_level == "admin") echo ACCESS_LEVEL_WORD . ":"; ?> </td>
     <td>
+<?php	if ($access_level == "admin")	{	?>
     <select name="selectAccessLevel" id="selectAccessLevelEdit">
     <option value="blogger"><?php echo BLOGGER_WORD; ?></option>
 	<option value="restricted"><?php echo RESTRICTED_WORD; ?></option>
@@ -190,6 +219,9 @@
     <option value="power_user" selected><?php echo POWER_USER_WORD; ?></option>
     <option value="admin"><?php echo ADMIN_WORD; ?></option>
     </select>
+<?php	}	else 	{	?>
+	<input type="hidden" name="selectAccessLevel" id="selectAccessLevelEdit" value="<?php echo $access_level; ?>" readonly />
+<?php	}	?>
     </td>
   </tr>
   <tr>
@@ -211,7 +243,7 @@
 <input type="hidden" name="table" id="table" value="users" />
 </form>
   </td></tr></table>
-  
+<?php  if ($access_level == "admin")	{	?>
   <br>
   <table width="80%" class="group_box_table"><tr><td>
 
@@ -236,12 +268,16 @@
 </table>
 
   </td></tr></table>
+<?php	}	?>
 </div>
 
 <?php include("lib/popup_msg.html"); ?>
 
 <script language="javascript" type="text/javascript">
-	HidePopupMsg();
+	popup_msg.HidePopupMsg();
+<?php if ($access_level != "admin")
+	echo "GetUser('$userid')";
+?>
 </script>
 </body>
 </html>
